@@ -28,6 +28,7 @@ package jdk.net;
 import java.io.FileDescriptor;
 import java.net.SocketException;
 import java.net.SocketOption;
+import java.net.StandardProtocolFamily;
 import java.security.AccessController;
 import java.security.PrivilegedAction;
 import java.util.Collections;
@@ -209,6 +210,9 @@ public final class ExtendedSocketOptions {
      * sizes to the {@link java.net.NetworkInterface#getMTU() local MTU}. Depending
      * on the implementation and the network interface, packets larger than the MTU
      * may be sent or dropped silently or dropped with an exception thrown.
+     * For {@link StandardProtocolFamily#INET6 IPv6} sockets it is
+     * system dependent whether the option also applies to datagrams
+     * sent to IPv4 addresses.
      *
      * @apiNote
      * For IPv4 this option sets the DF (Do not Fragment) flag in the IP packet
@@ -263,10 +267,9 @@ public final class ExtendedSocketOptions {
                 new sun.net.ext.ExtendedSocketOptions(extendedOptions) {
 
             @Override
-            @SuppressWarnings("removal")
             public void setOption(FileDescriptor fd,
                                   SocketOption<?> option,
-                                  Object value)
+                                  Object value, boolean isIPv6)
                 throws SocketException
             {
                 if (fd == null || !fd.valid())
@@ -277,7 +280,7 @@ public final class ExtendedSocketOptions {
                 } else if (option == TCP_KEEPCOUNT) {
                     setTcpkeepAliveProbes(fd, (Integer) value);
                 } else if (option == IP_DONTFRAGMENT) {
-                    setIpDontFragment(fd, (Boolean) value);
+                    setIpDontFragment(fd, (Boolean) value, isIPv6);
                 } else if (option == TCP_KEEPIDLE) {
                     setTcpKeepAliveTime(fd, (Integer) value);
                 } else if (option == TCP_KEEPINTERVAL) {
@@ -295,9 +298,8 @@ public final class ExtendedSocketOptions {
             }
 
             @Override
-            @SuppressWarnings("removal")
             public Object getOption(FileDescriptor fd,
-                                    SocketOption<?> option)
+                                    SocketOption<?> option, boolean isIPv6)
                 throws SocketException
             {
                 if (fd == null || !fd.valid())
@@ -308,7 +310,7 @@ public final class ExtendedSocketOptions {
                 } else if (option == TCP_KEEPCOUNT) {
                     return getTcpkeepAliveProbes(fd);
                 } else if (option == IP_DONTFRAGMENT) {
-                    return getIpDontFragment(fd);
+                    return getIpDontFragment(fd, isIPv6);
                 } else if (option == TCP_KEEPIDLE) {
                     return getTcpKeepAliveTime(fd);
                 } else if (option == TCP_KEEPINTERVAL) {
@@ -352,9 +354,9 @@ public final class ExtendedSocketOptions {
         platformSocketOptions.setTcpKeepAliveTime(fdAccess.get(fd), value);
     }
 
-    private static void setIpDontFragment(FileDescriptor fd, boolean value)
+    private static void setIpDontFragment(FileDescriptor fd, boolean value, boolean isIPv6)
             throws SocketException {
-        platformSocketOptions.setIpDontFragment(fdAccess.get(fd), value);
+        platformSocketOptions.setIpDontFragment(fdAccess.get(fd), value, isIPv6);
     }
 
     private static void setTcpKeepAliveIntvl(FileDescriptor fd, int value)
@@ -366,8 +368,8 @@ public final class ExtendedSocketOptions {
         return platformSocketOptions.getTcpkeepAliveProbes(fdAccess.get(fd));
     }
 
-    private static boolean getIpDontFragment(FileDescriptor fd) throws SocketException {
-        return platformSocketOptions.getIpDontFragment(fdAccess.get(fd));
+    private static boolean getIpDontFragment(FileDescriptor fd, boolean isIPv6) throws SocketException {
+        return platformSocketOptions.getIpDontFragment(fdAccess.get(fd), isIPv6);
     }
 
     private static int getTcpKeepAliveTime(FileDescriptor fd) throws SocketException {
@@ -464,11 +466,11 @@ public final class ExtendedSocketOptions {
             throw new UnsupportedOperationException("unsupported TCP_KEEPINTVL option");
         }
 
-        void setIpDontFragment(int fd, final boolean value) throws SocketException {
+        void setIpDontFragment(int fd, final boolean value, boolean isIPv6) throws SocketException {
             throw new UnsupportedOperationException("unsupported IP_DONTFRAGMENT option");
         }
 
-        boolean getIpDontFragment(int fd) throws SocketException {
+        boolean getIpDontFragment(int fd, boolean isIPv6) throws SocketException {
             throw new UnsupportedOperationException("unsupported IP_DONTFRAGMENT option");
         }
 
