@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1998, 2021, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 1998, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -63,7 +63,6 @@ import javax.print.attribute.standard.DialogTypeSelection;
 import javax.print.attribute.standard.JobName;
 import javax.print.attribute.standard.Sides;
 
-import java.io.BufferedInputStream;
 import java.io.BufferedOutputStream;
 import java.io.BufferedReader;
 import java.io.File;
@@ -339,7 +338,7 @@ public class PSPrinterJob extends RasterPrinterJob {
 
     @SuppressWarnings("removal")
     private static void initStatic() {
-       //enable priviledges so initProps can access system properties,
+       //enable privileges so initProps can access system properties,
         // open the property file, etc.
         java.security.AccessController.doPrivileged(
                             new java.security.PrivilegedAction<Object>() {
@@ -1309,9 +1308,7 @@ public class PSPrinterJob extends RasterPrinterJob {
                                       bb, true);
                         bb.flip();
                         len = bb.limit();
-                    } catch(IllegalStateException xx){
-                        continue;
-                    } catch(CoderMalfunctionError xx){
+                    } catch (IllegalStateException | CoderMalfunctionError xx){
                         continue;
                     }
                     /* The width to fit to may either be specified,
