@@ -66,14 +66,16 @@ import java.util.ListResourceBundle;
 public class FormatData_es_419 extends ListResourceBundle {
     @Override
     protected final Object[][] getContents() {
+        final String metaValue_generic_DateFormatItem_yyyyMMMd = "d 'de' MMM 'de' y G";
+        final String metaValue_generic_DateFormatItem_yyyyMMM = "MMM 'de' y G";
         final String[] metaValue_generic_DayNarrows = new String[] {
-            "d",
-            "l",
-            "m",
-            "m",
-            "j",
-            "v",
-            "s",
+            "D",
+            "L",
+            "M",
+            "M",
+            "J",
+            "V",
+            "S",
         };
         final String[] metaValue_generic_QuarterNames = new String[] {
             "1.\u00ba trimestre",
@@ -81,12 +83,25 @@ public class FormatData_es_419 extends ListResourceBundle {
             "3.\u00ba trimestre",
             "4.\u00ba trimestre",
         };
+        final String[] metaValue_long_Eras = new String[] {
+            "a.C.",
+            "d.C.",
+        };
         final String[] metaValue_generic_TimePatterns = new String[] {
             "HH:mm:ss zzzz",
             "HH:mm:ss z",
             "HH:mm:ss",
             "HH:mm",
         };
+        final String metaValue_generic_DateFormatItem_yMMMEd = "E, d MMM y";
+        final String metaValue_generic_DateFormatItem_yMEd = "E d/M/y";
+        final String metaValue_generic_DateFormatItem_MMMdd = "dd-MMM";
+        final String metaValue_generic_DateFormatItem_yQQQ = "QQQ 'de' y";
+        final String metaValue_generic_DateFormatItem_Hmsvvvv = "HH:mm:ss vvvv";
+        final String metaValue_generic_DateFormatItem_EHms = "E, HH:mm:ss";
+        final String metaValue_generic_DateFormatItem_EHm = "E, HH:mm";
+        final String metaValue_generic_DateFormatItem_Hmsv = "HH:mm:ss v";
+        final String metaValue_generic_DateFormatItem_Hmv = "HH:mm v";
         final String[] metaValue_java_time_generic_DatePatterns = new String[] {
             "EEEE, d 'de' MMMM 'de' y G",
             "d 'de' MMMM 'de' y G",
@@ -99,17 +114,6 @@ public class FormatData_es_419 extends ListResourceBundle {
             "d 'de' MMM 'de' y GGGG",
             "d/M/y G",
         };
-        final String metaValue_generic_DateFormatItem_yMMMEd = "E, d MMM y";
-        final String metaValue_generic_DateFormatItem_yMEd = "E d/M/y";
-        final String metaValue_generic_DateFormatItem_MMMdd = "dd-MMM";
-        final String metaValue_generic_DateFormatItem_yyyyMMMd = "d 'de' MMM 'de' y G";
-        final String metaValue_generic_DateFormatItem_yQQQ = "QQQ 'de' y";
-        final String metaValue_generic_DateFormatItem_Hmsvvvv = "HH:mm:ss vvvv";
-        final String metaValue_generic_DateFormatItem_EHms = "E, HH:mm:ss";
-        final String metaValue_generic_DateFormatItem_EHm = "E, HH:mm";
-        final String metaValue_generic_DateFormatItem_yyyyMMM = "MMM 'de' y G";
-        final String metaValue_generic_DateFormatItem_Hmsv = "HH:mm:ss v";
-        final String metaValue_generic_DateFormatItem_Hmv = "HH:mm v";
         final String metaValue_DateFormatItem_Hm = "HH:mm";
         final String metaValue_DateFormatItem_H = "HH";
         final String metaValue_DateFormatItem_Hms = "HH:mm:ss";
@@ -118,37 +122,58 @@ public class FormatData_es_419 extends ListResourceBundle {
             "R.O.C.",
         };
         final Object[][] data = new Object[][] {
-            { "islamic-umalqura.DateFormatItem.EHms", metaValue_generic_DateFormatItem_EHms },
-            { "roc.DateFormatItem.Hmsvvvv", metaValue_generic_DateFormatItem_Hmsvvvv },
-            { "islamic.DateFormatItem.Hmsv", metaValue_generic_DateFormatItem_Hmsv },
+            { "generic.DayNarrows", metaValue_generic_DayNarrows },
+            { "generic.QuarterNames", metaValue_generic_QuarterNames },
+            { "generic.TimePatterns", metaValue_generic_TimePatterns },
+            { "java.time.generic.DatePatterns", metaValue_java_time_generic_DatePatterns },
             { "generic.DatePatterns", metaValue_generic_DatePatterns },
-            { "islamic-civil.DateFormatItem.yMMMEd", metaValue_generic_DateFormatItem_yMMMEd },
-            { "java.time.japanese.DatePatterns", metaValue_java_time_generic_DatePatterns },
-            { "roc.QuarterNames", metaValue_generic_QuarterNames },
-            { "roc.DateFormatItem.EHms", metaValue_generic_DateFormatItem_EHms },
-            { "islamic-umalqura.DateFormatItem.EHm", metaValue_generic_DateFormatItem_EHm },
-            { "roc.DateFormatItem.GyMMMd", metaValue_generic_DateFormatItem_yyyyMMMd },
-            { "islamic-civil.DateFormatItem.yQQQ", metaValue_generic_DateFormatItem_yQQQ },
-            { "japanese.DateFormatItem.Hms", metaValue_DateFormatItem_Hms },
-            { "islamic-umalqura.DateFormatItem.yMEd", metaValue_generic_DateFormatItem_yMEd },
-            { "japanese.TimePatterns", metaValue_generic_TimePatterns },
-            { "roc.long.Eras", metaValue_java_time_roc_long_Eras },
-            { "buddhist.DateFormatItem.GyMMMd", metaValue_generic_DateFormatItem_yyyyMMMd },
-            { "japanese.DateFormatItem.H", metaValue_DateFormatItem_H },
-            { "timezone.regionFormat.standard", "hora est\u00e1ndar de {0}" },
-            { "generic.DateFormatItem.EHms", metaValue_generic_DateFormatItem_EHms },
+            { "generic.DateTimePatterns",
+                new String[] {
+                    "{1}, {0}",
+                    "{1}, {0}",
+                    "{1} {0}",
+                    "{1} {0}",
+                }
+            },
+            { "generic.DateFormatItem.yMMMEd", metaValue_generic_DateFormatItem_yMMMEd },
             { "generic.DateFormatItem.yMEd", metaValue_generic_DateFormatItem_yMEd },
-            { "buddhist.DateFormatItem.MMMdd", metaValue_generic_DateFormatItem_MMMdd },
-            { "DateFormatItem.Hmsvvvv", metaValue_generic_DateFormatItem_Hmsvvvv },
-            { "japanese.DateFormatItem.Hmv", metaValue_generic_DateFormatItem_Hmv },
-            { "DateFormatItem.Hm", metaValue_DateFormatItem_Hm },
-            { "islamic-umalqura.DateFormatItem.H", metaValue_DateFormatItem_H },
-            { "generic.DateFormatItem.Hmv", metaValue_generic_DateFormatItem_Hmv },
-            { "buddhist.DateFormatItem.EHm", metaValue_generic_DateFormatItem_EHm },
-            { "islamic-umalqura.DateFormatItem.Hm", metaValue_DateFormatItem_Hm },
-            { "islamic.DateFormatItem.H", metaValue_DateFormatItem_H },
+            { "generic.DateFormatItem.MMMdd", metaValue_generic_DateFormatItem_MMMdd },
+            { "generic.DateFormatItem.yyyyMMMd", metaValue_generic_DateFormatItem_yyyyMMMd },
+            { "generic.DateFormatItem.yyyyMMMEd", "EEE, d 'de' MMM 'de' y G" },
+            { "generic.DateFormatItem.GyMMMd", metaValue_generic_DateFormatItem_yyyyMMMd },
+            { "generic.DateFormatItem.yQQQ", metaValue_generic_DateFormatItem_yQQQ },
+            { "generic.DateFormatItem.yyyyMEd", "E d/M/y GGGGG" },
+            { "generic.DateFormatItem.Hmsvvvv", metaValue_generic_DateFormatItem_Hmsvvvv },
+            { "generic.DateFormatItem.EHms", metaValue_generic_DateFormatItem_EHms },
+            { "generic.DateFormatItem.EHm", metaValue_generic_DateFormatItem_EHm },
+            { "generic.DateFormatItem.yyyyMMM", metaValue_generic_DateFormatItem_yyyyMMM },
             { "generic.DateFormatItem.MMMEd", "E, d 'de' MMM" },
-            { "japanese.DateFormatItem.Hmsv", metaValue_generic_DateFormatItem_Hmsv },
+            { "generic.DateFormatItem.yyyyQQQ", "QQQ 'de' y G" },
+            { "generic.DateFormatItem.Hmsv", metaValue_generic_DateFormatItem_Hmsv },
+            { "generic.DateFormatItem.GyMMMEd", "E, d 'de' MMM 'de' y G" },
+            { "generic.DateFormatItem.Hmv", metaValue_generic_DateFormatItem_Hmv },
+            { "generic.DateFormatItem.MMMd", "d 'de' MMM" },
+            { "generic.DateFormatItem.GyMMM", metaValue_generic_DateFormatItem_yyyyMMM },
+            { "DayNarrows", metaValue_generic_DayNarrows },
+            { "standalone.DayNarrows", metaValue_generic_DayNarrows },
+            { "QuarterNames", metaValue_generic_QuarterNames },
+            { "standalone.QuarterNames", metaValue_generic_QuarterNames },
+            { "QuarterAbbreviations", metaValue_generic_QuarterNames },
+            { "long.Eras", metaValue_long_Eras },
+            { "Eras", metaValue_long_Eras },
+            { "narrow.Eras", metaValue_long_Eras },
+            { "field.dayperiod", "a.m./p.m." },
+            { "timezone.regionFormat.daylight", "hora de verano de {0}" },
+            { "timezone.regionFormat.standard", "hora est\u00e1ndar de {0}" },
+            { "TimePatterns", metaValue_generic_TimePatterns },
+            { "DatePatterns",
+                new String[] {
+                    "EEEE, d 'de' MMMM 'de' y",
+                    "d 'de' MMMM 'de' y",
+                    "d MMM y",
+                    "d/M/yy",
+                }
+            },
             { "DateTimePatterns",
                 new String[] {
                     "{1}, {0}",
@@ -157,27 +182,79 @@ public class FormatData_es_419 extends ListResourceBundle {
                     "{1}, {0}",
                 }
             },
-            { "latn.NumberElements",
-                new String[] {
-                    ".",
-                    ",",
-                    ";",
-                    "%",
-                    "0",
-                    "#",
-                    "-",
-                    "E",
-                    "\u2030",
-                    "\u221e",
-                    "NaN",
-                    "",
-                    "",
-                }
-            },
-            { "japanese.DatePatterns", metaValue_generic_DatePatterns },
-            { "roc.DateFormatItem.yMEd", metaValue_generic_DateFormatItem_yMEd },
+            { "DateFormatItem.yMMMEd", metaValue_generic_DateFormatItem_yMMMEd },
+            { "DateFormatItem.yMEd", metaValue_generic_DateFormatItem_yMEd },
+            { "DateFormatItem.MMMdd", metaValue_generic_DateFormatItem_MMMdd },
+            { "DateFormatItem.GyMMMd", metaValue_generic_DateFormatItem_yyyyMMMd },
+            { "DateFormatItem.yQQQ", metaValue_generic_DateFormatItem_yQQQ },
+            { "DateFormatItem.Hmsvvvv", metaValue_generic_DateFormatItem_Hmsvvvv },
+            { "DateFormatItem.Hm", metaValue_DateFormatItem_Hm },
+            { "DateFormatItem.EHms", metaValue_generic_DateFormatItem_EHms },
+            { "DateFormatItem.EHm", metaValue_generic_DateFormatItem_EHm },
+            { "DateFormatItem.H", metaValue_DateFormatItem_H },
+            { "DateFormatItem.Hmsv", metaValue_generic_DateFormatItem_Hmsv },
+            { "DateFormatItem.Hms", metaValue_DateFormatItem_Hms },
+            { "DateFormatItem.Hmv", metaValue_generic_DateFormatItem_Hmv },
+            { "buddhist.DayNarrows", metaValue_generic_DayNarrows },
+            { "buddhist.QuarterNames", metaValue_generic_QuarterNames },
+            { "buddhist.TimePatterns", metaValue_generic_TimePatterns },
+            { "java.time.buddhist.DatePatterns", metaValue_java_time_generic_DatePatterns },
+            { "buddhist.DatePatterns", metaValue_generic_DatePatterns },
+            { "buddhist.DateFormatItem.yMMMEd", metaValue_generic_DateFormatItem_yMMMEd },
+            { "buddhist.DateFormatItem.yMEd", metaValue_generic_DateFormatItem_yMEd },
+            { "buddhist.DateFormatItem.MMMdd", metaValue_generic_DateFormatItem_MMMdd },
+            { "buddhist.DateFormatItem.GyMMMd", metaValue_generic_DateFormatItem_yyyyMMMd },
+            { "buddhist.DateFormatItem.yQQQ", metaValue_generic_DateFormatItem_yQQQ },
             { "buddhist.DateFormatItem.Hmsvvvv", metaValue_generic_DateFormatItem_Hmsvvvv },
+            { "buddhist.DateFormatItem.Hm", metaValue_DateFormatItem_Hm },
+            { "buddhist.DateFormatItem.EHms", metaValue_generic_DateFormatItem_EHms },
+            { "buddhist.DateFormatItem.EHm", metaValue_generic_DateFormatItem_EHm },
+            { "buddhist.DateFormatItem.H", metaValue_DateFormatItem_H },
+            { "buddhist.DateFormatItem.Hmsv", metaValue_generic_DateFormatItem_Hmsv },
+            { "buddhist.DateFormatItem.Hms", metaValue_DateFormatItem_Hms },
+            { "buddhist.DateFormatItem.Hmv", metaValue_generic_DateFormatItem_Hmv },
+            { "japanese.DayNarrows", metaValue_generic_DayNarrows },
+            { "japanese.QuarterNames", metaValue_generic_QuarterNames },
+            { "japanese.TimePatterns", metaValue_generic_TimePatterns },
+            { "java.time.japanese.DatePatterns", metaValue_java_time_generic_DatePatterns },
+            { "japanese.DatePatterns", metaValue_generic_DatePatterns },
+            { "japanese.DateFormatItem.yMMMEd", metaValue_generic_DateFormatItem_yMMMEd },
+            { "japanese.DateFormatItem.yMEd", metaValue_generic_DateFormatItem_yMEd },
+            { "japanese.DateFormatItem.MMMdd", metaValue_generic_DateFormatItem_MMMdd },
+            { "japanese.DateFormatItem.GyMMMd", metaValue_generic_DateFormatItem_yyyyMMMd },
+            { "japanese.DateFormatItem.yQQQ", metaValue_generic_DateFormatItem_yQQQ },
             { "japanese.DateFormatItem.Hmsvvvv", metaValue_generic_DateFormatItem_Hmsvvvv },
+            { "japanese.DateFormatItem.Hm", metaValue_DateFormatItem_Hm },
+            { "japanese.DateFormatItem.EHms", metaValue_generic_DateFormatItem_EHms },
+            { "japanese.DateFormatItem.EHm", metaValue_generic_DateFormatItem_EHm },
+            { "japanese.DateFormatItem.H", metaValue_DateFormatItem_H },
+            { "japanese.DateFormatItem.Hmsv", metaValue_generic_DateFormatItem_Hmsv },
+            { "japanese.DateFormatItem.Hms", metaValue_DateFormatItem_Hms },
+            { "japanese.DateFormatItem.Hmv", metaValue_generic_DateFormatItem_Hmv },
+            { "roc.DayNarrows", metaValue_generic_DayNarrows },
+            { "roc.QuarterNames", metaValue_generic_QuarterNames },
+            { "java.time.roc.long.Eras", metaValue_java_time_roc_long_Eras },
+            { "roc.long.Eras", metaValue_java_time_roc_long_Eras },
+            { "java.time.roc.Eras", metaValue_java_time_roc_long_Eras },
+            { "roc.Eras", metaValue_java_time_roc_long_Eras },
+            { "java.time.roc.narrow.Eras", metaValue_java_time_roc_long_Eras },
+            { "roc.narrow.Eras", metaValue_java_time_roc_long_Eras },
+            { "roc.TimePatterns", metaValue_generic_TimePatterns },
+            { "java.time.roc.DatePatterns", metaValue_java_time_generic_DatePatterns },
+            { "roc.DatePatterns", metaValue_generic_DatePatterns },
+            { "roc.DateFormatItem.yMMMEd", metaValue_generic_DateFormatItem_yMMMEd },
+            { "roc.DateFormatItem.yMEd", metaValue_generic_DateFormatItem_yMEd },
+            { "roc.DateFormatItem.MMMdd", metaValue_generic_DateFormatItem_MMMdd },
+            { "roc.DateFormatItem.GyMMMd", metaValue_generic_DateFormatItem_yyyyMMMd },
+            { "roc.DateFormatItem.yQQQ", metaValue_generic_DateFormatItem_yQQQ },
+            { "roc.DateFormatItem.Hmsvvvv", metaValue_generic_DateFormatItem_Hmsvvvv },
+            { "roc.DateFormatItem.Hm", metaValue_DateFormatItem_Hm },
+            { "roc.DateFormatItem.EHms", metaValue_generic_DateFormatItem_EHms },
+            { "roc.DateFormatItem.EHm", metaValue_generic_DateFormatItem_EHm },
+            { "roc.DateFormatItem.H", metaValue_DateFormatItem_H },
+            { "roc.DateFormatItem.Hmsv", metaValue_generic_DateFormatItem_Hmsv },
+            { "roc.DateFormatItem.Hms", metaValue_DateFormatItem_Hms },
+            { "roc.DateFormatItem.Hmv", metaValue_generic_DateFormatItem_Hmv },
             { "islamic.MonthNames",
                 new String[] {
                     "Muharram",
@@ -195,139 +272,92 @@ public class FormatData_es_419 extends ListResourceBundle {
                     "",
                 }
             },
-            { "islamic-civil.DateFormatItem.MMMdd", metaValue_generic_DateFormatItem_MMMdd },
-            { "islamic.DateFormatItem.yQQQ", metaValue_generic_DateFormatItem_yQQQ },
-            { "roc.DateFormatItem.H", metaValue_DateFormatItem_H },
-            { "roc.DateFormatItem.Hmsv", metaValue_generic_DateFormatItem_Hmsv },
-            { "islamic.DatePatterns", metaValue_generic_DatePatterns },
-            { "islamic.DateFormatItem.EHms", metaValue_generic_DateFormatItem_EHms },
-            { "islamic.DateFormatItem.Hms", metaValue_DateFormatItem_Hms },
-            { "islamic-civil.DateFormatItem.Hm", metaValue_DateFormatItem_Hm },
-            { "roc.Eras", metaValue_java_time_roc_long_Eras },
-            { "generic.DateFormatItem.yyyyQQQ", "QQQ 'de' y G" },
-            { "DayNarrows", metaValue_generic_DayNarrows },
-            { "islamic.DateFormatItem.GyMMMd", metaValue_generic_DateFormatItem_yyyyMMMd },
-            { "islamic.DateFormatItem.Hm", metaValue_DateFormatItem_Hm },
-            { "roc.DatePatterns", metaValue_generic_DatePatterns },
-            { "java.time.roc.long.Eras", metaValue_java_time_roc_long_Eras },
-            { "islamic-umalqura.DateFormatItem.MMMdd", metaValue_generic_DateFormatItem_MMMdd },
-            { "japanese.DateFormatItem.MMMdd", metaValue_generic_DateFormatItem_MMMdd },
-            { "DateFormatItem.yQQQ", metaValue_generic_DateFormatItem_yQQQ },
-            { "islamic-civil.DateFormatItem.EHm", metaValue_generic_DateFormatItem_EHm },
-            { "roc.DateFormatItem.yMMMEd", metaValue_generic_DateFormatItem_yMMMEd },
-            { "java.time.generic.DatePatterns", metaValue_java_time_generic_DatePatterns },
-            { "japanese.DateFormatItem.EHms", metaValue_generic_DateFormatItem_EHms },
-            { "generic.TimePatterns", metaValue_generic_TimePatterns },
-            { "roc.DateFormatItem.Hm", metaValue_DateFormatItem_Hm },
-            { "DateFormatItem.Hmsv", metaValue_generic_DateFormatItem_Hmsv },
-            { "java.time.roc.narrow.Eras", metaValue_java_time_roc_long_Eras },
-            { "buddhist.TimePatterns", metaValue_generic_TimePatterns },
-            { "generic.DateFormatItem.EHm", metaValue_generic_DateFormatItem_EHm },
-            { "islamic-civil.DateFormatItem.yMEd", metaValue_generic_DateFormatItem_yMEd },
-            { "DateFormatItem.MMMdd", metaValue_generic_DateFormatItem_MMMdd },
-            { "long.CompactNumberPatterns",
+            { "islamic.MonthAbbreviations",
                 new String[] {
+                    "Muh.",
+                    "Saf.",
+                    "Rab. I",
+                    "Rab. II",
+                    "Jum. I",
+                    "Jum. II",
+                    "Raj.",
+                    "Sha.",
+                    "Ram.",
+                    "Shaw.",
+                    "Dhu\u02bbl-Q.",
+                    "Dhu\u02bbl-H.",
                     "",
-                    "",
-                    "",
-                    "{one:0' 'mil other:0' 'mil}",
-                    "{one:00' 'mil other:00' 'mil}",
-                    "{one:000' 'mil other:000' 'mil}",
-                    "{one:0' 'mill\u00f3n other:0' 'millones}",
-                    "{one:00' 'millones other:00' 'millones}",
-                    "{one:000' 'millones other:000' 'millones}",
-                    "{one:0' 'mil' 'millones other:0' 'mil' 'millones}",
-                    "{one:00' 'mil' 'millones other:00' 'mil' 'millones}",
-                    "{one:000' 'mil' 'millones other:000' 'mil' 'millones}",
-                    "{other:0' 'bill\u00f3n}",
-                    "{other:00' 'billones}",
-                    "{other:000' 'billones}",
                 }
             },
-            { "islamic-civil.DateFormatItem.GyMMMd", metaValue_generic_DateFormatItem_yyyyMMMd },
-            { "standalone.QuarterNames", metaValue_generic_QuarterNames },
-            { "islamic.DateFormatItem.Hmsvvvv", metaValue_generic_DateFormatItem_Hmsvvvv },
-            { "DateFormatItem.H", metaValue_DateFormatItem_H },
-            { "standalone.DayNarrows",
-                new String[] {
-                    "D",
-                    "L",
-                    "M",
-                    "M",
-                    "J",
-                    "V",
-                    "S",
-                }
-            },
-            { "islamic-civil.DateFormatItem.H", metaValue_DateFormatItem_H },
-            { "generic.DateTimePatterns",
-                new String[] {
-                    "{1}, {0}",
-                    "{1}, {0}",
-                    "{1} {0}",
-                    "{1} {0}",
-                }
-            },
-            { "TimePatterns", metaValue_generic_TimePatterns },
-            { "japanese.DateFormatItem.GyMMMd", metaValue_generic_DateFormatItem_yyyyMMMd },
             { "islamic.DayNarrows", metaValue_generic_DayNarrows },
-            { "DateFormatItem.yMEd", metaValue_generic_DateFormatItem_yMEd },
-            { "java.time.roc.Eras", metaValue_java_time_roc_long_Eras },
-            { "generic.DayNarrows", metaValue_generic_DayNarrows },
-            { "roc.DateFormatItem.yQQQ", metaValue_generic_DateFormatItem_yQQQ },
-            { "islamic-umalqura.DateFormatItem.Hmsvvvv", metaValue_generic_DateFormatItem_Hmsvvvv },
-            { "islamic.DateFormatItem.EHm", metaValue_generic_DateFormatItem_EHm },
-            { "roc.narrow.Eras", metaValue_java_time_roc_long_Eras },
-            { "buddhist.DateFormatItem.EHms", metaValue_generic_DateFormatItem_EHms },
-            { "japanese.DateFormatItem.yMMMEd", metaValue_generic_DateFormatItem_yMMMEd },
-            { "buddhist.DateFormatItem.yMEd", metaValue_generic_DateFormatItem_yMEd },
-            { "DateFormatItem.GyMMMd", metaValue_generic_DateFormatItem_yyyyMMMd },
-            { "DateFormatItem.Hms", metaValue_DateFormatItem_Hms },
-            { "DateFormatItem.Hmv", metaValue_generic_DateFormatItem_Hmv },
-            { "DateFormatItem.yMMMEd", metaValue_generic_DateFormatItem_yMMMEd },
-            { "islamic-civil.DateFormatItem.Hmv", metaValue_generic_DateFormatItem_Hmv },
             { "islamic.QuarterNames", metaValue_generic_QuarterNames },
-            { "generic.DateFormatItem.yyyyMMMd", metaValue_generic_DateFormatItem_yyyyMMMd },
-            { "islamic-civil.DateFormatItem.Hms", metaValue_DateFormatItem_Hms },
-            { "islamic-civil.DateFormatItem.Hmsvvvv", metaValue_generic_DateFormatItem_Hmsvvvv },
-            { "islamic.DateFormatItem.yMMMEd", metaValue_generic_DateFormatItem_yMMMEd },
-            { "islamic-umalqura.DateFormatItem.GyMMMd", metaValue_generic_DateFormatItem_yyyyMMMd },
-            { "japanese.DateFormatItem.yMEd", metaValue_generic_DateFormatItem_yMEd },
+            { "islamic.TimePatterns", metaValue_generic_TimePatterns },
             { "java.time.islamic.DatePatterns", metaValue_java_time_generic_DatePatterns },
-            { "islamic.DateFormatItem.Hmv", metaValue_generic_DateFormatItem_Hmv },
-            { "generic.DateFormatItem.GyMMMEd", "E, d 'de' MMM 'de' y G" },
-            { "DateFormatItem.EHms", metaValue_generic_DateFormatItem_EHms },
-            { "islamic-civil.DateFormatItem.EHms", metaValue_generic_DateFormatItem_EHms },
-            { "japanese.QuarterNames", metaValue_generic_QuarterNames },
-            { "generic.DateFormatItem.yQQQ", metaValue_generic_DateFormatItem_yQQQ },
-            { "islamic-umalqura.DateFormatItem.Hms", metaValue_DateFormatItem_Hms },
-            { "generic.DateFormatItem.MMMd", "d 'de' MMM" },
-            { "islamic-umalqura.DateFormatItem.Hmv", metaValue_generic_DateFormatItem_Hmv },
+            { "islamic.DatePatterns", metaValue_generic_DatePatterns },
+            { "islamic.DateFormatItem.yMMMEd", metaValue_generic_DateFormatItem_yMMMEd },
+            { "islamic.DateFormatItem.yMEd", metaValue_generic_DateFormatItem_yMEd },
             { "islamic.DateFormatItem.MMMdd", metaValue_generic_DateFormatItem_MMMdd },
-            { "generic.DateFormatItem.yyyyMMM", metaValue_generic_DateFormatItem_yyyyMMM },
+            { "islamic.DateFormatItem.GyMMMd", metaValue_generic_DateFormatItem_yyyyMMMd },
+            { "islamic.DateFormatItem.yQQQ", metaValue_generic_DateFormatItem_yQQQ },
+            { "islamic.DateFormatItem.Hmsvvvv", metaValue_generic_DateFormatItem_Hmsvvvv },
+            { "islamic.DateFormatItem.Hm", metaValue_DateFormatItem_Hm },
+            { "islamic.DateFormatItem.EHms", metaValue_generic_DateFormatItem_EHms },
+            { "islamic.DateFormatItem.EHm", metaValue_generic_DateFormatItem_EHm },
+            { "islamic.DateFormatItem.H", metaValue_DateFormatItem_H },
+            { "islamic.DateFormatItem.Hmsv", metaValue_generic_DateFormatItem_Hmsv },
+            { "islamic.DateFormatItem.Hms", metaValue_DateFormatItem_Hms },
+            { "islamic.DateFormatItem.Hmv", metaValue_generic_DateFormatItem_Hmv },
+            { "islamic-civil.DateFormatItem.yMMMEd", metaValue_generic_DateFormatItem_yMMMEd },
+            { "islamic-civil.DateFormatItem.yMEd", metaValue_generic_DateFormatItem_yMEd },
+            { "islamic-civil.DateFormatItem.MMMdd", metaValue_generic_DateFormatItem_MMMdd },
+            { "islamic-civil.DateFormatItem.GyMMMd", metaValue_generic_DateFormatItem_yyyyMMMd },
+            { "islamic-civil.DateFormatItem.yQQQ", metaValue_generic_DateFormatItem_yQQQ },
+            { "islamic-civil.DateFormatItem.Hmsvvvv", metaValue_generic_DateFormatItem_Hmsvvvv },
+            { "islamic-civil.DateFormatItem.Hm", metaValue_DateFormatItem_Hm },
+            { "islamic-civil.DateFormatItem.EHms", metaValue_generic_DateFormatItem_EHms },
+            { "islamic-civil.DateFormatItem.EHm", metaValue_generic_DateFormatItem_EHm },
+            { "islamic-civil.DateFormatItem.H", metaValue_DateFormatItem_H },
+            { "islamic-civil.DateFormatItem.Hmsv", metaValue_generic_DateFormatItem_Hmsv },
+            { "islamic-civil.DateFormatItem.Hms", metaValue_DateFormatItem_Hms },
+            { "islamic-civil.DateFormatItem.Hmv", metaValue_generic_DateFormatItem_Hmv },
+            { "islamic-umalqura.DateFormatItem.yMMMEd", metaValue_generic_DateFormatItem_yMMMEd },
+            { "islamic-umalqura.DateFormatItem.yMEd", metaValue_generic_DateFormatItem_yMEd },
+            { "islamic-umalqura.DateFormatItem.MMMdd", metaValue_generic_DateFormatItem_MMMdd },
+            { "islamic-umalqura.DateFormatItem.GyMMMd", metaValue_generic_DateFormatItem_yyyyMMMd },
+            { "islamic-umalqura.DateFormatItem.yQQQ", metaValue_generic_DateFormatItem_yQQQ },
+            { "islamic-umalqura.DateFormatItem.Hmsvvvv", metaValue_generic_DateFormatItem_Hmsvvvv },
+            { "islamic-umalqura.DateFormatItem.Hm", metaValue_DateFormatItem_Hm },
+            { "islamic-umalqura.DateFormatItem.EHms", metaValue_generic_DateFormatItem_EHms },
+            { "islamic-umalqura.DateFormatItem.EHm", metaValue_generic_DateFormatItem_EHm },
+            { "islamic-umalqura.DateFormatItem.H", metaValue_DateFormatItem_H },
             { "islamic-umalqura.DateFormatItem.Hmsv", metaValue_generic_DateFormatItem_Hmsv },
-            { "generic.DateFormatItem.yMMMEd", metaValue_generic_DateFormatItem_yMMMEd },
-            { "generic.DateFormatItem.GyMMMd", metaValue_generic_DateFormatItem_yyyyMMMd },
-            { "buddhist.DateFormatItem.Hm", metaValue_DateFormatItem_Hm },
-            { "generic.DateFormatItem.yyyyMMMEd", "EEE, d 'de' MMM 'de' y G" },
-            { "DateFormatItem.EHm", metaValue_generic_DateFormatItem_EHm },
-            { "buddhist.DatePatterns", metaValue_generic_DatePatterns },
-            { "generic.DateFormatItem.Hmsv", metaValue_generic_DateFormatItem_Hmsv },
-            { "japanese.DateFormatItem.yQQQ", metaValue_generic_DateFormatItem_yQQQ },
-            { "japanese.DateFormatItem.EHm", metaValue_generic_DateFormatItem_EHm },
-            { "buddhist.DateFormatItem.Hmsv", metaValue_generic_DateFormatItem_Hmsv },
-            { "roc.DateFormatItem.Hms", metaValue_DateFormatItem_Hms },
-            { "roc.DateFormatItem.Hmv", metaValue_generic_DateFormatItem_Hmv },
-            { "buddhist.QuarterNames", metaValue_generic_QuarterNames },
-            { "generic.DateFormatItem.GyMMM", metaValue_generic_DateFormatItem_yyyyMMM },
-            { "roc.DayNarrows", metaValue_generic_DayNarrows },
-            { "generic.DateFormatItem.Hmsvvvv", metaValue_generic_DateFormatItem_Hmsvvvv },
-            { "roc.DateFormatItem.EHm", metaValue_generic_DateFormatItem_EHm },
-            { "buddhist.DateFormatItem.H", metaValue_DateFormatItem_H },
-            { "generic.DateFormatItem.yyyyMEd", "E d/M/y GGGGG" },
-            { "generic.QuarterNames", metaValue_generic_QuarterNames },
-            { "java.time.buddhist.DatePatterns", metaValue_java_time_generic_DatePatterns },
-            { "java.time.roc.DatePatterns", metaValue_java_time_generic_DatePatterns },
+            { "islamic-umalqura.DateFormatItem.Hms", metaValue_DateFormatItem_Hms },
+            { "islamic-umalqura.DateFormatItem.Hmv", metaValue_generic_DateFormatItem_Hmv },
+            { "latn.NumberElements",
+                new String[] {
+                    ".",
+                    ",",
+                    ";",
+                    "%",
+                    "0",
+                    "#",
+                    "-",
+                    "E",
+                    "\u2030",
+                    "\u221e",
+                    "NaN",
+                    "",
+                    "",
+                }
+            },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "\u00a4#,##0.00",
+                    "#,##0\u00a0%",
+                    "\u00a4#,##0.00",
+                }
+            },
             { "short.CompactNumberPatterns",
                 new String[] {
                     "",
@@ -347,57 +377,25 @@ public class FormatData_es_419 extends ListResourceBundle {
                     "{one:000\u00a0B other:000\u00a0B}",
                 }
             },
-            { "islamic.DateFormatItem.yMEd", metaValue_generic_DateFormatItem_yMEd },
-            { "timezone.regionFormat.daylight", "hora de verano de {0}" },
-            { "DatePatterns",
+            { "long.CompactNumberPatterns",
                 new String[] {
-                    "EEEE, d 'de' MMMM 'de' y",
-                    "d 'de' MMMM 'de' y",
-                    "d MMM y",
-                    "d/M/yy",
-                }
-            },
-            { "generic.DateFormatItem.MMMdd", metaValue_generic_DateFormatItem_MMMdd },
-            { "islamic.TimePatterns", metaValue_generic_TimePatterns },
-            { "buddhist.DateFormatItem.Hms", metaValue_DateFormatItem_Hms },
-            { "japanese.DateFormatItem.Hm", metaValue_DateFormatItem_Hm },
-            { "buddhist.DateFormatItem.yMMMEd", metaValue_generic_DateFormatItem_yMMMEd },
-            { "islamic-civil.DateFormatItem.Hmsv", metaValue_generic_DateFormatItem_Hmsv },
-            { "islamic.MonthAbbreviations",
-                new String[] {
-                    "Muh.",
-                    "Saf.",
-                    "Rab. I",
-                    "Rab. II",
-                    "Jum. I",
-                    "Jum. II",
-                    "Raj.",
-                    "Sha.",
-                    "Ram.",
-                    "Shaw.",
-                    "Dhu\u02bbl-Q.",
-                    "Dhu\u02bbl-H.",
                     "",
+                    "",
+                    "",
+                    "{one:0' 'mil other:0' 'mil}",
+                    "{one:00' 'mil other:00' 'mil}",
+                    "{one:000' 'mil other:000' 'mil}",
+                    "{one:0' 'mill\u00f3n other:0' 'millones}",
+                    "{one:00' 'millones other:00' 'millones}",
+                    "{one:000' 'millones other:000' 'millones}",
+                    "{one:0' 'mil' 'millones other:0' 'mil' 'millones}",
+                    "{one:00' 'mil' 'millones other:00' 'mil' 'millones}",
+                    "{one:000' 'mil' 'millones other:000' 'mil' 'millones}",
+                    "{other:0' 'bill\u00f3n}",
+                    "{other:00' 'billones}",
+                    "{other:000' 'billones}",
                 }
             },
-            { "buddhist.DateFormatItem.Hmv", metaValue_generic_DateFormatItem_Hmv },
-            { "islamic-umalqura.DateFormatItem.yQQQ", metaValue_generic_DateFormatItem_yQQQ },
-            { "roc.DateFormatItem.MMMdd", metaValue_generic_DateFormatItem_MMMdd },
-            { "latn.NumberPatterns",
-                new String[] {
-                    "#,##0.###",
-                    "\u00a4#,##0.00",
-                    "#,##0\u00a0%",
-                    "\u00a4#,##0.00",
-                }
-            },
-            { "buddhist.DayNarrows", metaValue_generic_DayNarrows },
-            { "islamic-umalqura.DateFormatItem.yMMMEd", metaValue_generic_DateFormatItem_yMMMEd },
-            { "japanese.DayNarrows", metaValue_generic_DayNarrows },
-            { "QuarterNames", metaValue_generic_QuarterNames },
-            { "roc.TimePatterns", metaValue_generic_TimePatterns },
-            { "QuarterAbbreviations", metaValue_generic_QuarterNames },
-            { "buddhist.DateFormatItem.yQQQ", metaValue_generic_DateFormatItem_yQQQ },
         };
         return data;
     }
