@@ -66,18 +66,9 @@ import java.util.ListResourceBundle;
 public class FormatData_es_CO extends ListResourceBundle {
     @Override
     protected final Object[][] getContents() {
-        final String[] metaValue_generic_DayNarrows = new String[] {
-            "D",
-            "L",
-            "M",
-            "M",
-            "J",
-            "V",
-            "S",
-        };
         final String[] metaValue_generic_narrow_AmPmMarkers = new String[] {
-            "a.\u00a0m.",
-            "p.\u00a0m.",
+            "a.\u202fm.",
+            "p.\u202fm.",
             "",
             "m.",
             "de la madrugada",
@@ -90,22 +81,10 @@ public class FormatData_es_CO extends ListResourceBundle {
             "",
         };
         final String[] metaValue_generic_TimePatterns = new String[] {
-            "h:mm:ss a zzzz",
-            "h:mm:ss a z",
-            "h:mm:ss a",
-            "h:mm a",
-        };
-        final String[] metaValue_java_time_generic_DatePatterns = new String[] {
-            "EEEE, d 'de' MMMM 'de' y G",
-            "d 'de' MMMM 'de' y G",
-            "d/MM/y G",
-            "d/MM/yy GGGGG",
-        };
-        final String[] metaValue_generic_DatePatterns = new String[] {
-            "EEEE, d 'de' MMMM 'de' y GGGG",
-            "d 'de' MMMM 'de' y GGGG",
-            "d/MM/y GGGG",
-            "d/MM/yy G",
+            "h:mm:ss\u202fa zzzz",
+            "h:mm:ss\u202fa z",
+            "h:mm:ss\u202fa",
+            "h:mm\u202fa",
         };
         final String[] metaValue_generic_DateTimePatterns = new String[] {
             "{1}, {0}",
@@ -123,6 +102,18 @@ public class FormatData_es_CO extends ListResourceBundle {
         final String metaValue_generic_DateFormatItem_Hms = "H:mm:ss";
         final String metaValue_DateFormatItem_MMMEd = "E, d 'de' MMM";
         final String metaValue_DateFormatItem_GyMMM = "MMM 'de' y G";
+        final String[] metaValue_java_time_generic_DatePatterns = new String[] {
+            "EEEE, d 'de' MMMM 'de' y G",
+            "d 'de' MMMM 'de' y G",
+            "d/MM/y G",
+            "d/MM/yy GGGGG",
+        };
+        final String[] metaValue_generic_DatePatterns = new String[] {
+            "EEEE, d 'de' MMMM 'de' y GGGG",
+            "d 'de' MMMM 'de' y GGGG",
+            "d/MM/y GGGG",
+            "d/MM/yy G",
+        };
         final String[] metaValue_java_time_buddhist_DatePatterns = new String[] {
             "",
             "",
@@ -136,87 +127,20 @@ public class FormatData_es_CO extends ListResourceBundle {
             "d/MM/yy G",
         };
         final Object[][] data = new Object[][] {
-            { "generic.DatePatterns", metaValue_generic_DatePatterns },
-            { "islamic.DateFormatItem.MMMEd", metaValue_DateFormatItem_MMMEd },
-            { "japanese.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
-            { "AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
-            { "java.time.japanese.DatePatterns", metaValue_java_time_generic_DatePatterns },
-            { "buddhist.DateFormatItem.yMMMd", metaValue_generic_DateFormatItem_yMMMd },
-            { "islamic.DateFormatItem.GyMMMEd", metaValue_generic_DateFormatItem_GyMMMEd },
-            { "roc.DateFormatItem.yMMM", metaValue_generic_DateFormatItem_yMMM },
-            { "japanese.DateFormatItem.Hms", metaValue_generic_DateFormatItem_Hms },
-            { "islamic-umalqura.DateFormatItem.yMEd", metaValue_generic_DateFormatItem_yMEd },
-            { "islamic-civil.DateFormatItem.GyMMM", metaValue_DateFormatItem_GyMMM },
-            { "japanese.TimePatterns", metaValue_generic_TimePatterns },
-            { "japanese.DateFormatItem.H", metaValue_generic_DateFormatItem_H },
-            { "abbreviated.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
-            { "japanese.abbreviated.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
-            { "generic.DateFormatItem.yMEd", metaValue_generic_DateFormatItem_yMEd },
-            { "buddhist.DateFormatItem.MMMdd", metaValue_generic_DateFormatItem_MMMdd },
-            { "islamic-civil.DateFormatItem.GyMMMEd", metaValue_generic_DateFormatItem_GyMMMEd },
-            { "japanese.DateFormatItem.MMMd", metaValue_generic_DateFormatItem_MMMdd },
-            { "DateFormatItem.Hm", metaValue_generic_DateFormatItem_Hm },
-            { "islamic-umalqura.DateFormatItem.MMMEd", metaValue_DateFormatItem_MMMEd },
-            { "islamic-umalqura.DateFormatItem.H", metaValue_generic_DateFormatItem_H },
-            { "roc.DateFormatItem.GyMMM", metaValue_DateFormatItem_GyMMM },
-            { "islamic-umalqura.DateFormatItem.Hm", metaValue_generic_DateFormatItem_Hm },
-            { "islamic.DateFormatItem.H", metaValue_generic_DateFormatItem_H },
-            { "japanese.DateFormatItem.MMMEd", metaValue_DateFormatItem_MMMEd },
-            { "DateTimePatterns", metaValue_generic_DateTimePatterns },
-            { "islamic-umalqura.DateFormatItem.GyMMMEd", metaValue_generic_DateFormatItem_GyMMMEd },
-            { "narrow.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
-            { "generic.DateFormatItem.Hms", metaValue_generic_DateFormatItem_Hms },
-            { "latn.NumberElements",
-                new String[] {
-                    ",",
-                    ".",
-                    ";",
-                    "%",
-                    "0",
-                    "#",
-                    "-",
-                    "E",
-                    "\u2030",
-                    "\u221e",
-                    "NaN",
-                    "",
-                    "",
-                }
-            },
-            { "japanese.DatePatterns", metaValue_generic_DatePatterns },
-            { "roc.DateFormatItem.yMEd", metaValue_generic_DateFormatItem_yMEd },
-            { "generic.DateFormatItem.Hm", metaValue_generic_DateFormatItem_Hm },
-            { "islamic-umalqura.DateFormatItem.yMMMd", metaValue_generic_DateFormatItem_yMMMd },
-            { "DateFormatItem.MMMEd", metaValue_DateFormatItem_MMMEd },
-            { "buddhist.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
-            { "generic.DateFormatItem.yMMM", metaValue_generic_DateFormatItem_yMMM },
-            { "roc.DateFormatItem.MMMd", metaValue_generic_DateFormatItem_MMMdd },
-            { "buddhist.DateFormatItem.MMMEd", metaValue_DateFormatItem_MMMEd },
-            { "islamic-civil.DateFormatItem.MMMdd", metaValue_generic_DateFormatItem_MMMdd },
-            { "roc.DateFormatItem.H", metaValue_generic_DateFormatItem_H },
-            { "japanese.DateFormatItem.yMMM", metaValue_generic_DateFormatItem_yMMM },
-            { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
+            { "generic.narrow.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
             { "generic.abbreviated.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
-            { "islamic.DateFormatItem.Hms", metaValue_generic_DateFormatItem_Hms },
-            { "islamic-civil.DateFormatItem.Hm", metaValue_generic_DateFormatItem_Hm },
-            { "DayNarrows", metaValue_generic_DayNarrows },
-            { "islamic.DateFormatItem.Hm", metaValue_generic_DateFormatItem_Hm },
-            { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
-            { "DateFormatItem.MMMd", metaValue_generic_DateFormatItem_MMMdd },
-            { "japanese.DateFormatItem.yMMMd", metaValue_generic_DateFormatItem_yMMMd },
-            { "DayPeriodRules", "noon:12:00;night1:20:00-24:00;morning2:00:00-12:00;evening1:12:00-20:00" },
-            { "islamic-umalqura.DateFormatItem.MMMdd", metaValue_generic_DateFormatItem_MMMdd },
-            { "japanese.DateFormatItem.MMMdd", metaValue_generic_DateFormatItem_MMMdd },
-            { "DateFormatItem.GyMMMEd", metaValue_generic_DateFormatItem_GyMMMEd },
-            { "java.time.generic.DatePatterns", metaValue_java_time_generic_DatePatterns },
             { "generic.TimePatterns", metaValue_generic_TimePatterns },
-            { "roc.DateFormatItem.Hm", metaValue_generic_DateFormatItem_Hm },
-            { "buddhist.DateFormatItem.GyMMM", metaValue_DateFormatItem_GyMMM },
-            { "islamic-umalqura.DateFormatItem.yMMM", metaValue_generic_DateFormatItem_yMMM },
-            { "buddhist.TimePatterns", metaValue_generic_TimePatterns },
-            { "islamic-civil.DateFormatItem.yMEd", metaValue_generic_DateFormatItem_yMEd },
-            { "DateFormatItem.MMMdd", metaValue_generic_DateFormatItem_MMMdd },
-            { "buddhist.DateFormatItem.yMMM", metaValue_generic_DateFormatItem_yMMM },
+            { "java.time.generic.DatePatterns", metaValue_java_time_generic_DatePatterns },
+            { "generic.DatePatterns", metaValue_generic_DatePatterns },
+            { "generic.DateTimePatterns", metaValue_generic_DateTimePatterns },
+            { "generic.DateFormatItem.yMEd", metaValue_generic_DateFormatItem_yMEd },
+            { "generic.DateFormatItem.MMMdd", metaValue_generic_DateFormatItem_MMMdd },
+            { "generic.DateFormatItem.yMMMd", metaValue_generic_DateFormatItem_yMMMd },
+            { "generic.DateFormatItem.Hm", metaValue_generic_DateFormatItem_Hm },
+            { "generic.DateFormatItem.yMMM", metaValue_generic_DateFormatItem_yMMM },
+            { "generic.DateFormatItem.H", metaValue_generic_DateFormatItem_H },
+            { "generic.DateFormatItem.GyMMMEd", metaValue_generic_DateFormatItem_GyMMMEd },
+            { "generic.DateFormatItem.Hms", metaValue_generic_DateFormatItem_Hms },
             { "standalone.MonthAbbreviations",
                 new String[] {
                     "ene.",
@@ -234,9 +158,6 @@ public class FormatData_es_CO extends ListResourceBundle {
                     "",
                 }
             },
-            { "islamic.DateFormatItem.MMMd", metaValue_generic_DateFormatItem_MMMdd },
-            { "generic.DateFormatItem.H", metaValue_generic_DateFormatItem_H },
-            { "DateFormatItem.H", metaValue_generic_DateFormatItem_H },
             { "standalone.DayNarrows",
                 new String[] {
                     "d",
@@ -248,50 +169,11 @@ public class FormatData_es_CO extends ListResourceBundle {
                     "s",
                 }
             },
-            { "islamic-civil.DateFormatItem.H", metaValue_generic_DateFormatItem_H },
-            { "generic.DateTimePatterns", metaValue_generic_DateTimePatterns },
-            { "roc.DateFormatItem.GyMMMEd", metaValue_generic_DateFormatItem_GyMMMEd },
-            { "islamic-civil.DateFormatItem.MMMEd", metaValue_DateFormatItem_MMMEd },
+            { "AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
+            { "narrow.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
+            { "abbreviated.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
+            { "field.dayperiod", "a.\u00a0m./p.\u00a0m." },
             { "TimePatterns", metaValue_generic_TimePatterns },
-            { "islamic.DayNarrows", metaValue_generic_DayNarrows },
-            { "DateFormatItem.yMEd", metaValue_generic_DateFormatItem_yMEd },
-            { "roc.DateFormatItem.yMMMd", metaValue_generic_DateFormatItem_yMMMd },
-            { "islamic-umalqura.DateFormatItem.GyMMM", metaValue_DateFormatItem_GyMMM },
-            { "generic.DayNarrows", metaValue_generic_DayNarrows },
-            { "islamic-civil.DateFormatItem.yMMM", metaValue_generic_DateFormatItem_yMMM },
-            { "buddhist.DateFormatItem.yMEd", metaValue_generic_DateFormatItem_yMEd },
-            { "buddhist.narrow.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
-            { "islamic.DateFormatItem.GyMMM", metaValue_DateFormatItem_GyMMM },
-            { "DateFormatItem.Hms", metaValue_generic_DateFormatItem_Hms },
-            { "buddhist.abbreviated.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
-            { "DateFormatItem.GyMMM", metaValue_DateFormatItem_GyMMM },
-            { "islamic.abbreviated.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
-            { "islamic-civil.DateFormatItem.Hms", metaValue_generic_DateFormatItem_Hms },
-            { "japanese.DateFormatItem.yMEd", metaValue_generic_DateFormatItem_yMEd },
-            { "java.time.islamic.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
-            { "generic.DateFormatItem.GyMMMEd", metaValue_generic_DateFormatItem_GyMMMEd },
-            { "DateFormatItem.yMMMd", metaValue_generic_DateFormatItem_yMMMd },
-            { "roc.DateFormatItem.MMMEd", metaValue_DateFormatItem_MMMEd },
-            { "generic.DateFormatItem.yMMMd", metaValue_generic_DateFormatItem_yMMMd },
-            { "japanese.DateFormatItem.GyMMM", metaValue_DateFormatItem_GyMMM },
-            { "buddhist.DateFormatItem.MMMd", metaValue_generic_DateFormatItem_MMMdd },
-            { "islamic-umalqura.DateFormatItem.Hms", metaValue_generic_DateFormatItem_Hms },
-            { "islamic.DateFormatItem.yMMMd", metaValue_generic_DateFormatItem_yMMMd },
-            { "islamic.DateFormatItem.MMMdd", metaValue_generic_DateFormatItem_MMMdd },
-            { "islamic-civil.DateFormatItem.MMMd", metaValue_generic_DateFormatItem_MMMdd },
-            { "islamic-civil.DateFormatItem.yMMMd", metaValue_generic_DateFormatItem_yMMMd },
-            { "buddhist.DateFormatItem.Hm", metaValue_generic_DateFormatItem_Hm },
-            { "islamic.DateFormatItem.yMMM", metaValue_generic_DateFormatItem_yMMM },
-            { "japanese.DateFormatItem.GyMMMEd", metaValue_generic_DateFormatItem_GyMMMEd },
-            { "buddhist.DatePatterns", metaValue_buddhist_DatePatterns },
-            { "islamic-umalqura.DateFormatItem.MMMd", metaValue_generic_DateFormatItem_MMMdd },
-            { "roc.DateFormatItem.Hms", metaValue_generic_DateFormatItem_Hms },
-            { "roc.DayNarrows", metaValue_generic_DayNarrows },
-            { "buddhist.DateFormatItem.H", metaValue_generic_DateFormatItem_H },
-            { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
-            { "java.time.buddhist.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
-            { "buddhist.DateFormatItem.GyMMMEd", metaValue_generic_DateFormatItem_GyMMMEd },
-            { "islamic.DateFormatItem.yMEd", metaValue_generic_DateFormatItem_yMEd },
             { "DatePatterns",
                 new String[] {
                     "EEEE, d 'de' MMMM 'de' y",
@@ -300,13 +182,121 @@ public class FormatData_es_CO extends ListResourceBundle {
                     "d/MM/yy",
                 }
             },
-            { "generic.DateFormatItem.MMMdd", metaValue_generic_DateFormatItem_MMMdd },
-            { "islamic.TimePatterns", metaValue_generic_TimePatterns },
+            { "DateTimePatterns", metaValue_generic_DateTimePatterns },
+            { "DayPeriodRules", "noon:12:00;night1:20:00-24:00;morning2:00:00-12:00;evening1:12:00-20:00" },
+            { "DateFormatItem.yMEd", metaValue_generic_DateFormatItem_yMEd },
+            { "DateFormatItem.MMMdd", metaValue_generic_DateFormatItem_MMMdd },
+            { "DateFormatItem.yMMMd", metaValue_generic_DateFormatItem_yMMMd },
+            { "DateFormatItem.Hm", metaValue_generic_DateFormatItem_Hm },
             { "DateFormatItem.yMMM", metaValue_generic_DateFormatItem_yMMM },
-            { "generic.narrow.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
+            { "DateFormatItem.H", metaValue_generic_DateFormatItem_H },
+            { "DateFormatItem.MMMEd", metaValue_DateFormatItem_MMMEd },
+            { "DateFormatItem.GyMMMEd", metaValue_generic_DateFormatItem_GyMMMEd },
+            { "DateFormatItem.Hms", metaValue_generic_DateFormatItem_Hms },
+            { "DateFormatItem.MMMd", metaValue_generic_DateFormatItem_MMMdd },
+            { "DateFormatItem.GyMMM", metaValue_DateFormatItem_GyMMM },
+            { "buddhist.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
+            { "buddhist.narrow.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
+            { "buddhist.abbreviated.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
+            { "buddhist.TimePatterns", metaValue_generic_TimePatterns },
+            { "java.time.buddhist.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
+            { "buddhist.DatePatterns", metaValue_buddhist_DatePatterns },
+            { "buddhist.DateFormatItem.yMEd", metaValue_generic_DateFormatItem_yMEd },
+            { "buddhist.DateFormatItem.MMMdd", metaValue_generic_DateFormatItem_MMMdd },
+            { "buddhist.DateFormatItem.yMMMd", metaValue_generic_DateFormatItem_yMMMd },
+            { "buddhist.DateFormatItem.Hm", metaValue_generic_DateFormatItem_Hm },
+            { "buddhist.DateFormatItem.yMMM", metaValue_generic_DateFormatItem_yMMM },
+            { "buddhist.DateFormatItem.H", metaValue_generic_DateFormatItem_H },
+            { "buddhist.DateFormatItem.MMMEd", metaValue_DateFormatItem_MMMEd },
+            { "buddhist.DateFormatItem.GyMMMEd", metaValue_generic_DateFormatItem_GyMMMEd },
             { "buddhist.DateFormatItem.Hms", metaValue_generic_DateFormatItem_Hms },
+            { "buddhist.DateFormatItem.MMMd", metaValue_generic_DateFormatItem_MMMdd },
+            { "buddhist.DateFormatItem.GyMMM", metaValue_DateFormatItem_GyMMM },
+            { "japanese.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
+            { "japanese.abbreviated.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
+            { "japanese.TimePatterns", metaValue_generic_TimePatterns },
+            { "java.time.japanese.DatePatterns", metaValue_java_time_generic_DatePatterns },
+            { "japanese.DatePatterns", metaValue_generic_DatePatterns },
+            { "japanese.DateFormatItem.yMEd", metaValue_generic_DateFormatItem_yMEd },
+            { "japanese.DateFormatItem.MMMdd", metaValue_generic_DateFormatItem_MMMdd },
+            { "japanese.DateFormatItem.yMMMd", metaValue_generic_DateFormatItem_yMMMd },
             { "japanese.DateFormatItem.Hm", metaValue_generic_DateFormatItem_Hm },
+            { "japanese.DateFormatItem.yMMM", metaValue_generic_DateFormatItem_yMMM },
+            { "japanese.DateFormatItem.H", metaValue_generic_DateFormatItem_H },
+            { "japanese.DateFormatItem.MMMEd", metaValue_DateFormatItem_MMMEd },
+            { "japanese.DateFormatItem.GyMMMEd", metaValue_generic_DateFormatItem_GyMMMEd },
+            { "japanese.DateFormatItem.Hms", metaValue_generic_DateFormatItem_Hms },
+            { "japanese.DateFormatItem.MMMd", metaValue_generic_DateFormatItem_MMMdd },
+            { "japanese.DateFormatItem.GyMMM", metaValue_DateFormatItem_GyMMM },
+            { "roc.abbreviated.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
+            { "roc.TimePatterns", metaValue_generic_TimePatterns },
+            { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
+            { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
+            { "roc.DateFormatItem.yMEd", metaValue_generic_DateFormatItem_yMEd },
             { "roc.DateFormatItem.MMMdd", metaValue_generic_DateFormatItem_MMMdd },
+            { "roc.DateFormatItem.yMMMd", metaValue_generic_DateFormatItem_yMMMd },
+            { "roc.DateFormatItem.Hm", metaValue_generic_DateFormatItem_Hm },
+            { "roc.DateFormatItem.yMMM", metaValue_generic_DateFormatItem_yMMM },
+            { "roc.DateFormatItem.H", metaValue_generic_DateFormatItem_H },
+            { "roc.DateFormatItem.MMMEd", metaValue_DateFormatItem_MMMEd },
+            { "roc.DateFormatItem.GyMMMEd", metaValue_generic_DateFormatItem_GyMMMEd },
+            { "roc.DateFormatItem.Hms", metaValue_generic_DateFormatItem_Hms },
+            { "roc.DateFormatItem.MMMd", metaValue_generic_DateFormatItem_MMMdd },
+            { "roc.DateFormatItem.GyMMM", metaValue_DateFormatItem_GyMMM },
+            { "islamic.abbreviated.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
+            { "islamic.TimePatterns", metaValue_generic_TimePatterns },
+            { "java.time.islamic.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
+            { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
+            { "islamic.DateFormatItem.yMEd", metaValue_generic_DateFormatItem_yMEd },
+            { "islamic.DateFormatItem.MMMdd", metaValue_generic_DateFormatItem_MMMdd },
+            { "islamic.DateFormatItem.yMMMd", metaValue_generic_DateFormatItem_yMMMd },
+            { "islamic.DateFormatItem.Hm", metaValue_generic_DateFormatItem_Hm },
+            { "islamic.DateFormatItem.yMMM", metaValue_generic_DateFormatItem_yMMM },
+            { "islamic.DateFormatItem.H", metaValue_generic_DateFormatItem_H },
+            { "islamic.DateFormatItem.MMMEd", metaValue_DateFormatItem_MMMEd },
+            { "islamic.DateFormatItem.GyMMMEd", metaValue_generic_DateFormatItem_GyMMMEd },
+            { "islamic.DateFormatItem.Hms", metaValue_generic_DateFormatItem_Hms },
+            { "islamic.DateFormatItem.MMMd", metaValue_generic_DateFormatItem_MMMdd },
+            { "islamic.DateFormatItem.GyMMM", metaValue_DateFormatItem_GyMMM },
+            { "islamic-civil.DateFormatItem.yMEd", metaValue_generic_DateFormatItem_yMEd },
+            { "islamic-civil.DateFormatItem.MMMdd", metaValue_generic_DateFormatItem_MMMdd },
+            { "islamic-civil.DateFormatItem.yMMMd", metaValue_generic_DateFormatItem_yMMMd },
+            { "islamic-civil.DateFormatItem.Hm", metaValue_generic_DateFormatItem_Hm },
+            { "islamic-civil.DateFormatItem.yMMM", metaValue_generic_DateFormatItem_yMMM },
+            { "islamic-civil.DateFormatItem.H", metaValue_generic_DateFormatItem_H },
+            { "islamic-civil.DateFormatItem.MMMEd", metaValue_DateFormatItem_MMMEd },
+            { "islamic-civil.DateFormatItem.GyMMMEd", metaValue_generic_DateFormatItem_GyMMMEd },
+            { "islamic-civil.DateFormatItem.Hms", metaValue_generic_DateFormatItem_Hms },
+            { "islamic-civil.DateFormatItem.MMMd", metaValue_generic_DateFormatItem_MMMdd },
+            { "islamic-civil.DateFormatItem.GyMMM", metaValue_DateFormatItem_GyMMM },
+            { "islamic-umalqura.DateFormatItem.yMEd", metaValue_generic_DateFormatItem_yMEd },
+            { "islamic-umalqura.DateFormatItem.MMMdd", metaValue_generic_DateFormatItem_MMMdd },
+            { "islamic-umalqura.DateFormatItem.yMMMd", metaValue_generic_DateFormatItem_yMMMd },
+            { "islamic-umalqura.DateFormatItem.Hm", metaValue_generic_DateFormatItem_Hm },
+            { "islamic-umalqura.DateFormatItem.yMMM", metaValue_generic_DateFormatItem_yMMM },
+            { "islamic-umalqura.DateFormatItem.H", metaValue_generic_DateFormatItem_H },
+            { "islamic-umalqura.DateFormatItem.MMMEd", metaValue_DateFormatItem_MMMEd },
+            { "islamic-umalqura.DateFormatItem.GyMMMEd", metaValue_generic_DateFormatItem_GyMMMEd },
+            { "islamic-umalqura.DateFormatItem.Hms", metaValue_generic_DateFormatItem_Hms },
+            { "islamic-umalqura.DateFormatItem.MMMd", metaValue_generic_DateFormatItem_MMMdd },
+            { "islamic-umalqura.DateFormatItem.GyMMM", metaValue_DateFormatItem_GyMMM },
+            { "latn.NumberElements",
+                new String[] {
+                    ",",
+                    ".",
+                    ";",
+                    "%",
+                    "0",
+                    "#",
+                    "-",
+                    "E",
+                    "\u2030",
+                    "\u221e",
+                    "NaN",
+                    "",
+                    "",
+                }
+            },
             { "latn.NumberPatterns",
                 new String[] {
                     "#,##0.###",
@@ -315,10 +305,6 @@ public class FormatData_es_CO extends ListResourceBundle {
                     "\u00a4#,##0.00",
                 }
             },
-            { "buddhist.DayNarrows", metaValue_generic_DayNarrows },
-            { "japanese.DayNarrows", metaValue_generic_DayNarrows },
-            { "roc.TimePatterns", metaValue_generic_TimePatterns },
-            { "roc.abbreviated.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
         };
         return data;
     }
