@@ -66,79 +66,6 @@ import java.util.ListResourceBundle;
 public class FormatData_hi_Latn extends ListResourceBundle {
     @Override
     protected final Object[][] getContents() {
-        final String[] metaValue_generic_DayNames = new String[] {
-            "ravivaar",
-            "somvaar",
-            "mangalvaar",
-            "budhvaar",
-            "guruvaar",
-            "shukravaar",
-            "shanivaar",
-        };
-        final String[] metaValue_generic_DayAbbreviations = new String[] {
-            "ravi",
-            "som",
-            "mangal",
-            "budh",
-            "guru",
-            "shukra",
-            "shani",
-        };
-        final String[] metaValue_generic_DayNarrows = new String[] {
-            "ra",
-            "so",
-            "ma",
-            "bu",
-            "gu",
-            "su",
-            "sa",
-        };
-        final String[] metaValue_generic_AmPmMarkers = new String[] {
-            "AM",
-            "PM",
-            "aadhi raat",
-            "noon",
-            "subah",
-            "",
-            "dopahar",
-            "",
-            "shaam",
-            "",
-            "raat",
-            "",
-        };
-        final String[] metaValue_generic_narrow_AmPmMarkers = new String[] {
-            "AM",
-            "PM",
-            "mi",
-            "n",
-            "in the morning",
-            "",
-            "in the afternoon",
-            "",
-            "in the evening",
-            "",
-            "at night",
-            "",
-        };
-        final String[] metaValue_generic_TimePatterns = new String[] {
-            "h:mm:ss a zzzz",
-            "h:mm:ss a z",
-            "h:mm:ss a",
-            "h:mm a",
-        };
-        final String[] metaValue_java_time_generic_DatePatterns = new String[] {
-            "EEEE, d MMMM, y G",
-            "d MMMM, y G",
-            "d MMM, y G",
-            "d/M/y GGGGG",
-        };
-        final String[] metaValue_generic_DatePatterns = new String[] {
-            "EEEE, d MMMM, y GGGG",
-            "d MMMM, y GGGG",
-            "d MMM, y GGGG",
-            "d/M/y G",
-        };
         final String[] metaValue_MonthAbbreviations = new String[] {
             "Jan",
             "Feb",
@@ -154,36 +81,156 @@ public class FormatData_hi_Latn extends ListResourceBundle {
             "Dec",
             "",
         };
+        final String[] metaValue_generic_DayNames = new String[] {
+            "Raviwaar",
+            "Somwaar",
+            "Mangalwaar",
+            "Budhwaar",
+            "Guruwaar",
+            "Shukrawaar",
+            "Shaniwaar",
+        };
+        final String[] metaValue_generic_DayAbbreviations = new String[] {
+            "Ravi",
+            "Som",
+            "Mangal",
+            "Budh",
+            "Guru",
+            "Shukra",
+            "Shani",
+        };
+        final String[] metaValue_generic_DayNarrows = new String[] {
+            "Ra",
+            "So",
+            "Ma",
+            "Bu",
+            "Gu",
+            "Sh",
+            "Sha",
+        };
+        final String[] metaValue_generic_AmPmMarkers = new String[] {
+            "AM",
+            "PM",
+            "aadhi raat",
+            "Madhyanh",
+            "subah",
+            "",
+            "dopahar",
+            "",
+            "shaam",
+            "",
+            "raat",
+            "",
+        };
+        final String[] metaValue_generic_narrow_AmPmMarkers = new String[] {
+            "a",
+            "p",
+            "mi",
+            "n",
+            "subah",
+            "",
+            "dopahar",
+            "",
+            "shaam",
+            "",
+            "raat",
+            "",
+        };
+        final String[] metaValue_generic_abbreviated_AmPmMarkers = new String[] {
+            "AM",
+            "PM",
+            "midnight",
+            "noon",
+            "subah",
+            "",
+            "dopahar",
+            "",
+            "shaam",
+            "",
+            "raat",
+            "",
+        };
+        final String[] metaValue_generic_TimePatterns = new String[] {
+            "h:mm:ss\u202fa zzzz",
+            "h:mm:ss\u202fa z",
+            "h:mm:ss\u202fa",
+            "h:mm\u202fa",
+        };
+        final String metaValue_generic_DateFormatItem_Gy = "G y";
+        final String metaValue_generic_DateFormatItem_GyMMMd = "G y, d MMM";
+        final String metaValue_generic_DateFormatItem_yMMMd = "d MMM, y";
+        final String metaValue_generic_DateFormatItem_yw = "Y 'kaa' 'week' w";
+        final String metaValue_generic_DateFormatItem_GyMMMEd = "G y, dd MMM, E";
+        final String metaValue_generic_DateFormatItem_MMMMW = "MMMM 'kaa' 'week' W";
+        final String metaValue_generic_DateFormatItem_GyMMM = "G y MMM";
+        final String[] metaValue_java_time_generic_DatePatterns = new String[] {
+            "EEEE, d MMMM, y G",
+            "d MMMM, y G",
+            "d MMM, y G",
+            "d/M/y GGGGG",
+        };
+        final String[] metaValue_generic_DatePatterns = new String[] {
+            "EEEE, d MMMM, y GGGG",
+            "d MMMM, y GGGG",
+            "d MMM, y GGGG",
+            "d/M/y G",
+        };
         final String[] metaValue_java_time_islamic_long_Eras = new String[] {
             "",
             "Hijri",
         };
         final Object[][] data = new Object[][] {
-            { "field.year", "saal" },
-            { "generic.DatePatterns", metaValue_generic_DatePatterns },
-            { "roc.DayAbbreviations", metaValue_generic_DayAbbreviations },
-            { "standalone.DayNarrows", metaValue_generic_DayNarrows },
-            { "japanese.AmPmMarkers", metaValue_generic_AmPmMarkers },
-            { "islamic.AmPmMarkers", metaValue_generic_AmPmMarkers },
-            { "AmPmMarkers", metaValue_generic_AmPmMarkers },
-            { "java.time.japanese.DatePatterns", metaValue_java_time_generic_DatePatterns },
-            { "TimePatterns", metaValue_generic_TimePatterns },
+            { "generic.DayNames", metaValue_generic_DayNames },
+            { "generic.DayAbbreviations", metaValue_generic_DayAbbreviations },
             { "generic.DayNarrows", metaValue_generic_DayNarrows },
-            { "calendarname.islamic-civil", "Islamic Civil Calendar (tabular, civil epoch)" },
-            { "japanese.TimePatterns", metaValue_generic_TimePatterns },
-            { "abbreviated.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
-            { "japanese.abbreviated.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
+            { "generic.AmPmMarkers", metaValue_generic_AmPmMarkers },
+            { "generic.narrow.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
+            { "generic.abbreviated.AmPmMarkers", metaValue_generic_abbreviated_AmPmMarkers },
+            { "generic.TimePatterns", metaValue_generic_TimePatterns },
+            { "java.time.generic.DatePatterns", metaValue_java_time_generic_DatePatterns },
+            { "generic.DatePatterns", metaValue_generic_DatePatterns },
+            { "generic.DateTimePatterns",
+                new String[] {
+                    "{1}, {0}",
+                    "{1}, {0}",
+                    "{1}, {0}",
+                    "{1}, {0}",
+                }
+            },
+            { "generic.DateFormatItem.Gy", metaValue_generic_DateFormatItem_Gy },
             { "generic.DateFormatItem.Bhms", "h:mm.ss B" },
-            { "buddhist.narrow.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
-            { "buddhist.abbreviated.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
-            { "roc.DayNames", metaValue_generic_DayNames },
+            { "generic.DateFormatItem.GyMMMd", metaValue_generic_DateFormatItem_GyMMMd },
+            { "generic.DateFormatItem.yMMMd", metaValue_generic_DateFormatItem_yMMMd },
+            { "generic.DateFormatItem.yw", metaValue_generic_DateFormatItem_yw },
+            { "generic.DateFormatItem.yyyyMd", "d/M/y GGGGG" },
+            { "generic.DateFormatItem.GyMMMEd", metaValue_generic_DateFormatItem_GyMMMEd },
+            { "generic.DateFormatItem.MMMMW", metaValue_generic_DateFormatItem_MMMMW },
+            { "generic.DateFormatItem.GyMMM", metaValue_generic_DateFormatItem_GyMMM },
+            { "MonthAbbreviations", metaValue_MonthAbbreviations },
+            { "standalone.MonthAbbreviations", metaValue_MonthAbbreviations },
+            { "DayNames", metaValue_generic_DayNames },
+            { "standalone.DayNames", metaValue_generic_DayNames },
+            { "DayAbbreviations", metaValue_generic_DayAbbreviations },
             { "standalone.DayAbbreviations", metaValue_generic_DayAbbreviations },
-            { "roc.MonthAbbreviations", metaValue_MonthAbbreviations },
-            { "java.time.islamic.narrow.Eras", metaValue_java_time_islamic_long_Eras },
-            { "islamic.abbreviated.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
-            { "islamic.DayNames", metaValue_generic_DayNames },
-            { "java.time.islamic.DatePatterns", metaValue_java_time_generic_DatePatterns },
-            { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
+            { "DayNarrows", metaValue_generic_DayNarrows },
+            { "standalone.DayNarrows", metaValue_generic_DayNarrows },
+            { "AmPmMarkers", metaValue_generic_AmPmMarkers },
+            { "narrow.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
+            { "abbreviated.AmPmMarkers", metaValue_generic_abbreviated_AmPmMarkers },
+            { "field.year", "saal" },
+            { "field.month", "mahina" },
+            { "field.week", "hafta" },
+            { "field.weekday", "Week kaa din" },
+            { "field.hour", "ghanta" },
+            { "TimePatterns", metaValue_generic_TimePatterns },
+            { "DatePatterns",
+                new String[] {
+                    "EEEE, d MMMM, y",
+                    "d MMMM, y",
+                    "dd MMM, y",
+                    "dd/MM/y",
+                }
+            },
             { "DateTimePatterns",
                 new String[] {
                     "{1}, {0}",
@@ -192,32 +239,65 @@ public class FormatData_hi_Latn extends ListResourceBundle {
                     "{1} {0}",
                 }
             },
-            { "narrow.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
-            { "latn.NumberElements",
-                new String[] {
-                    ".",
-                    ",",
-                    ";",
-                    "%",
-                    "0",
-                    "#",
-                    "-",
-                    "E",
-                    "\u2030",
-                    "\u221e",
-                    "NaN",
-                    "",
-                    "",
-                }
-            },
-            { "japanese.DatePatterns", metaValue_generic_DatePatterns },
+            { "DayPeriodRules", "midnight:00:00;noon:12:00;night1:20:00-04:00;afternoon1:12:00-16:00;morning1:04:00-12:00;evening1:16:00-20:00" },
+            { "DateFormatItem.Gy", metaValue_generic_DateFormatItem_Gy },
+            { "DateFormatItem.GyMMMd", metaValue_generic_DateFormatItem_GyMMMd },
+            { "DateFormatItem.yMMMd", metaValue_generic_DateFormatItem_yMMMd },
+            { "DateFormatItem.yw", metaValue_generic_DateFormatItem_yw },
+            { "DateFormatItem.GyMMMEd", metaValue_generic_DateFormatItem_GyMMMEd },
+            { "DateFormatItem.MMMMW", metaValue_generic_DateFormatItem_MMMMW },
+            { "DateFormatItem.GyMMM", metaValue_generic_DateFormatItem_GyMMM },
+            { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "buddhist.DayNames", metaValue_generic_DayNames },
-            { "japanese.MonthAbbreviations", metaValue_MonthAbbreviations },
-            { "generic.DayNames", metaValue_generic_DayNames },
-            { "islamic.DayAbbreviations", metaValue_generic_DayAbbreviations },
+            { "buddhist.DayAbbreviations", metaValue_generic_DayAbbreviations },
+            { "buddhist.DayNarrows", metaValue_generic_DayNarrows },
             { "buddhist.AmPmMarkers", metaValue_generic_AmPmMarkers },
-            { "islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
-            { "java.time.islamic.Eras", metaValue_java_time_islamic_long_Eras },
+            { "buddhist.narrow.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
+            { "buddhist.abbreviated.AmPmMarkers", metaValue_generic_abbreviated_AmPmMarkers },
+            { "buddhist.TimePatterns", metaValue_generic_TimePatterns },
+            { "java.time.buddhist.DatePatterns", metaValue_java_time_generic_DatePatterns },
+            { "buddhist.DatePatterns", metaValue_generic_DatePatterns },
+            { "buddhist.DateFormatItem.Gy", metaValue_generic_DateFormatItem_Gy },
+            { "buddhist.DateFormatItem.GyMMMd", metaValue_generic_DateFormatItem_GyMMMd },
+            { "buddhist.DateFormatItem.yMMMd", metaValue_generic_DateFormatItem_yMMMd },
+            { "buddhist.DateFormatItem.yw", metaValue_generic_DateFormatItem_yw },
+            { "buddhist.DateFormatItem.GyMMMEd", metaValue_generic_DateFormatItem_GyMMMEd },
+            { "buddhist.DateFormatItem.MMMMW", metaValue_generic_DateFormatItem_MMMMW },
+            { "buddhist.DateFormatItem.GyMMM", metaValue_generic_DateFormatItem_GyMMM },
+            { "japanese.MonthAbbreviations", metaValue_MonthAbbreviations },
+            { "japanese.DayNames", metaValue_generic_DayNames },
+            { "japanese.DayAbbreviations", metaValue_generic_DayAbbreviations },
+            { "japanese.DayNarrows", metaValue_generic_DayNarrows },
+            { "japanese.AmPmMarkers", metaValue_generic_AmPmMarkers },
+            { "japanese.narrow.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
+            { "japanese.abbreviated.AmPmMarkers", metaValue_generic_abbreviated_AmPmMarkers },
+            { "japanese.TimePatterns", metaValue_generic_TimePatterns },
+            { "java.time.japanese.DatePatterns", metaValue_java_time_generic_DatePatterns },
+            { "japanese.DatePatterns", metaValue_generic_DatePatterns },
+            { "japanese.DateFormatItem.Gy", metaValue_generic_DateFormatItem_Gy },
+            { "japanese.DateFormatItem.GyMMMd", metaValue_generic_DateFormatItem_GyMMMd },
+            { "japanese.DateFormatItem.yMMMd", metaValue_generic_DateFormatItem_yMMMd },
+            { "japanese.DateFormatItem.yw", metaValue_generic_DateFormatItem_yw },
+            { "japanese.DateFormatItem.GyMMMEd", metaValue_generic_DateFormatItem_GyMMMEd },
+            { "japanese.DateFormatItem.MMMMW", metaValue_generic_DateFormatItem_MMMMW },
+            { "japanese.DateFormatItem.GyMMM", metaValue_generic_DateFormatItem_GyMMM },
+            { "roc.MonthAbbreviations", metaValue_MonthAbbreviations },
+            { "roc.DayNames", metaValue_generic_DayNames },
+            { "roc.DayAbbreviations", metaValue_generic_DayAbbreviations },
+            { "roc.DayNarrows", metaValue_generic_DayNarrows },
+            { "roc.AmPmMarkers", metaValue_generic_AmPmMarkers },
+            { "roc.narrow.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
+            { "roc.abbreviated.AmPmMarkers", metaValue_generic_abbreviated_AmPmMarkers },
+            { "roc.TimePatterns", metaValue_generic_TimePatterns },
+            { "java.time.roc.DatePatterns", metaValue_java_time_generic_DatePatterns },
+            { "roc.DatePatterns", metaValue_generic_DatePatterns },
+            { "roc.DateFormatItem.Gy", metaValue_generic_DateFormatItem_Gy },
+            { "roc.DateFormatItem.GyMMMd", metaValue_generic_DateFormatItem_GyMMMd },
+            { "roc.DateFormatItem.yMMMd", metaValue_generic_DateFormatItem_yMMMd },
+            { "roc.DateFormatItem.yw", metaValue_generic_DateFormatItem_yw },
+            { "roc.DateFormatItem.GyMMMEd", metaValue_generic_DateFormatItem_GyMMMEd },
+            { "roc.DateFormatItem.MMMMW", metaValue_generic_DateFormatItem_MMMMW },
+            { "roc.DateFormatItem.GyMMM", metaValue_generic_DateFormatItem_GyMMM },
             { "islamic.MonthNames",
                 new String[] {
                     "Muharram",
@@ -235,60 +315,6 @@ public class FormatData_hi_Latn extends ListResourceBundle {
                     "",
                 }
             },
-            { "islamic.DatePatterns", metaValue_generic_DatePatterns },
-            { "generic.abbreviated.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
-            { "japanese.DayNames", metaValue_generic_DayNames },
-            { "islamic.Eras", metaValue_java_time_islamic_long_Eras },
-            { "japanese.DayAbbreviations", metaValue_generic_DayAbbreviations },
-            { "DayNames", metaValue_generic_DayNames },
-            { "field.month", "mahina" },
-            { "buddhist.DatePatterns", metaValue_generic_DatePatterns },
-            { "field.week", "hafta" },
-            { "DayAbbreviations", metaValue_generic_DayAbbreviations },
-            { "DayNarrows", metaValue_generic_DayNarrows },
-            { "roc.DatePatterns", metaValue_generic_DatePatterns },
-            { "roc.DayNarrows", metaValue_generic_DayNarrows },
-            { "generic.DateFormatItem.yyyyMd", "d/M/y GGGGG" },
-            { "roc.AmPmMarkers", metaValue_generic_AmPmMarkers },
-            { "java.time.buddhist.DatePatterns", metaValue_java_time_generic_DatePatterns },
-            { "java.time.roc.DatePatterns", metaValue_java_time_generic_DatePatterns },
-            { "short.CompactNumberPatterns",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "{one:0\u00a0hazaar other:0\u00a0hazaar}",
-                    "{one:00\u00a0hazaar other:00\u00a0hazaar}",
-                    "{one:0\u00a0laakh other:0\u00a0laakh}",
-                    "{one:00\u00a0laakh other:00\u00a0laakh}",
-                    "{one:0\u00a0ka'.' other:0\u00a0ka'.'}",
-                    "{one:00\u00a0ka'.' other:00\u00a0ka'.'}",
-                    "{one:0\u00a0a'.' other:0\u00a0a'.'}",
-                    "{one:00\u00a0a'.' other:00\u00a0a'.'}",
-                    "{one:0\u00a0kha'.' other:0\u00a0kha'.'}",
-                    "{one:00\u00a0kha'.' other:00\u00a0kha'.'}",
-                    "{one:000\u00a0kha'.' other:000\u00a0kha'.'}",
-                    "{one:0000\u00a0kha'.' other:0000\u00a0kha'.'}",
-                }
-            },
-            { "DatePatterns",
-                new String[] {
-                    "EEEE, d MMMM, y",
-                    "d MMMM y",
-                    "dd-MMM-y",
-                    "dd/MM/y",
-                }
-            },
-            { "buddhist.DayAbbreviations", metaValue_generic_DayAbbreviations },
-            { "java.time.generic.DatePatterns", metaValue_java_time_generic_DatePatterns },
-            { "islamic.TimePatterns", metaValue_generic_TimePatterns },
-            { "generic.TimePatterns", metaValue_generic_TimePatterns },
-            { "standalone.DayNames", metaValue_generic_DayNames },
-            { "MonthAbbreviations", metaValue_MonthAbbreviations },
-            { "generic.narrow.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
-            { "field.hour", "ghanta" },
-            { "generic.DayAbbreviations", metaValue_generic_DayAbbreviations },
-            { "buddhist.TimePatterns", metaValue_generic_TimePatterns },
             { "islamic.MonthAbbreviations",
                 new String[] {
                     "Muh",
@@ -306,9 +332,60 @@ public class FormatData_hi_Latn extends ListResourceBundle {
                     "",
                 }
             },
+            { "islamic.DayNames", metaValue_generic_DayNames },
+            { "islamic.DayAbbreviations", metaValue_generic_DayAbbreviations },
+            { "islamic.DayNarrows", metaValue_generic_DayNarrows },
+            { "islamic.AmPmMarkers", metaValue_generic_AmPmMarkers },
+            { "islamic.narrow.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
+            { "islamic.abbreviated.AmPmMarkers", metaValue_generic_abbreviated_AmPmMarkers },
+            { "java.time.islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
+            { "islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
+            { "java.time.islamic.Eras", metaValue_java_time_islamic_long_Eras },
+            { "islamic.Eras", metaValue_java_time_islamic_long_Eras },
+            { "java.time.islamic.narrow.Eras", metaValue_java_time_islamic_long_Eras },
             { "islamic.narrow.Eras", metaValue_java_time_islamic_long_Eras },
-            { "generic.AmPmMarkers", metaValue_generic_AmPmMarkers },
-            { "standalone.MonthAbbreviations", metaValue_MonthAbbreviations },
+            { "islamic.TimePatterns", metaValue_generic_TimePatterns },
+            { "java.time.islamic.DatePatterns", metaValue_java_time_generic_DatePatterns },
+            { "islamic.DatePatterns", metaValue_generic_DatePatterns },
+            { "islamic.DateFormatItem.Gy", metaValue_generic_DateFormatItem_Gy },
+            { "islamic.DateFormatItem.GyMMMd", metaValue_generic_DateFormatItem_GyMMMd },
+            { "islamic.DateFormatItem.yMMMd", metaValue_generic_DateFormatItem_yMMMd },
+            { "islamic.DateFormatItem.yw", metaValue_generic_DateFormatItem_yw },
+            { "islamic.DateFormatItem.GyMMMEd", metaValue_generic_DateFormatItem_GyMMMEd },
+            { "islamic.DateFormatItem.MMMMW", metaValue_generic_DateFormatItem_MMMMW },
+            { "islamic.DateFormatItem.GyMMM", metaValue_generic_DateFormatItem_GyMMM },
+            { "islamic-civil.DateFormatItem.Gy", metaValue_generic_DateFormatItem_Gy },
+            { "islamic-civil.DateFormatItem.GyMMMd", metaValue_generic_DateFormatItem_GyMMMd },
+            { "islamic-civil.DateFormatItem.yMMMd", metaValue_generic_DateFormatItem_yMMMd },
+            { "islamic-civil.DateFormatItem.yw", metaValue_generic_DateFormatItem_yw },
+            { "islamic-civil.DateFormatItem.GyMMMEd", metaValue_generic_DateFormatItem_GyMMMEd },
+            { "islamic-civil.DateFormatItem.MMMMW", metaValue_generic_DateFormatItem_MMMMW },
+            { "islamic-civil.DateFormatItem.GyMMM", metaValue_generic_DateFormatItem_GyMMM },
+            { "islamic-umalqura.DateFormatItem.Gy", metaValue_generic_DateFormatItem_Gy },
+            { "islamic-umalqura.DateFormatItem.GyMMMd", metaValue_generic_DateFormatItem_GyMMMd },
+            { "islamic-umalqura.DateFormatItem.yMMMd", metaValue_generic_DateFormatItem_yMMMd },
+            { "islamic-umalqura.DateFormatItem.yw", metaValue_generic_DateFormatItem_yw },
+            { "islamic-umalqura.DateFormatItem.GyMMMEd", metaValue_generic_DateFormatItem_GyMMMEd },
+            { "islamic-umalqura.DateFormatItem.MMMMW", metaValue_generic_DateFormatItem_MMMMW },
+            { "islamic-umalqura.DateFormatItem.GyMMM", metaValue_generic_DateFormatItem_GyMMM },
+            { "calendarname.islamic-civil", "Islamic Civil Calendar (tabular, civil epoch)" },
+            { "latn.NumberElements",
+                new String[] {
+                    ".",
+                    ",",
+                    ";",
+                    "%",
+                    "0",
+                    "#",
+                    "-",
+                    "E",
+                    "\u2030",
+                    "\u221e",
+                    "NaN",
+                    "",
+                    "",
+                }
+            },
             { "latn.NumberPatterns",
                 new String[] {
                     "#,##,##0.###",
@@ -317,6 +394,25 @@ public class FormatData_hi_Latn extends ListResourceBundle {
                     "\u00a4#,##,##0.00",
                 }
             },
+            { "short.CompactNumberPatterns",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "{one:0\u00a0hazaar other:0\u00a0hazaar}",
+                    "{one:00Th other:00Th}",
+                    "{one:0\u00a0laakh other:0\u00a0laakh}",
+                    "{one:00\u00a0laakh other:00\u00a0laakh}",
+                    "{one:0\u00a0ka'.' other:0\u00a0ka'.'}",
+                    "{one:00\u00a0ka'.' other:00\u00a0ka'.'}",
+                    "{one:0\u00a0a'.' other:0\u00a0a'.'}",
+                    "{one:00\u00a0a'.' other:00\u00a0a'.'}",
+                    "{one:0\u00a0kha'.' other:0\u00a0kha'.'}",
+                    "{one:00\u00a0kha'.' other:00\u00a0kha'.'}",
+                    "{one:000\u00a0kha'.' other:000\u00a0kha'.'}",
+                    "{one:000kha'.' other:000kha'.'}",
+                }
+            },
             { "long.CompactNumberPatterns",
                 new String[] {
                     "",
@@ -336,9 +432,6 @@ public class FormatData_hi_Latn extends ListResourceBundle {
                     "{one:0000' 'kharab other:0000' 'kharab}",
                 }
             },
-            { "java.time.islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
-            { "roc.TimePatterns", metaValue_generic_TimePatterns },
-            { "roc.abbreviated.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
         };
         return data;
     }
