@@ -72,6 +72,22 @@ public class FormatData_ms_ID extends ListResourceBundle {
             "HH.mm.ss",
             "HH.mm",
         };
+        final String metaValue_generic_DateFormatItem_hm = "h.mm\u202fa";
+        final String metaValue_generic_DateFormatItem_Ehm = "E h.mm\u202fa";
+        final String metaValue_generic_DateFormatItem_hms = "h.mm.ss\u202fa";
+        final String metaValue_generic_DateFormatItem_hmv = "h.mm\u202fa v";
+        final String metaValue_generic_DateFormatItem_hmsv = "h.mm.ss. a v";
+        final String metaValue_generic_DateFormatItem_Hm = "HH.mm";
+        final String metaValue_generic_DateFormatItem_EHm = "E HH.mm";
+        final String metaValue_generic_DateFormatItem_EBhm = "E h.mm B";
+        final String metaValue_generic_DateFormatItem_Hmsv = "HH.mm.ss v";
+        final String metaValue_generic_DateFormatItem_Ehms = "E h.mm.ss\u202fa";
+        final String metaValue_generic_DateFormatItem_Bhms = "h.mm.ss B";
+        final String metaValue_generic_DateFormatItem_EHms = "E HH.mm.ss";
+        final String metaValue_generic_DateFormatItem_EBhms = "E h.mm.ss B";
+        final String metaValue_generic_DateFormatItem_Bhm = "h.mm B";
+        final String metaValue_generic_DateFormatItem_Hms = "HH.mm.ss";
+        final String metaValue_generic_DateFormatItem_Hmv = "HH.mm v";
         final String[] metaValue_java_time_generic_DatePatterns = new String[] {
             "EEEE, dd MMMM y G",
             "d MMMM y G",
@@ -84,22 +100,6 @@ public class FormatData_ms_ID extends ListResourceBundle {
             "d MMM y GGGG",
             "dd/MM/yy G",
         };
-        final String metaValue_generic_DateFormatItem_hm = "h.mm a";
-        final String metaValue_generic_DateFormatItem_Ehm = "E h.mm a";
-        final String metaValue_generic_DateFormatItem_hms = "h.mm.ss a";
-        final String metaValue_generic_DateFormatItem_hmv = "h.mm a v";
-        final String metaValue_generic_DateFormatItem_hmsv = "h.mm.ss. a v";
-        final String metaValue_generic_DateFormatItem_Hm = "HH.mm";
-        final String metaValue_generic_DateFormatItem_EHm = "E HH.mm";
-        final String metaValue_generic_DateFormatItem_EBhm = "E h.mm B";
-        final String metaValue_generic_DateFormatItem_Hmsv = "HH.mm.ss v";
-        final String metaValue_generic_DateFormatItem_Ehms = "E h.mm.ss a";
-        final String metaValue_generic_DateFormatItem_Bhms = "h.mm.ss B";
-        final String metaValue_generic_DateFormatItem_EHms = "E HH.mm.ss";
-        final String metaValue_generic_DateFormatItem_EBhms = "E h.mm.ss B";
-        final String metaValue_generic_DateFormatItem_Bhm = "h.mm B";
-        final String metaValue_generic_DateFormatItem_Hms = "HH.mm.ss";
-        final String metaValue_generic_DateFormatItem_Hmv = "HH.mm v";
         final String[] metaValue_java_time_buddhist_DatePatterns = new String[] {
             "EEEE, dd MMMM y G",
             "",
@@ -113,45 +113,159 @@ public class FormatData_ms_ID extends ListResourceBundle {
             "dd/MM/yy G",
         };
         final Object[][] data = new Object[][] {
-            { "islamic-umalqura.DateFormatItem.EHms", metaValue_generic_DateFormatItem_EHms },
-            { "islamic.DateFormatItem.Hmsv", metaValue_generic_DateFormatItem_Hmsv },
+            { "generic.TimePatterns", metaValue_generic_TimePatterns },
+            { "java.time.generic.DatePatterns", metaValue_java_time_generic_DatePatterns },
             { "generic.DatePatterns", metaValue_generic_DatePatterns },
-            { "DateFormatItem.hm", metaValue_generic_DateFormatItem_hm },
-            { "DateFormatItem.hmsv", metaValue_generic_DateFormatItem_hmsv },
-            { "roc.DateFormatItem.Bhms", metaValue_generic_DateFormatItem_Bhms },
-            { "buddhist.DateFormatItem.hmsv", metaValue_generic_DateFormatItem_hmsv },
-            { "islamic-umalqura.DateFormatItem.Bhms", metaValue_generic_DateFormatItem_Bhms },
-            { "islamic-civil.DateFormatItem.hmsv", metaValue_generic_DateFormatItem_hmsv },
-            { "java.time.japanese.DatePatterns", metaValue_java_time_generic_DatePatterns },
-            { "generic.DateFormatItem.hmv", metaValue_generic_DateFormatItem_hmv },
-            { "islamic-umalqura.DateFormatItem.EHm", metaValue_generic_DateFormatItem_EHm },
-            { "roc.DateFormatItem.EHms", metaValue_generic_DateFormatItem_EHms },
-            { "buddhist.DateFormatItem.Ehm", metaValue_generic_DateFormatItem_Ehm },
-            { "generic.DateFormatItem.hms", metaValue_generic_DateFormatItem_hms },
-            { "buddhist.DateFormatItem.hmv", metaValue_generic_DateFormatItem_hmv },
-            { "japanese.DateFormatItem.Hms", metaValue_generic_DateFormatItem_Hms },
             { "generic.DateFormatItem.hm", metaValue_generic_DateFormatItem_hm },
             { "generic.DateFormatItem.Ehm", metaValue_generic_DateFormatItem_Ehm },
-            { "buddhist.DateFormatItem.hms", metaValue_generic_DateFormatItem_hms },
-            { "japanese.TimePatterns", metaValue_generic_TimePatterns },
+            { "generic.DateFormatItem.hms", metaValue_generic_DateFormatItem_hms },
+            { "generic.DateFormatItem.hmv", metaValue_generic_DateFormatItem_hmv },
+            { "generic.DateFormatItem.hmsv", metaValue_generic_DateFormatItem_hmsv },
+            { "generic.DateFormatItem.Hm", metaValue_generic_DateFormatItem_Hm },
+            { "generic.DateFormatItem.EHm", metaValue_generic_DateFormatItem_EHm },
+            { "generic.DateFormatItem.EBhm", metaValue_generic_DateFormatItem_EBhm },
+            { "generic.DateFormatItem.Hmsv", metaValue_generic_DateFormatItem_Hmsv },
+            { "generic.DateFormatItem.Ehms", metaValue_generic_DateFormatItem_Ehms },
             { "generic.DateFormatItem.Bhms", metaValue_generic_DateFormatItem_Bhms },
             { "generic.DateFormatItem.EHms", metaValue_generic_DateFormatItem_EHms },
-            { "japanese.DateFormatItem.Hmv", metaValue_generic_DateFormatItem_Hmv },
-            { "islamic-umalqura.DateFormatItem.hms", metaValue_generic_DateFormatItem_hms },
-            { "islamic-civil.DateFormatItem.EBhms", metaValue_generic_DateFormatItem_EBhms },
-            { "japanese.DateFormatItem.hmsv", metaValue_generic_DateFormatItem_hmsv },
-            { "DateFormatItem.Hm", metaValue_generic_DateFormatItem_Hm },
-            { "buddhist.DateFormatItem.EBhms", metaValue_generic_DateFormatItem_EBhms },
-            { "islamic-umalqura.DateFormatItem.hmv", metaValue_generic_DateFormatItem_hmv },
-            { "islamic-umalqura.DateFormatItem.EBhm", metaValue_generic_DateFormatItem_EBhm },
-            { "japanese.DateFormatItem.Bhm", metaValue_generic_DateFormatItem_Bhm },
-            { "roc.DateFormatItem.EBhm", metaValue_generic_DateFormatItem_EBhm },
-            { "generic.DateFormatItem.Hmv", metaValue_generic_DateFormatItem_Hmv },
-            { "islamic-umalqura.DateFormatItem.Ehm", metaValue_generic_DateFormatItem_Ehm },
-            { "islamic-umalqura.DateFormatItem.Hm", metaValue_generic_DateFormatItem_Hm },
-            { "buddhist.DateFormatItem.EHm", metaValue_generic_DateFormatItem_EHm },
-            { "japanese.DateFormatItem.Hmsv", metaValue_generic_DateFormatItem_Hmsv },
+            { "generic.DateFormatItem.EBhms", metaValue_generic_DateFormatItem_EBhms },
+            { "generic.DateFormatItem.Bhm", metaValue_generic_DateFormatItem_Bhm },
             { "generic.DateFormatItem.Hms", metaValue_generic_DateFormatItem_Hms },
+            { "generic.DateFormatItem.Hmv", metaValue_generic_DateFormatItem_Hmv },
+            { "timezone.hourFormat", "+HH.mm;-HH.mm" },
+            { "TimePatterns", metaValue_generic_TimePatterns },
+            { "DatePatterns",
+                new String[] {
+                    "EEEE, dd MMMM y",
+                    "d MMMM y",
+                    "d MMM y",
+                    "dd/MM/yy",
+                }
+            },
+            { "DateFormatItem.hm", metaValue_generic_DateFormatItem_hm },
+            { "DateFormatItem.Ehm", metaValue_generic_DateFormatItem_Ehm },
+            { "DateFormatItem.hms", metaValue_generic_DateFormatItem_hms },
+            { "DateFormatItem.hmv", metaValue_generic_DateFormatItem_hmv },
+            { "DateFormatItem.hmsv", metaValue_generic_DateFormatItem_hmsv },
+            { "DateFormatItem.Hm", metaValue_generic_DateFormatItem_Hm },
+            { "DateFormatItem.EHm", metaValue_generic_DateFormatItem_EHm },
+            { "DateFormatItem.EBhm", metaValue_generic_DateFormatItem_EBhm },
+            { "DateFormatItem.Hmsv", metaValue_generic_DateFormatItem_Hmsv },
+            { "DateFormatItem.Ehms", metaValue_generic_DateFormatItem_Ehms },
+            { "DateFormatItem.Bhms", metaValue_generic_DateFormatItem_Bhms },
+            { "DateFormatItem.EHms", metaValue_generic_DateFormatItem_EHms },
+            { "DateFormatItem.EBhms", metaValue_generic_DateFormatItem_EBhms },
+            { "DateFormatItem.Bhm", metaValue_generic_DateFormatItem_Bhm },
+            { "DateFormatItem.Hms", metaValue_generic_DateFormatItem_Hms },
+            { "DateFormatItem.Hmv", metaValue_generic_DateFormatItem_Hmv },
+            { "buddhist.TimePatterns", metaValue_generic_TimePatterns },
+            { "java.time.buddhist.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
+            { "buddhist.DatePatterns", metaValue_buddhist_DatePatterns },
+            { "buddhist.DateFormatItem.hm", metaValue_generic_DateFormatItem_hm },
+            { "buddhist.DateFormatItem.Ehm", metaValue_generic_DateFormatItem_Ehm },
+            { "buddhist.DateFormatItem.hms", metaValue_generic_DateFormatItem_hms },
+            { "buddhist.DateFormatItem.hmv", metaValue_generic_DateFormatItem_hmv },
+            { "buddhist.DateFormatItem.hmsv", metaValue_generic_DateFormatItem_hmsv },
+            { "buddhist.DateFormatItem.Hm", metaValue_generic_DateFormatItem_Hm },
+            { "buddhist.DateFormatItem.EHm", metaValue_generic_DateFormatItem_EHm },
+            { "buddhist.DateFormatItem.EBhm", metaValue_generic_DateFormatItem_EBhm },
+            { "buddhist.DateFormatItem.Hmsv", metaValue_generic_DateFormatItem_Hmsv },
+            { "buddhist.DateFormatItem.Ehms", metaValue_generic_DateFormatItem_Ehms },
+            { "buddhist.DateFormatItem.Bhms", metaValue_generic_DateFormatItem_Bhms },
+            { "buddhist.DateFormatItem.EHms", metaValue_generic_DateFormatItem_EHms },
+            { "buddhist.DateFormatItem.EBhms", metaValue_generic_DateFormatItem_EBhms },
+            { "buddhist.DateFormatItem.Bhm", metaValue_generic_DateFormatItem_Bhm },
+            { "buddhist.DateFormatItem.Hms", metaValue_generic_DateFormatItem_Hms },
+            { "buddhist.DateFormatItem.Hmv", metaValue_generic_DateFormatItem_Hmv },
+            { "japanese.TimePatterns", metaValue_generic_TimePatterns },
+            { "java.time.japanese.DatePatterns", metaValue_java_time_generic_DatePatterns },
+            { "japanese.DatePatterns", metaValue_generic_DatePatterns },
+            { "japanese.DateFormatItem.hm", metaValue_generic_DateFormatItem_hm },
+            { "japanese.DateFormatItem.Ehm", metaValue_generic_DateFormatItem_Ehm },
+            { "japanese.DateFormatItem.hms", metaValue_generic_DateFormatItem_hms },
+            { "japanese.DateFormatItem.hmv", metaValue_generic_DateFormatItem_hmv },
+            { "japanese.DateFormatItem.hmsv", metaValue_generic_DateFormatItem_hmsv },
+            { "japanese.DateFormatItem.Hm", metaValue_generic_DateFormatItem_Hm },
+            { "japanese.DateFormatItem.EHm", metaValue_generic_DateFormatItem_EHm },
+            { "japanese.DateFormatItem.EBhm", metaValue_generic_DateFormatItem_EBhm },
+            { "japanese.DateFormatItem.Hmsv", metaValue_generic_DateFormatItem_Hmsv },
+            { "japanese.DateFormatItem.Ehms", metaValue_generic_DateFormatItem_Ehms },
+            { "japanese.DateFormatItem.Bhms", metaValue_generic_DateFormatItem_Bhms },
+            { "japanese.DateFormatItem.EHms", metaValue_generic_DateFormatItem_EHms },
+            { "japanese.DateFormatItem.EBhms", metaValue_generic_DateFormatItem_EBhms },
+            { "japanese.DateFormatItem.Bhm", metaValue_generic_DateFormatItem_Bhm },
+            { "japanese.DateFormatItem.Hms", metaValue_generic_DateFormatItem_Hms },
+            { "japanese.DateFormatItem.Hmv", metaValue_generic_DateFormatItem_Hmv },
+            { "roc.TimePatterns", metaValue_generic_TimePatterns },
+            { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
+            { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
+            { "roc.DateFormatItem.hm", metaValue_generic_DateFormatItem_hm },
+            { "roc.DateFormatItem.Ehm", metaValue_generic_DateFormatItem_Ehm },
+            { "roc.DateFormatItem.hms", metaValue_generic_DateFormatItem_hms },
+            { "roc.DateFormatItem.hmv", metaValue_generic_DateFormatItem_hmv },
+            { "roc.DateFormatItem.hmsv", metaValue_generic_DateFormatItem_hmsv },
+            { "roc.DateFormatItem.Hm", metaValue_generic_DateFormatItem_Hm },
+            { "roc.DateFormatItem.EHm", metaValue_generic_DateFormatItem_EHm },
+            { "roc.DateFormatItem.EBhm", metaValue_generic_DateFormatItem_EBhm },
+            { "roc.DateFormatItem.Hmsv", metaValue_generic_DateFormatItem_Hmsv },
+            { "roc.DateFormatItem.Ehms", metaValue_generic_DateFormatItem_Ehms },
+            { "roc.DateFormatItem.Bhms", metaValue_generic_DateFormatItem_Bhms },
+            { "roc.DateFormatItem.EHms", metaValue_generic_DateFormatItem_EHms },
+            { "roc.DateFormatItem.EBhms", metaValue_generic_DateFormatItem_EBhms },
+            { "roc.DateFormatItem.Bhm", metaValue_generic_DateFormatItem_Bhm },
+            { "roc.DateFormatItem.Hms", metaValue_generic_DateFormatItem_Hms },
+            { "roc.DateFormatItem.Hmv", metaValue_generic_DateFormatItem_Hmv },
+            { "islamic.TimePatterns", metaValue_generic_TimePatterns },
+            { "java.time.islamic.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
+            { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
+            { "islamic.DateFormatItem.hm", metaValue_generic_DateFormatItem_hm },
+            { "islamic.DateFormatItem.Ehm", metaValue_generic_DateFormatItem_Ehm },
+            { "islamic.DateFormatItem.hms", metaValue_generic_DateFormatItem_hms },
+            { "islamic.DateFormatItem.hmv", metaValue_generic_DateFormatItem_hmv },
+            { "islamic.DateFormatItem.hmsv", metaValue_generic_DateFormatItem_hmsv },
+            { "islamic.DateFormatItem.Hm", metaValue_generic_DateFormatItem_Hm },
+            { "islamic.DateFormatItem.EHm", metaValue_generic_DateFormatItem_EHm },
+            { "islamic.DateFormatItem.EBhm", metaValue_generic_DateFormatItem_EBhm },
+            { "islamic.DateFormatItem.Hmsv", metaValue_generic_DateFormatItem_Hmsv },
+            { "islamic.DateFormatItem.Ehms", metaValue_generic_DateFormatItem_Ehms },
+            { "islamic.DateFormatItem.Bhms", metaValue_generic_DateFormatItem_Bhms },
+            { "islamic.DateFormatItem.EHms", metaValue_generic_DateFormatItem_EHms },
+            { "islamic.DateFormatItem.EBhms", metaValue_generic_DateFormatItem_EBhms },
+            { "islamic.DateFormatItem.Bhm", metaValue_generic_DateFormatItem_Bhm },
+            { "islamic.DateFormatItem.Hms", metaValue_generic_DateFormatItem_Hms },
+            { "islamic.DateFormatItem.Hmv", metaValue_generic_DateFormatItem_Hmv },
+            { "islamic-civil.DateFormatItem.hm", metaValue_generic_DateFormatItem_hm },
+            { "islamic-civil.DateFormatItem.Ehm", metaValue_generic_DateFormatItem_Ehm },
+            { "islamic-civil.DateFormatItem.hms", metaValue_generic_DateFormatItem_hms },
+            { "islamic-civil.DateFormatItem.hmv", metaValue_generic_DateFormatItem_hmv },
+            { "islamic-civil.DateFormatItem.hmsv", metaValue_generic_DateFormatItem_hmsv },
+            { "islamic-civil.DateFormatItem.Hm", metaValue_generic_DateFormatItem_Hm },
+            { "islamic-civil.DateFormatItem.EHm", metaValue_generic_DateFormatItem_EHm },
+            { "islamic-civil.DateFormatItem.EBhm", metaValue_generic_DateFormatItem_EBhm },
+            { "islamic-civil.DateFormatItem.Hmsv", metaValue_generic_DateFormatItem_Hmsv },
+            { "islamic-civil.DateFormatItem.Ehms", metaValue_generic_DateFormatItem_Ehms },
+            { "islamic-civil.DateFormatItem.Bhms", metaValue_generic_DateFormatItem_Bhms },
+            { "islamic-civil.DateFormatItem.EHms", metaValue_generic_DateFormatItem_EHms },
+            { "islamic-civil.DateFormatItem.EBhms", metaValue_generic_DateFormatItem_EBhms },
+            { "islamic-civil.DateFormatItem.Bhm", metaValue_generic_DateFormatItem_Bhm },
+            { "islamic-civil.DateFormatItem.Hms", metaValue_generic_DateFormatItem_Hms },
+            { "islamic-civil.DateFormatItem.Hmv", metaValue_generic_DateFormatItem_Hmv },
+            { "islamic-umalqura.DateFormatItem.hm", metaValue_generic_DateFormatItem_hm },
+            { "islamic-umalqura.DateFormatItem.Ehm", metaValue_generic_DateFormatItem_Ehm },
+            { "islamic-umalqura.DateFormatItem.hms", metaValue_generic_DateFormatItem_hms },
+            { "islamic-umalqura.DateFormatItem.hmv", metaValue_generic_DateFormatItem_hmv },
+            { "islamic-umalqura.DateFormatItem.hmsv", metaValue_generic_DateFormatItem_hmsv },
+            { "islamic-umalqura.DateFormatItem.Hm", metaValue_generic_DateFormatItem_Hm },
+            { "islamic-umalqura.DateFormatItem.EHm", metaValue_generic_DateFormatItem_EHm },
+            { "islamic-umalqura.DateFormatItem.EBhm", metaValue_generic_DateFormatItem_EBhm },
+            { "islamic-umalqura.DateFormatItem.Hmsv", metaValue_generic_DateFormatItem_Hmsv },
+            { "islamic-umalqura.DateFormatItem.Ehms", metaValue_generic_DateFormatItem_Ehms },
+            { "islamic-umalqura.DateFormatItem.Bhms", metaValue_generic_DateFormatItem_Bhms },
+            { "islamic-umalqura.DateFormatItem.EHms", metaValue_generic_DateFormatItem_EHms },
+            { "islamic-umalqura.DateFormatItem.EBhms", metaValue_generic_DateFormatItem_EBhms },
+            { "islamic-umalqura.DateFormatItem.Bhm", metaValue_generic_DateFormatItem_Bhm },
+            { "islamic-umalqura.DateFormatItem.Hms", metaValue_generic_DateFormatItem_Hms },
+            { "islamic-umalqura.DateFormatItem.Hmv", metaValue_generic_DateFormatItem_Hmv },
             { "latn.NumberElements",
                 new String[] {
                     ",",
@@ -169,117 +283,6 @@ public class FormatData_ms_ID extends ListResourceBundle {
                     "",
                 }
             },
-            { "japanese.DatePatterns", metaValue_generic_DatePatterns },
-            { "generic.DateFormatItem.Hm", metaValue_generic_DateFormatItem_Hm },
-            { "japanese.DateFormatItem.EBhm", metaValue_generic_DateFormatItem_EBhm },
-            { "generic.DateFormatItem.Ehms", metaValue_generic_DateFormatItem_Ehms },
-            { "roc.DateFormatItem.Hmsv", metaValue_generic_DateFormatItem_Hmsv },
-            { "islamic.DateFormatItem.Bhms", metaValue_generic_DateFormatItem_Bhms },
-            { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
-            { "islamic.DateFormatItem.EHms", metaValue_generic_DateFormatItem_EHms },
-            { "islamic.DateFormatItem.hmsv", metaValue_generic_DateFormatItem_hmsv },
-            { "islamic.DateFormatItem.Hms", metaValue_generic_DateFormatItem_Hms },
-            { "islamic-civil.DateFormatItem.Hm", metaValue_generic_DateFormatItem_Hm },
-            { "DateFormatItem.EBhm", metaValue_generic_DateFormatItem_EBhm },
-            { "islamic-umalqura.DateFormatItem.EBhms", metaValue_generic_DateFormatItem_EBhms },
-            { "islamic.DateFormatItem.Hm", metaValue_generic_DateFormatItem_Hm },
-            { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
-            { "islamic-umalqura.DateFormatItem.Ehms", metaValue_generic_DateFormatItem_Ehms },
-            { "islamic.DateFormatItem.EBhm", metaValue_generic_DateFormatItem_EBhm },
-            { "islamic-civil.DateFormatItem.EHm", metaValue_generic_DateFormatItem_EHm },
-            { "japanese.DateFormatItem.Bhms", metaValue_generic_DateFormatItem_Bhms },
-            { "java.time.generic.DatePatterns", metaValue_java_time_generic_DatePatterns },
-            { "japanese.DateFormatItem.EHms", metaValue_generic_DateFormatItem_EHms },
-            { "generic.TimePatterns", metaValue_generic_TimePatterns },
-            { "roc.DateFormatItem.Hm", metaValue_generic_DateFormatItem_Hm },
-            { "DateFormatItem.Hmsv", metaValue_generic_DateFormatItem_Hmsv },
-            { "japanese.DateFormatItem.EBhms", metaValue_generic_DateFormatItem_EBhms },
-            { "islamic-civil.DateFormatItem.hm", metaValue_generic_DateFormatItem_hm },
-            { "DateFormatItem.Bhm", metaValue_generic_DateFormatItem_Bhm },
-            { "buddhist.TimePatterns", metaValue_generic_TimePatterns },
-            { "generic.DateFormatItem.EHm", metaValue_generic_DateFormatItem_EHm },
-            { "buddhist.DateFormatItem.Ehms", metaValue_generic_DateFormatItem_Ehms },
-            { "islamic.DateFormatItem.Bhm", metaValue_generic_DateFormatItem_Bhm },
-            { "roc.DateFormatItem.Bhm", metaValue_generic_DateFormatItem_Bhm },
-            { "islamic-civil.DateFormatItem.hmv", metaValue_generic_DateFormatItem_hmv },
-            { "generic.DateFormatItem.hmsv", metaValue_generic_DateFormatItem_hmsv },
-            { "islamic-civil.DateFormatItem.Bhms", metaValue_generic_DateFormatItem_Bhms },
-            { "islamic-civil.DateFormatItem.hms", metaValue_generic_DateFormatItem_hms },
-            { "DateFormatItem.Bhms", metaValue_generic_DateFormatItem_Bhms },
-            { "TimePatterns", metaValue_generic_TimePatterns },
-            { "islamic-civil.DateFormatItem.Ehm", metaValue_generic_DateFormatItem_Ehm },
-            { "islamic.DateFormatItem.hmv", metaValue_generic_DateFormatItem_hmv },
-            { "roc.DateFormatItem.hm", metaValue_generic_DateFormatItem_hm },
-            { "DateFormatItem.EBhms", metaValue_generic_DateFormatItem_EBhms },
-            { "DateFormatItem.Ehms", metaValue_generic_DateFormatItem_Ehms },
-            { "japanese.DateFormatItem.Ehms", metaValue_generic_DateFormatItem_Ehms },
-            { "islamic.DateFormatItem.EHm", metaValue_generic_DateFormatItem_EHm },
-            { "islamic-civil.DateFormatItem.Ehms", metaValue_generic_DateFormatItem_Ehms },
-            { "buddhist.DateFormatItem.EHms", metaValue_generic_DateFormatItem_EHms },
-            { "buddhist.DateFormatItem.Bhms", metaValue_generic_DateFormatItem_Bhms },
-            { "roc.DateFormatItem.hmsv", metaValue_generic_DateFormatItem_hmsv },
-            { "DateFormatItem.Hms", metaValue_generic_DateFormatItem_Hms },
-            { "DateFormatItem.Hmv", metaValue_generic_DateFormatItem_Hmv },
-            { "generic.DateFormatItem.EBhms", metaValue_generic_DateFormatItem_EBhms },
-            { "islamic.DateFormatItem.Ehms", metaValue_generic_DateFormatItem_Ehms },
-            { "islamic.DateFormatItem.EBhms", metaValue_generic_DateFormatItem_EBhms },
-            { "islamic-civil.DateFormatItem.Hmv", metaValue_generic_DateFormatItem_Hmv },
-            { "islamic-civil.DateFormatItem.Hms", metaValue_generic_DateFormatItem_Hms },
-            { "buddhist.DateFormatItem.hm", metaValue_generic_DateFormatItem_hm },
-            { "java.time.islamic.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
-            { "islamic.DateFormatItem.Hmv", metaValue_generic_DateFormatItem_Hmv },
-            { "DateFormatItem.Ehm", metaValue_generic_DateFormatItem_Ehm },
-            { "islamic.DateFormatItem.hms", metaValue_generic_DateFormatItem_hms },
-            { "DateFormatItem.EHms", metaValue_generic_DateFormatItem_EHms },
-            { "islamic.DateFormatItem.Ehm", metaValue_generic_DateFormatItem_Ehm },
-            { "islamic-civil.DateFormatItem.EHms", metaValue_generic_DateFormatItem_EHms },
-            { "islamic.DateFormatItem.hm", metaValue_generic_DateFormatItem_hm },
-            { "DateFormatItem.hmv", metaValue_generic_DateFormatItem_hmv },
-            { "DateFormatItem.hms", metaValue_generic_DateFormatItem_hms },
-            { "islamic-umalqura.DateFormatItem.Hms", metaValue_generic_DateFormatItem_Hms },
-            { "roc.DateFormatItem.Ehm", metaValue_generic_DateFormatItem_Ehm },
-            { "islamic-umalqura.DateFormatItem.Hmv", metaValue_generic_DateFormatItem_Hmv },
-            { "islamic-umalqura.DateFormatItem.Hmsv", metaValue_generic_DateFormatItem_Hmsv },
-            { "timezone.hourFormat", "+HH.mm;-HH.mm" },
-            { "buddhist.DateFormatItem.Bhm", metaValue_generic_DateFormatItem_Bhm },
-            { "buddhist.DateFormatItem.Hm", metaValue_generic_DateFormatItem_Hm },
-            { "islamic-umalqura.DateFormatItem.hm", metaValue_generic_DateFormatItem_hm },
-            { "buddhist.DateFormatItem.EBhm", metaValue_generic_DateFormatItem_EBhm },
-            { "islamic-civil.DateFormatItem.Bhm", metaValue_generic_DateFormatItem_Bhm },
-            { "islamic-civil.DateFormatItem.EBhm", metaValue_generic_DateFormatItem_EBhm },
-            { "DateFormatItem.EHm", metaValue_generic_DateFormatItem_EHm },
-            { "japanese.DateFormatItem.hm", metaValue_generic_DateFormatItem_hm },
-            { "generic.DateFormatItem.Hmsv", metaValue_generic_DateFormatItem_Hmsv },
-            { "buddhist.DatePatterns", metaValue_buddhist_DatePatterns },
-            { "japanese.DateFormatItem.EHm", metaValue_generic_DateFormatItem_EHm },
-            { "buddhist.DateFormatItem.Hmsv", metaValue_generic_DateFormatItem_Hmsv },
-            { "generic.DateFormatItem.Bhm", metaValue_generic_DateFormatItem_Bhm },
-            { "roc.DateFormatItem.Hms", metaValue_generic_DateFormatItem_Hms },
-            { "roc.DateFormatItem.Hmv", metaValue_generic_DateFormatItem_Hmv },
-            { "roc.DateFormatItem.EHm", metaValue_generic_DateFormatItem_EHm },
-            { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
-            { "java.time.buddhist.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
-            { "DatePatterns",
-                new String[] {
-                    "EEEE, dd MMMM y",
-                    "d MMMM y",
-                    "d MMM y",
-                    "dd/MM/yy",
-                }
-            },
-            { "roc.DateFormatItem.Ehms", metaValue_generic_DateFormatItem_Ehms },
-            { "islamic.TimePatterns", metaValue_generic_TimePatterns },
-            { "islamic-umalqura.DateFormatItem.Bhm", metaValue_generic_DateFormatItem_Bhm },
-            { "japanese.DateFormatItem.hmv", metaValue_generic_DateFormatItem_hmv },
-            { "generic.DateFormatItem.EBhm", metaValue_generic_DateFormatItem_EBhm },
-            { "roc.DateFormatItem.EBhms", metaValue_generic_DateFormatItem_EBhms },
-            { "buddhist.DateFormatItem.Hms", metaValue_generic_DateFormatItem_Hms },
-            { "japanese.DateFormatItem.Hm", metaValue_generic_DateFormatItem_Hm },
-            { "islamic-civil.DateFormatItem.Hmsv", metaValue_generic_DateFormatItem_Hmsv },
-            { "japanese.DateFormatItem.Ehm", metaValue_generic_DateFormatItem_Ehm },
-            { "islamic-umalqura.DateFormatItem.hmsv", metaValue_generic_DateFormatItem_hmsv },
-            { "buddhist.DateFormatItem.Hmv", metaValue_generic_DateFormatItem_Hmv },
-            { "roc.DateFormatItem.hms", metaValue_generic_DateFormatItem_hms },
             { "latn.NumberPatterns",
                 new String[] {
                     "#,##0.###",
@@ -288,9 +291,6 @@ public class FormatData_ms_ID extends ListResourceBundle {
                     "\u00a4#,##0.00",
                 }
             },
-            { "roc.DateFormatItem.hmv", metaValue_generic_DateFormatItem_hmv },
-            { "roc.TimePatterns", metaValue_generic_TimePatterns },
-            { "japanese.DateFormatItem.hms", metaValue_generic_DateFormatItem_hms },
         };
         return data;
     }
