@@ -66,6 +66,7 @@ import java.util.ListResourceBundle;
 public class FormatData_sv_FI extends ListResourceBundle {
     @Override
     protected final Object[][] getContents() {
+        final String metaValue_generic_DateFormatItem_Md = "d.M";
         final String[] metaValue_generic_QuarterAbbreviations = new String[] {
             "Q1",
             "Q2",
@@ -73,70 +74,200 @@ public class FormatData_sv_FI extends ListResourceBundle {
             "Q4",
         };
         final String metaValue_generic_DateFormatItem_MMdd = "dd.MM";
-        final String metaValue_generic_DateFormatItem_hm = "h.mm a";
-        final String metaValue_generic_DateFormatItem_Ehm = "E h.mm a";
-        final String metaValue_generic_DateFormatItem_hms = "h.mm.ss a";
-        final String metaValue_generic_DateFormatItem_hmv = "h.mm a v";
-        final String metaValue_generic_DateFormatItem_hmsv = "h.mm.ss a v";
+        final String metaValue_generic_DateFormatItem_hm = "h.mm\u202fa";
+        final String metaValue_generic_DateFormatItem_Ehm = "E h.mm\u202fa";
+        final String metaValue_generic_DateFormatItem_hms = "h.mm.ss\u202fa";
+        final String metaValue_generic_DateFormatItem_hmv = "h.mm\u202fa v";
+        final String metaValue_generic_DateFormatItem_hmsv = "h.mm.ss\u202fa v";
         final String metaValue_generic_DateFormatItem_Hm = "HH.mm";
         final String metaValue_generic_DateFormatItem_EHm = "E HH.mm";
         final String metaValue_generic_DateFormatItem_EBhm = "E h.mm B";
         final String metaValue_generic_DateFormatItem_Hmsv = "HH.mm.ss v";
-        final String metaValue_generic_DateFormatItem_Ehms = "E h.mm.ss a";
+        final String metaValue_generic_DateFormatItem_Ehms = "E h.mm.ss\u202fa";
         final String metaValue_generic_DateFormatItem_Bhms = "h.mm.ss B";
         final String metaValue_generic_DateFormatItem_ms = "mm.ss";
         final String metaValue_generic_DateFormatItem_EHms = "E HH.mm.ss";
-        final String metaValue_generic_DateFormatItem_Md = "d.M";
         final String metaValue_generic_DateFormatItem_EBhms = "E h.mm.ss B";
         final String metaValue_generic_DateFormatItem_Bhm = "h.mm B";
         final String metaValue_generic_DateFormatItem_MEd = "E d.M";
         final String metaValue_generic_DateFormatItem_Hms = "HH.mm.ss";
         final String metaValue_generic_DateFormatItem_Hmv = "HH.mm v";
         final Object[][] data = new Object[][] {
-            { "islamic-umalqura.DateFormatItem.EHms", metaValue_generic_DateFormatItem_EHms },
-            { "islamic.DateFormatItem.Hmsv", metaValue_generic_DateFormatItem_Hmsv },
-            { "DateFormatItem.hm", metaValue_generic_DateFormatItem_hm },
-            { "DateFormatItem.hmsv", metaValue_generic_DateFormatItem_hmsv },
-            { "roc.DateFormatItem.Bhms", metaValue_generic_DateFormatItem_Bhms },
-            { "buddhist.DateFormatItem.hmsv", metaValue_generic_DateFormatItem_hmsv },
-            { "islamic-umalqura.DateFormatItem.Bhms", metaValue_generic_DateFormatItem_Bhms },
-            { "DateFormatItem.MMdd", metaValue_generic_DateFormatItem_MMdd },
-            { "islamic-civil.DateFormatItem.hmsv", metaValue_generic_DateFormatItem_hmsv },
-            { "buddhist.DateFormatItem.MMdd", metaValue_generic_DateFormatItem_MMdd },
-            { "standalone.QuarterAbbreviations", metaValue_generic_QuarterAbbreviations },
-            { "generic.DateFormatItem.hmv", metaValue_generic_DateFormatItem_hmv },
-            { "islamic-umalqura.DateFormatItem.EHm", metaValue_generic_DateFormatItem_EHm },
-            { "roc.DateFormatItem.EHms", metaValue_generic_DateFormatItem_EHms },
-            { "buddhist.DateFormatItem.Ehm", metaValue_generic_DateFormatItem_Ehm },
-            { "generic.DateFormatItem.hms", metaValue_generic_DateFormatItem_hms },
-            { "buddhist.DateFormatItem.hmv", metaValue_generic_DateFormatItem_hmv },
-            { "japanese.DateFormatItem.Hms", metaValue_generic_DateFormatItem_Hms },
+            { "generic.QuarterAbbreviations", metaValue_generic_QuarterAbbreviations },
+            { "generic.DateFormatItem.MMdd", metaValue_generic_DateFormatItem_MMdd },
             { "generic.DateFormatItem.hm", metaValue_generic_DateFormatItem_hm },
             { "generic.DateFormatItem.Ehm", metaValue_generic_DateFormatItem_Ehm },
-            { "buddhist.DateFormatItem.hms", metaValue_generic_DateFormatItem_hms },
+            { "generic.DateFormatItem.hms", metaValue_generic_DateFormatItem_hms },
+            { "generic.DateFormatItem.hmv", metaValue_generic_DateFormatItem_hmv },
+            { "generic.DateFormatItem.hmsv", metaValue_generic_DateFormatItem_hmsv },
+            { "generic.DateFormatItem.Hm", metaValue_generic_DateFormatItem_Hm },
+            { "generic.DateFormatItem.EHm", metaValue_generic_DateFormatItem_EHm },
+            { "generic.DateFormatItem.EBhm", metaValue_generic_DateFormatItem_EBhm },
+            { "generic.DateFormatItem.Hmsv", metaValue_generic_DateFormatItem_Hmsv },
+            { "generic.DateFormatItem.Ehms", metaValue_generic_DateFormatItem_Ehms },
             { "generic.DateFormatItem.Bhms", metaValue_generic_DateFormatItem_Bhms },
+            { "generic.DateFormatItem.ms", metaValue_generic_DateFormatItem_ms },
             { "generic.DateFormatItem.EHms", metaValue_generic_DateFormatItem_EHms },
-            { "islamic-civil.DateFormatItem.MMdd", metaValue_generic_DateFormatItem_MMdd },
-            { "japanese.DateFormatItem.Md", metaValue_generic_DateFormatItem_Md },
-            { "japanese.DateFormatItem.Hmv", metaValue_generic_DateFormatItem_Hmv },
-            { "islamic-umalqura.DateFormatItem.hms", metaValue_generic_DateFormatItem_hms },
-            { "islamic-civil.DateFormatItem.EBhms", metaValue_generic_DateFormatItem_EBhms },
-            { "japanese.DateFormatItem.hmsv", metaValue_generic_DateFormatItem_hmsv },
-            { "DateFormatItem.Hm", metaValue_generic_DateFormatItem_Hm },
-            { "buddhist.DateFormatItem.EBhms", metaValue_generic_DateFormatItem_EBhms },
-            { "islamic-civil.DateFormatItem.Md", metaValue_generic_DateFormatItem_Md },
-            { "islamic-umalqura.DateFormatItem.hmv", metaValue_generic_DateFormatItem_hmv },
-            { "islamic-umalqura.DateFormatItem.EBhm", metaValue_generic_DateFormatItem_EBhm },
-            { "japanese.DateFormatItem.Bhm", metaValue_generic_DateFormatItem_Bhm },
-            { "roc.DateFormatItem.EBhm", metaValue_generic_DateFormatItem_EBhm },
-            { "islamic.DateFormatItem.MMdd", metaValue_generic_DateFormatItem_MMdd },
-            { "japanese.DateFormatItem.MMd", metaValue_generic_DateFormatItem_Md },
-            { "generic.DateFormatItem.Hmv", metaValue_generic_DateFormatItem_Hmv },
-            { "islamic-umalqura.DateFormatItem.Ehm", metaValue_generic_DateFormatItem_Ehm },
-            { "islamic-umalqura.DateFormatItem.Hm", metaValue_generic_DateFormatItem_Hm },
-            { "buddhist.DateFormatItem.EHm", metaValue_generic_DateFormatItem_EHm },
-            { "japanese.DateFormatItem.Hmsv", metaValue_generic_DateFormatItem_Hmsv },
+            { "generic.DateFormatItem.Md", metaValue_generic_DateFormatItem_Md },
+            { "generic.DateFormatItem.EBhms", metaValue_generic_DateFormatItem_EBhms },
+            { "generic.DateFormatItem.MMd", metaValue_generic_DateFormatItem_Md },
+            { "generic.DateFormatItem.Bhm", metaValue_generic_DateFormatItem_Bhm },
+            { "generic.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
             { "generic.DateFormatItem.Hms", metaValue_generic_DateFormatItem_Hms },
+            { "generic.DateFormatItem.Hmv", metaValue_generic_DateFormatItem_Hmv },
+            { "QuarterAbbreviations", metaValue_generic_QuarterAbbreviations },
+            { "standalone.QuarterAbbreviations", metaValue_generic_QuarterAbbreviations },
+            { "DateFormatItem.MMdd", metaValue_generic_DateFormatItem_MMdd },
+            { "DateFormatItem.hm", metaValue_generic_DateFormatItem_hm },
+            { "DateFormatItem.Ehm", metaValue_generic_DateFormatItem_Ehm },
+            { "DateFormatItem.hms", metaValue_generic_DateFormatItem_hms },
+            { "DateFormatItem.hmv", metaValue_generic_DateFormatItem_hmv },
+            { "DateFormatItem.hmsv", metaValue_generic_DateFormatItem_hmsv },
+            { "DateFormatItem.Hm", metaValue_generic_DateFormatItem_Hm },
+            { "DateFormatItem.EHm", metaValue_generic_DateFormatItem_EHm },
+            { "DateFormatItem.EBhm", metaValue_generic_DateFormatItem_EBhm },
+            { "DateFormatItem.Hmsv", metaValue_generic_DateFormatItem_Hmsv },
+            { "DateFormatItem.Ehms", metaValue_generic_DateFormatItem_Ehms },
+            { "DateFormatItem.Bhms", metaValue_generic_DateFormatItem_Bhms },
+            { "DateFormatItem.ms", metaValue_generic_DateFormatItem_ms },
+            { "DateFormatItem.EHms", metaValue_generic_DateFormatItem_EHms },
+            { "DateFormatItem.Md", metaValue_generic_DateFormatItem_Md },
+            { "DateFormatItem.EBhms", metaValue_generic_DateFormatItem_EBhms },
+            { "DateFormatItem.MMd", metaValue_generic_DateFormatItem_Md },
+            { "DateFormatItem.Bhm", metaValue_generic_DateFormatItem_Bhm },
+            { "DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
+            { "DateFormatItem.Hms", metaValue_generic_DateFormatItem_Hms },
+            { "DateFormatItem.Hmv", metaValue_generic_DateFormatItem_Hmv },
+            { "buddhist.QuarterAbbreviations", metaValue_generic_QuarterAbbreviations },
+            { "buddhist.DateFormatItem.MMdd", metaValue_generic_DateFormatItem_MMdd },
+            { "buddhist.DateFormatItem.hm", metaValue_generic_DateFormatItem_hm },
+            { "buddhist.DateFormatItem.Ehm", metaValue_generic_DateFormatItem_Ehm },
+            { "buddhist.DateFormatItem.hms", metaValue_generic_DateFormatItem_hms },
+            { "buddhist.DateFormatItem.hmv", metaValue_generic_DateFormatItem_hmv },
+            { "buddhist.DateFormatItem.hmsv", metaValue_generic_DateFormatItem_hmsv },
+            { "buddhist.DateFormatItem.Hm", metaValue_generic_DateFormatItem_Hm },
+            { "buddhist.DateFormatItem.EHm", metaValue_generic_DateFormatItem_EHm },
+            { "buddhist.DateFormatItem.EBhm", metaValue_generic_DateFormatItem_EBhm },
+            { "buddhist.DateFormatItem.Hmsv", metaValue_generic_DateFormatItem_Hmsv },
+            { "buddhist.DateFormatItem.Ehms", metaValue_generic_DateFormatItem_Ehms },
+            { "buddhist.DateFormatItem.Bhms", metaValue_generic_DateFormatItem_Bhms },
+            { "buddhist.DateFormatItem.ms", metaValue_generic_DateFormatItem_ms },
+            { "buddhist.DateFormatItem.EHms", metaValue_generic_DateFormatItem_EHms },
+            { "buddhist.DateFormatItem.Md", metaValue_generic_DateFormatItem_Md },
+            { "buddhist.DateFormatItem.EBhms", metaValue_generic_DateFormatItem_EBhms },
+            { "buddhist.DateFormatItem.MMd", metaValue_generic_DateFormatItem_Md },
+            { "buddhist.DateFormatItem.Bhm", metaValue_generic_DateFormatItem_Bhm },
+            { "buddhist.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
+            { "buddhist.DateFormatItem.Hms", metaValue_generic_DateFormatItem_Hms },
+            { "buddhist.DateFormatItem.Hmv", metaValue_generic_DateFormatItem_Hmv },
+            { "japanese.QuarterAbbreviations", metaValue_generic_QuarterAbbreviations },
+            { "japanese.DateFormatItem.MMdd", metaValue_generic_DateFormatItem_MMdd },
+            { "japanese.DateFormatItem.hm", metaValue_generic_DateFormatItem_hm },
+            { "japanese.DateFormatItem.Ehm", metaValue_generic_DateFormatItem_Ehm },
+            { "japanese.DateFormatItem.hms", metaValue_generic_DateFormatItem_hms },
+            { "japanese.DateFormatItem.hmv", metaValue_generic_DateFormatItem_hmv },
+            { "japanese.DateFormatItem.hmsv", metaValue_generic_DateFormatItem_hmsv },
+            { "japanese.DateFormatItem.Hm", metaValue_generic_DateFormatItem_Hm },
+            { "japanese.DateFormatItem.EHm", metaValue_generic_DateFormatItem_EHm },
+            { "japanese.DateFormatItem.EBhm", metaValue_generic_DateFormatItem_EBhm },
+            { "japanese.DateFormatItem.Hmsv", metaValue_generic_DateFormatItem_Hmsv },
+            { "japanese.DateFormatItem.Ehms", metaValue_generic_DateFormatItem_Ehms },
+            { "japanese.DateFormatItem.Bhms", metaValue_generic_DateFormatItem_Bhms },
+            { "japanese.DateFormatItem.ms", metaValue_generic_DateFormatItem_ms },
+            { "japanese.DateFormatItem.EHms", metaValue_generic_DateFormatItem_EHms },
+            { "japanese.DateFormatItem.Md", metaValue_generic_DateFormatItem_Md },
+            { "japanese.DateFormatItem.EBhms", metaValue_generic_DateFormatItem_EBhms },
+            { "japanese.DateFormatItem.MMd", metaValue_generic_DateFormatItem_Md },
+            { "japanese.DateFormatItem.Bhm", metaValue_generic_DateFormatItem_Bhm },
+            { "japanese.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
+            { "japanese.DateFormatItem.Hms", metaValue_generic_DateFormatItem_Hms },
+            { "japanese.DateFormatItem.Hmv", metaValue_generic_DateFormatItem_Hmv },
+            { "roc.QuarterAbbreviations", metaValue_generic_QuarterAbbreviations },
+            { "roc.DateFormatItem.MMdd", metaValue_generic_DateFormatItem_MMdd },
+            { "roc.DateFormatItem.hm", metaValue_generic_DateFormatItem_hm },
+            { "roc.DateFormatItem.Ehm", metaValue_generic_DateFormatItem_Ehm },
+            { "roc.DateFormatItem.hms", metaValue_generic_DateFormatItem_hms },
+            { "roc.DateFormatItem.hmv", metaValue_generic_DateFormatItem_hmv },
+            { "roc.DateFormatItem.hmsv", metaValue_generic_DateFormatItem_hmsv },
+            { "roc.DateFormatItem.Hm", metaValue_generic_DateFormatItem_Hm },
+            { "roc.DateFormatItem.EHm", metaValue_generic_DateFormatItem_EHm },
+            { "roc.DateFormatItem.EBhm", metaValue_generic_DateFormatItem_EBhm },
+            { "roc.DateFormatItem.Hmsv", metaValue_generic_DateFormatItem_Hmsv },
+            { "roc.DateFormatItem.Ehms", metaValue_generic_DateFormatItem_Ehms },
+            { "roc.DateFormatItem.Bhms", metaValue_generic_DateFormatItem_Bhms },
+            { "roc.DateFormatItem.ms", metaValue_generic_DateFormatItem_ms },
+            { "roc.DateFormatItem.EHms", metaValue_generic_DateFormatItem_EHms },
+            { "roc.DateFormatItem.Md", metaValue_generic_DateFormatItem_Md },
+            { "roc.DateFormatItem.EBhms", metaValue_generic_DateFormatItem_EBhms },
+            { "roc.DateFormatItem.MMd", metaValue_generic_DateFormatItem_Md },
+            { "roc.DateFormatItem.Bhm", metaValue_generic_DateFormatItem_Bhm },
+            { "roc.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
+            { "roc.DateFormatItem.Hms", metaValue_generic_DateFormatItem_Hms },
+            { "roc.DateFormatItem.Hmv", metaValue_generic_DateFormatItem_Hmv },
+            { "islamic.QuarterAbbreviations", metaValue_generic_QuarterAbbreviations },
+            { "islamic.DateFormatItem.MMdd", metaValue_generic_DateFormatItem_MMdd },
+            { "islamic.DateFormatItem.hm", metaValue_generic_DateFormatItem_hm },
+            { "islamic.DateFormatItem.Ehm", metaValue_generic_DateFormatItem_Ehm },
+            { "islamic.DateFormatItem.hms", metaValue_generic_DateFormatItem_hms },
+            { "islamic.DateFormatItem.hmv", metaValue_generic_DateFormatItem_hmv },
+            { "islamic.DateFormatItem.hmsv", metaValue_generic_DateFormatItem_hmsv },
+            { "islamic.DateFormatItem.Hm", metaValue_generic_DateFormatItem_Hm },
+            { "islamic.DateFormatItem.EHm", metaValue_generic_DateFormatItem_EHm },
+            { "islamic.DateFormatItem.EBhm", metaValue_generic_DateFormatItem_EBhm },
+            { "islamic.DateFormatItem.Hmsv", metaValue_generic_DateFormatItem_Hmsv },
+            { "islamic.DateFormatItem.Ehms", metaValue_generic_DateFormatItem_Ehms },
+            { "islamic.DateFormatItem.Bhms", metaValue_generic_DateFormatItem_Bhms },
+            { "islamic.DateFormatItem.ms", metaValue_generic_DateFormatItem_ms },
+            { "islamic.DateFormatItem.EHms", metaValue_generic_DateFormatItem_EHms },
+            { "islamic.DateFormatItem.Md", metaValue_generic_DateFormatItem_Md },
+            { "islamic.DateFormatItem.EBhms", metaValue_generic_DateFormatItem_EBhms },
+            { "islamic.DateFormatItem.MMd", metaValue_generic_DateFormatItem_Md },
+            { "islamic.DateFormatItem.Bhm", metaValue_generic_DateFormatItem_Bhm },
+            { "islamic.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
+            { "islamic.DateFormatItem.Hms", metaValue_generic_DateFormatItem_Hms },
+            { "islamic.DateFormatItem.Hmv", metaValue_generic_DateFormatItem_Hmv },
+            { "islamic-civil.DateFormatItem.MMdd", metaValue_generic_DateFormatItem_MMdd },
+            { "islamic-civil.DateFormatItem.hm", metaValue_generic_DateFormatItem_hm },
+            { "islamic-civil.DateFormatItem.Ehm", metaValue_generic_DateFormatItem_Ehm },
+            { "islamic-civil.DateFormatItem.hms", metaValue_generic_DateFormatItem_hms },
+            { "islamic-civil.DateFormatItem.hmv", metaValue_generic_DateFormatItem_hmv },
+            { "islamic-civil.DateFormatItem.hmsv", metaValue_generic_DateFormatItem_hmsv },
+            { "islamic-civil.DateFormatItem.Hm", metaValue_generic_DateFormatItem_Hm },
+            { "islamic-civil.DateFormatItem.EHm", metaValue_generic_DateFormatItem_EHm },
+            { "islamic-civil.DateFormatItem.EBhm", metaValue_generic_DateFormatItem_EBhm },
+            { "islamic-civil.DateFormatItem.Hmsv", metaValue_generic_DateFormatItem_Hmsv },
+            { "islamic-civil.DateFormatItem.Ehms", metaValue_generic_DateFormatItem_Ehms },
+            { "islamic-civil.DateFormatItem.Bhms", metaValue_generic_DateFormatItem_Bhms },
+            { "islamic-civil.DateFormatItem.ms", metaValue_generic_DateFormatItem_ms },
+            { "islamic-civil.DateFormatItem.EHms", metaValue_generic_DateFormatItem_EHms },
+            { "islamic-civil.DateFormatItem.Md", metaValue_generic_DateFormatItem_Md },
+            { "islamic-civil.DateFormatItem.EBhms", metaValue_generic_DateFormatItem_EBhms },
+            { "islamic-civil.DateFormatItem.MMd", metaValue_generic_DateFormatItem_Md },
+            { "islamic-civil.DateFormatItem.Bhm", metaValue_generic_DateFormatItem_Bhm },
+            { "islamic-civil.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
+            { "islamic-civil.DateFormatItem.Hms", metaValue_generic_DateFormatItem_Hms },
+            { "islamic-civil.DateFormatItem.Hmv", metaValue_generic_DateFormatItem_Hmv },
+            { "islamic-umalqura.DateFormatItem.MMdd", metaValue_generic_DateFormatItem_MMdd },
+            { "islamic-umalqura.DateFormatItem.hm", metaValue_generic_DateFormatItem_hm },
+            { "islamic-umalqura.DateFormatItem.Ehm", metaValue_generic_DateFormatItem_Ehm },
+            { "islamic-umalqura.DateFormatItem.hms", metaValue_generic_DateFormatItem_hms },
+            { "islamic-umalqura.DateFormatItem.hmv", metaValue_generic_DateFormatItem_hmv },
+            { "islamic-umalqura.DateFormatItem.hmsv", metaValue_generic_DateFormatItem_hmsv },
+            { "islamic-umalqura.DateFormatItem.Hm", metaValue_generic_DateFormatItem_Hm },
+            { "islamic-umalqura.DateFormatItem.EHm", metaValue_generic_DateFormatItem_EHm },
+            { "islamic-umalqura.DateFormatItem.EBhm", metaValue_generic_DateFormatItem_EBhm },
+            { "islamic-umalqura.DateFormatItem.Hmsv", metaValue_generic_DateFormatItem_Hmsv },
+            { "islamic-umalqura.DateFormatItem.Ehms", metaValue_generic_DateFormatItem_Ehms },
+            { "islamic-umalqura.DateFormatItem.Bhms", metaValue_generic_DateFormatItem_Bhms },
+            { "islamic-umalqura.DateFormatItem.ms", metaValue_generic_DateFormatItem_ms },
+            { "islamic-umalqura.DateFormatItem.EHms", metaValue_generic_DateFormatItem_EHms },
+            { "islamic-umalqura.DateFormatItem.Md", metaValue_generic_DateFormatItem_Md },
+            { "islamic-umalqura.DateFormatItem.EBhms", metaValue_generic_DateFormatItem_EBhms },
+            { "islamic-umalqura.DateFormatItem.MMd", metaValue_generic_DateFormatItem_Md },
+            { "islamic-umalqura.DateFormatItem.Bhm", metaValue_generic_DateFormatItem_Bhm },
+            { "islamic-umalqura.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
+            { "islamic-umalqura.DateFormatItem.Hms", metaValue_generic_DateFormatItem_Hms },
+            { "islamic-umalqura.DateFormatItem.Hmv", metaValue_generic_DateFormatItem_Hmv },
             { "latn.NumberElements",
                 new String[] {
                     ",",
@@ -154,134 +285,6 @@ public class FormatData_sv_FI extends ListResourceBundle {
                     "",
                 }
             },
-            { "generic.DateFormatItem.Hm", metaValue_generic_DateFormatItem_Hm },
-            { "japanese.DateFormatItem.EBhm", metaValue_generic_DateFormatItem_EBhm },
-            { "japanese.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
-            { "generic.DateFormatItem.Ehms", metaValue_generic_DateFormatItem_Ehms },
-            { "roc.DateFormatItem.Hmsv", metaValue_generic_DateFormatItem_Hmsv },
-            { "islamic.DateFormatItem.Bhms", metaValue_generic_DateFormatItem_Bhms },
-            { "buddhist.DateFormatItem.ms", metaValue_generic_DateFormatItem_ms },
-            { "roc.QuarterAbbreviations", metaValue_generic_QuarterAbbreviations },
-            { "islamic.DateFormatItem.EHms", metaValue_generic_DateFormatItem_EHms },
-            { "islamic.DateFormatItem.hmsv", metaValue_generic_DateFormatItem_hmsv },
-            { "islamic.DateFormatItem.Hms", metaValue_generic_DateFormatItem_Hms },
-            { "islamic-civil.DateFormatItem.Hm", metaValue_generic_DateFormatItem_Hm },
-            { "DateFormatItem.EBhm", metaValue_generic_DateFormatItem_EBhm },
-            { "islamic-umalqura.DateFormatItem.EBhms", metaValue_generic_DateFormatItem_EBhms },
-            { "islamic.DateFormatItem.Hm", metaValue_generic_DateFormatItem_Hm },
-            { "buddhist.DateFormatItem.Md", metaValue_generic_DateFormatItem_Md },
-            { "islamic-umalqura.DateFormatItem.Ehms", metaValue_generic_DateFormatItem_Ehms },
-            { "islamic.DateFormatItem.EBhm", metaValue_generic_DateFormatItem_EBhm },
-            { "islamic-civil.DateFormatItem.EHm", metaValue_generic_DateFormatItem_EHm },
-            { "japanese.DateFormatItem.Bhms", metaValue_generic_DateFormatItem_Bhms },
-            { "DateFormatItem.MMd", metaValue_generic_DateFormatItem_Md },
-            { "japanese.DateFormatItem.EHms", metaValue_generic_DateFormatItem_EHms },
-            { "roc.DateFormatItem.Hm", metaValue_generic_DateFormatItem_Hm },
-            { "roc.DateFormatItem.MMdd", metaValue_generic_DateFormatItem_MMdd },
-            { "DateFormatItem.Hmsv", metaValue_generic_DateFormatItem_Hmsv },
-            { "japanese.DateFormatItem.EBhms", metaValue_generic_DateFormatItem_EBhms },
-            { "islamic-civil.DateFormatItem.hm", metaValue_generic_DateFormatItem_hm },
-            { "japanese.DateFormatItem.ms", metaValue_generic_DateFormatItem_ms },
-            { "DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
-            { "islamic.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
-            { "DateFormatItem.Bhm", metaValue_generic_DateFormatItem_Bhm },
-            { "generic.DateFormatItem.EHm", metaValue_generic_DateFormatItem_EHm },
-            { "buddhist.DateFormatItem.Ehms", metaValue_generic_DateFormatItem_Ehms },
-            { "generic.QuarterAbbreviations", metaValue_generic_QuarterAbbreviations },
-            { "islamic.DateFormatItem.Bhm", metaValue_generic_DateFormatItem_Bhm },
-            { "islamic.DateFormatItem.MMd", metaValue_generic_DateFormatItem_Md },
-            { "roc.DateFormatItem.Bhm", metaValue_generic_DateFormatItem_Bhm },
-            { "islamic.QuarterAbbreviations", metaValue_generic_QuarterAbbreviations },
-            { "islamic-civil.DateFormatItem.hmv", metaValue_generic_DateFormatItem_hmv },
-            { "generic.DateFormatItem.hmsv", metaValue_generic_DateFormatItem_hmsv },
-            { "islamic-civil.DateFormatItem.Bhms", metaValue_generic_DateFormatItem_Bhms },
-            { "roc.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
-            { "islamic-civil.DateFormatItem.hms", metaValue_generic_DateFormatItem_hms },
-            { "DateFormatItem.Bhms", metaValue_generic_DateFormatItem_Bhms },
-            { "generic.DateFormatItem.MMdd", metaValue_generic_DateFormatItem_MMdd },
-            { "islamic-civil.DateFormatItem.Ehm", metaValue_generic_DateFormatItem_Ehm },
-            { "islamic.DateFormatItem.hmv", metaValue_generic_DateFormatItem_hmv },
-            { "roc.DateFormatItem.MMd", metaValue_generic_DateFormatItem_Md },
-            { "roc.DateFormatItem.hm", metaValue_generic_DateFormatItem_hm },
-            { "DateFormatItem.EBhms", metaValue_generic_DateFormatItem_EBhms },
-            { "DateFormatItem.Ehms", metaValue_generic_DateFormatItem_Ehms },
-            { "japanese.DateFormatItem.Ehms", metaValue_generic_DateFormatItem_Ehms },
-            { "japanese.QuarterAbbreviations", metaValue_generic_QuarterAbbreviations },
-            { "islamic.DateFormatItem.EHm", metaValue_generic_DateFormatItem_EHm },
-            { "islamic-civil.DateFormatItem.Ehms", metaValue_generic_DateFormatItem_Ehms },
-            { "buddhist.DateFormatItem.EHms", metaValue_generic_DateFormatItem_EHms },
-            { "buddhist.DateFormatItem.Bhms", metaValue_generic_DateFormatItem_Bhms },
-            { "roc.DateFormatItem.hmsv", metaValue_generic_DateFormatItem_hmsv },
-            { "DateFormatItem.Hms", metaValue_generic_DateFormatItem_Hms },
-            { "DateFormatItem.Hmv", metaValue_generic_DateFormatItem_Hmv },
-            { "generic.DateFormatItem.EBhms", metaValue_generic_DateFormatItem_EBhms },
-            { "islamic.DateFormatItem.Ehms", metaValue_generic_DateFormatItem_Ehms },
-            { "islamic.DateFormatItem.EBhms", metaValue_generic_DateFormatItem_EBhms },
-            { "DateFormatItem.ms", metaValue_generic_DateFormatItem_ms },
-            { "islamic-civil.DateFormatItem.Hmv", metaValue_generic_DateFormatItem_Hmv },
-            { "generic.DateFormatItem.Md", metaValue_generic_DateFormatItem_Md },
-            { "islamic-civil.DateFormatItem.Hms", metaValue_generic_DateFormatItem_Hms },
-            { "buddhist.DateFormatItem.hm", metaValue_generic_DateFormatItem_hm },
-            { "islamic.DateFormatItem.Hmv", metaValue_generic_DateFormatItem_Hmv },
-            { "islamic-umalqura.DateFormatItem.ms", metaValue_generic_DateFormatItem_ms },
-            { "DateFormatItem.Ehm", metaValue_generic_DateFormatItem_Ehm },
-            { "islamic.DateFormatItem.hms", metaValue_generic_DateFormatItem_hms },
-            { "DateFormatItem.EHms", metaValue_generic_DateFormatItem_EHms },
-            { "islamic.DateFormatItem.Ehm", metaValue_generic_DateFormatItem_Ehm },
-            { "generic.DateFormatItem.ms", metaValue_generic_DateFormatItem_ms },
-            { "islamic-civil.DateFormatItem.EHms", metaValue_generic_DateFormatItem_EHms },
-            { "islamic.DateFormatItem.hm", metaValue_generic_DateFormatItem_hm },
-            { "islamic-umalqura.DateFormatItem.Md", metaValue_generic_DateFormatItem_Md },
-            { "DateFormatItem.hmv", metaValue_generic_DateFormatItem_hmv },
-            { "DateFormatItem.hms", metaValue_generic_DateFormatItem_hms },
-            { "buddhist.QuarterAbbreviations", metaValue_generic_QuarterAbbreviations },
-            { "islamic-umalqura.DateFormatItem.Hms", metaValue_generic_DateFormatItem_Hms },
-            { "roc.DateFormatItem.Ehm", metaValue_generic_DateFormatItem_Ehm },
-            { "buddhist.DateFormatItem.MMd", metaValue_generic_DateFormatItem_Md },
-            { "islamic-umalqura.DateFormatItem.Hmv", metaValue_generic_DateFormatItem_Hmv },
-            { "islamic-umalqura.DateFormatItem.Hmsv", metaValue_generic_DateFormatItem_Hmsv },
-            { "buddhist.DateFormatItem.Bhm", metaValue_generic_DateFormatItem_Bhm },
-            { "islamic-civil.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
-            { "buddhist.DateFormatItem.Hm", metaValue_generic_DateFormatItem_Hm },
-            { "buddhist.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
-            { "islamic-umalqura.DateFormatItem.hm", metaValue_generic_DateFormatItem_hm },
-            { "buddhist.DateFormatItem.EBhm", metaValue_generic_DateFormatItem_EBhm },
-            { "islamic-civil.DateFormatItem.Bhm", metaValue_generic_DateFormatItem_Bhm },
-            { "islamic-civil.DateFormatItem.EBhm", metaValue_generic_DateFormatItem_EBhm },
-            { "DateFormatItem.EHm", metaValue_generic_DateFormatItem_EHm },
-            { "islamic-civil.DateFormatItem.MMd", metaValue_generic_DateFormatItem_Md },
-            { "japanese.DateFormatItem.hm", metaValue_generic_DateFormatItem_hm },
-            { "generic.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
-            { "generic.DateFormatItem.Hmsv", metaValue_generic_DateFormatItem_Hmsv },
-            { "islamic-civil.DateFormatItem.ms", metaValue_generic_DateFormatItem_ms },
-            { "DateFormatItem.Md", metaValue_generic_DateFormatItem_Md },
-            { "japanese.DateFormatItem.EHm", metaValue_generic_DateFormatItem_EHm },
-            { "buddhist.DateFormatItem.Hmsv", metaValue_generic_DateFormatItem_Hmsv },
-            { "generic.DateFormatItem.Bhm", metaValue_generic_DateFormatItem_Bhm },
-            { "roc.DateFormatItem.Hms", metaValue_generic_DateFormatItem_Hms },
-            { "islamic.DateFormatItem.ms", metaValue_generic_DateFormatItem_ms },
-            { "roc.DateFormatItem.Md", metaValue_generic_DateFormatItem_Md },
-            { "generic.DateFormatItem.MMd", metaValue_generic_DateFormatItem_Md },
-            { "roc.DateFormatItem.Hmv", metaValue_generic_DateFormatItem_Hmv },
-            { "islamic-umalqura.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
-            { "roc.DateFormatItem.EHm", metaValue_generic_DateFormatItem_EHm },
-            { "roc.DateFormatItem.ms", metaValue_generic_DateFormatItem_ms },
-            { "islamic.DateFormatItem.Md", metaValue_generic_DateFormatItem_Md },
-            { "japanese.DateFormatItem.MMdd", metaValue_generic_DateFormatItem_MMdd },
-            { "islamic-umalqura.DateFormatItem.MMd", metaValue_generic_DateFormatItem_Md },
-            { "islamic-umalqura.DateFormatItem.MMdd", metaValue_generic_DateFormatItem_MMdd },
-            { "roc.DateFormatItem.Ehms", metaValue_generic_DateFormatItem_Ehms },
-            { "islamic-umalqura.DateFormatItem.Bhm", metaValue_generic_DateFormatItem_Bhm },
-            { "japanese.DateFormatItem.hmv", metaValue_generic_DateFormatItem_hmv },
-            { "generic.DateFormatItem.EBhm", metaValue_generic_DateFormatItem_EBhm },
-            { "roc.DateFormatItem.EBhms", metaValue_generic_DateFormatItem_EBhms },
-            { "buddhist.DateFormatItem.Hms", metaValue_generic_DateFormatItem_Hms },
-            { "japanese.DateFormatItem.Hm", metaValue_generic_DateFormatItem_Hm },
-            { "islamic-civil.DateFormatItem.Hmsv", metaValue_generic_DateFormatItem_Hmsv },
-            { "japanese.DateFormatItem.Ehm", metaValue_generic_DateFormatItem_Ehm },
-            { "islamic-umalqura.DateFormatItem.hmsv", metaValue_generic_DateFormatItem_hmsv },
-            { "buddhist.DateFormatItem.Hmv", metaValue_generic_DateFormatItem_Hmv },
-            { "roc.DateFormatItem.hms", metaValue_generic_DateFormatItem_hms },
             { "latn.NumberPatterns",
                 new String[] {
                     "#,##0.###",
@@ -290,9 +293,6 @@ public class FormatData_sv_FI extends ListResourceBundle {
                     "#,##0.00\u00a0\u00a4",
                 }
             },
-            { "roc.DateFormatItem.hmv", metaValue_generic_DateFormatItem_hmv },
-            { "QuarterAbbreviations", metaValue_generic_QuarterAbbreviations },
-            { "japanese.DateFormatItem.hms", metaValue_generic_DateFormatItem_hms },
         };
         return data;
     }
