@@ -32,10 +32,14 @@ import sun.util.locale.provider.LocaleProviderAdapter;
 
 public class CLDRBaseLocaleDataMetaInfo implements LocaleDataMetaInfo {
     private static final Map<String, String> resourceNameToLocales = HashMap.newHashMap(1);
-    private static final Map<Locale, String[]> parentLocalesMap = HashMap.newHashMap(8);
-    private static final Map<String, String> languageAliasMap = HashMap.newHashMap(204);
+    private static final Map<Locale, String[]> parentLocalesMap = HashMap.newHashMap(9);
+    private static final Map<String, String> languageAliasMap = HashMap.newHashMap(208);
 
     static {
+        parentLocalesMap.put(Locale.forLanguageTag("fr-HT"),
+            new String[] {
+                "", "ht", 
+            });
         resourceNameToLocales.put("AvailableLocales",
             " en en-Latn-US en-US en-US-POSIX");
         parentLocalesMap.put(Locale.forLanguageTag("es-419"),
@@ -236,13 +240,16 @@ public class CLDRBaseLocaleDataMetaInfo implements LocaleDataMetaInfo {
         languageAliasMap.put("guv", "duz");
         languageAliasMap.put("oun", "vaj");
         languageAliasMap.put("ais", "ami");
+        languageAliasMap.put("smd", "kmb");
         languageAliasMap.put("jw", "jv");
         languageAliasMap.put("und-aaland", "und-AX");
         languageAliasMap.put("izi", "eza");
         languageAliasMap.put("ncp", "kdz");
         languageAliasMap.put("blg", "iba");
+        languageAliasMap.put("snb", "iba");
         languageAliasMap.put("cnr", "sr-ME");
         languageAliasMap.put("yiy", "yrm");
+        languageAliasMap.put("ajt", "aeb");
         languageAliasMap.put("nts", "pij");
         languageAliasMap.put("art-lojban", "jbo");
         languageAliasMap.put("und-lojban", "und");
@@ -262,6 +269,7 @@ public class CLDRBaseLocaleDataMetaInfo implements LocaleDataMetaInfo {
         languageAliasMap.put("ggr", "gtu");
         languageAliasMap.put("i-tay", "tay");
         languageAliasMap.put("rmr", "emx");
+        languageAliasMap.put("lak", "ksp");
         languageAliasMap.put("drh", "mn");
         languageAliasMap.put("mo", "ro");
         languageAliasMap.put("drr", "kzk");
@@ -298,7 +306,7 @@ public class CLDRBaseLocaleDataMetaInfo implements LocaleDataMetaInfo {
     }
 
     private static class TZCanonicalIDMapHolder {
-        static final Map<String, String> tzCanonicalIDMap = HashMap.newHashMap(460);
+        static final Map<String, String> tzCanonicalIDMap = HashMap.newHashMap(461);
         static {
             tzCanonicalIDMap.put("fmksa", "Pacific/Kosrae");
             tzCanonicalIDMap.put("ruyks", "Asia/Yakutsk");
@@ -481,6 +489,7 @@ public class CLDRBaseLocaleDataMetaInfo implements LocaleDataMetaInfo {
             tzCanonicalIDMap.put("ommct", "Asia/Muscat");
             tzCanonicalIDMap.put("lrmlw", "Africa/Monrovia");
             tzCanonicalIDMap.put("imdgs", "Europe/Isle_of_Man");
+            tzCanonicalIDMap.put("mxcjs", "America/Ciudad_Juarez");
             tzCanonicalIDMap.put("npktm", "Asia/Katmandu");
             tzCanonicalIDMap.put("Asia/Kathmandu", "Asia/Katmandu");
             tzCanonicalIDMap.put("robuh", "Europe/Bucharest");
