@@ -450,7 +450,7 @@ public class CurrencyNames_nl extends OpenListResourceBundle {
             { "fjd", "Fiji-dollar" },
             { "fkp", "Falklandeilands pond" },
             { "frf", "Franse franc" },
-            { "gbp", "Brits pond" },
+            { "gbp", "Britse pond" },
             { "gek", "Georgische kupon larit" },
             { "gel", "Georgische lari" },
             { "ghc", "Ghanese cedi (1979\u20132007)" },
