@@ -394,7 +394,7 @@ public class CurrencyNames_zh_Hant extends OpenListResourceBundle {
             { "brb", "\u5df4\u897f\u514b\u9b6f\u85a9\u591a\u8fb2\u74e6 (1967\u20131986)" },
             { "brc", "\u5df4\u897f\u514b\u9b6f\u8cfd\u7f85 (1986\u20131989)" },
             { "bre", "\u5df4\u897f\u514b\u9b6f\u8cfd\u7f85 (1990\u20131993)" },
-            { "brl", "\u5df4\u897f\u91cc\u62c9" },
+            { "brl", "\u5df4\u897f\u96f7\u4e9e\u723e" },
             { "brn", "\u5df4\u897f\u514b\u5982\u723e\u9054\u8fb2\u74e6" },
             { "brr", "\u5df4\u897f\u514b\u9b6f\u8cfd\u7f85 (1993\u20131994)" },
             { "brz", "\u5df4\u897f\u514b\u9b6f\u8cfd\u7f85 (1942 \u20131967)" },
