@@ -556,13 +556,16 @@ public class LocaleNames_bs extends OpenListResourceBundle {
             { "ale", "aleutski" },
             { "alt", "ju\u017eni altai" },
             { "ang", "staroengleski" },
+            { "ann", "obolo" },
             { "anp", "angika" },
             { "arc", "aramejski" },
             { "arn", "mapu\u0161ki" },
             { "arp", "arapaho" },
+            { "ars", "najdski arapski" },
             { "arw", "aravak" },
             { "asa", "asu" },
             { "ast", "asturijski" },
+            { "atj", "atikamekw" },
             { "awa", "avadhi" },
             { "bal", "balu\u010di" },
             { "ban", "balinezijski" },
@@ -604,10 +607,18 @@ public class LocaleNames_bs extends OpenListResourceBundle {
             { "chr", "\u010deroki" },
             { "chy", "\u010dejenski" },
             { "ckb", "centralnokurdski" },
+            { "clc", "chilcotin" },
             { "cop", "koptski" },
+            { "crg", "mi\u010dif" },
             { "crh", "krimski turski" },
+            { "crj", "jugoisto\u010dni kri" },
+            { "crk", "ravni\u010darski kri" },
+            { "crl", "sjeveroisto\u010dni kri" },
+            { "crm", "mus kri" },
+            { "crr", "sjevernokarolin\u0161ki algonkvijski" },
             { "crs", "seselva kreolski francuski" },
             { "csb", "ka\u0161ubijanski" },
+            { "csw", "mo\u010dvarni kri" },
             { "dak", "dakota" },
             { "dar", "dargva" },
             { "dav", "taita" },
@@ -658,13 +669,16 @@ public class LocaleNames_bs extends OpenListResourceBundle {
             { "gwi", "gvi\u010din" },
             { "hai", "haida" },
             { "haw", "havajski" },
+            { "hax", "ju\u017eni haida" },
             { "hil", "hiligajnon" },
             { "hit", "hitite" },
             { "hmn", "hmong" },
             { "hsb", "gornjolu\u017ei\u010dkosrpski" },
             { "hup", "hupa" },
+            { "hur", "halkomelem" },
             { "iba", "iban" },
             { "ibb", "ibibio" },
+            { "ikt", "zapadnokanadski inuktitut" },
             { "ilo", "iloko" },
             { "inh", "ingu\u0161etski" },
             { "jbo", "lojban" },
@@ -704,17 +718,20 @@ public class LocaleNames_bs extends OpenListResourceBundle {
             { "ksh", "kelnski" },
             { "kum", "kumik" },
             { "kut", "kutenai" },
+            { "kwk", "kvakvala" },
             { "lad", "ladino" },
             { "lag", "langi" },
             { "lah", "landa" },
             { "lam", "lamba" },
             { "lez", "lezgijski" },
             { "lij", "ligurski" },
+            { "lil", "liluet" },
             { "lkt", "lakota" },
             { "lol", "mongo" },
             { "lou", "luizijana kreolski" },
             { "loz", "lozi" },
             { "lrc", "sjeverni luri" },
+            { "lsm", "samia" },
             { "lua", "luba-lulua" },
             { "lui", "luiseno" },
             { "lun", "lunda" },
@@ -741,6 +758,7 @@ public class LocaleNames_bs extends OpenListResourceBundle {
             { "min", "minangkabau" },
             { "mnc", "man\u010du" },
             { "mni", "manipuri" },
+            { "moe", "innu-aimun" },
             { "moh", "mohavk" },
             { "mos", "mosi" },
             { "mua", "mundang" },
@@ -769,6 +787,11 @@ public class LocaleNames_bs extends OpenListResourceBundle {
             { "nyn", "njankole" },
             { "nyo", "njoro" },
             { "nzi", "nzima" },
+            { "ojb", "sjeverozapadni ojibva" },
+            { "ojc", "centralni ojibva" },
+            { "ojs", "od\u017ei kri" },
+            { "ojw", "zapadni ojibva" },
+            { "oka", "okanagan" },
             { "osa", "osage" },
             { "ota", "osmanski turski" },
             { "pag", "pangasinski" },
@@ -779,7 +802,9 @@ public class LocaleNames_bs extends OpenListResourceBundle {
             { "pcm", "nigerijski pid\u017ein" },
             { "peo", "staroperzijski" },
             { "phn", "feni\u010danski" },
+            { "pis", "pid\u017ein" },
             { "pon", "ponpejski" },
+            { "pqm", "malisit-pasamakvodi" },
             { "prg", "pruski" },
             { "pro", "staroprovansalski" },
             { "quc", "ki\u010de" },
@@ -811,6 +836,7 @@ public class LocaleNames_bs extends OpenListResourceBundle {
             { "shn", "\u0161an" },
             { "shu", "\u010dadski arapski" },
             { "sid", "sidamo" },
+            { "slh", "ju\u017eni la\u0161utsid" },
             { "sma", "ju\u017eni sami" },
             { "smj", "lule sami" },
             { "smn", "inari sami" },
@@ -820,16 +846,20 @@ public class LocaleNames_bs extends OpenListResourceBundle {
             { "srn", "srananski tongo" },
             { "srr", "serer" },
             { "ssy", "saho" },
+            { "str", "ravni\u010darski sali\u0161ki" },
             { "suk", "sukuma" },
             { "sus", "susu" },
             { "sux", "sumerski" },
             { "swb", "komorski" },
             { "syc", "klasi\u010dni sirijski" },
             { "syr", "sirijski" },
+            { "tce", "ju\u017eni tu\u010doni" },
             { "tem", "timne" },
             { "teo", "teso" },
             { "ter", "tereno" },
             { "tet", "tetum" },
+            { "tgx", "tagi\u0161" },
+            { "tht", "tahltanski" },
             { "tig", "tigre" },
             { "tiv", "tiv" },
             { "tkl", "tokelau" },
@@ -837,9 +867,11 @@ public class LocaleNames_bs extends OpenListResourceBundle {
             { "tli", "tlingit" },
             { "tmh", "tama\u0161ek" },
             { "tog", "njasa tonga" },
+            { "tok", "toki pona" },
             { "tpi", "tok pisin" },
             { "trv", "taroko" },
             { "tsi", "tsim\u0161ian" },
+            { "ttm", "sjeverni tu\u010doni" },
             { "tum", "tumbuka" },
             { "tvl", "tuvalu" },
             { "twq", "tasavak" },
@@ -850,6 +882,7 @@ public class LocaleNames_bs extends OpenListResourceBundle {
             { "umb", "umbundu" },
             { "und", "nepoznati jezik" },
             { "vai", "vai" },
+            { "vec", "venecijanski" },
             { "vot", "votski" },
             { "vun", "vunjo" },
             { "wae", "valser" },
@@ -857,12 +890,14 @@ public class LocaleNames_bs extends OpenListResourceBundle {
             { "war", "varej" },
             { "was", "va\u0161o" },
             { "wbp", "varlpiri" },
+            { "wuu", "Wu kineski" },
             { "xal", "kalmik" },
             { "xog", "soga" },
             { "yao", "jao" },
             { "yap", "jape\u0161ki" },
             { "yav", "jangben" },
             { "ybb", "jemba" },
+            { "yrl", "ningatu" },
             { "yue", "kantonski" },
             { "zap", "zapote\u010dki" },
             { "zbl", "blis simboli" },
@@ -893,7 +928,7 @@ public class LocaleNames_bs extends OpenListResourceBundle {
             { "Bugi", "buginsko pismo" },
             { "Buhd", "buhidsko pismo" },
             { "Cakm", "\u010dakmansko pismo" },
-            { "Cans", "Ujedinjeni kanadski aborid\u017einski slogovi" },
+            { "Cans", "ujedinjeni kanadski aborid\u017einski slogovi" },
             { "Cari", "karijsko pismo" },
             { "Cham", "\u010damsko pismo" },
             { "Cher", "\u010deroki pismo" },
@@ -908,7 +943,7 @@ public class LocaleNames_bs extends OpenListResourceBundle {
             { "Diak", "dives akuru pismo" },
             { "Dogr", "dogra pismo" },
             { "Dsrt", "dezeret pismo" },
-            { "Dupl", "Duploaje stenografija" },
+            { "Dupl", "duploaje stenografija" },
             { "Egyd", "egipatsko narodno pismo" },
             { "Egyh", "egipatsko hijeratsko pismo" },
             { "Egyp", "egipatski hijeroglifi" },
@@ -947,6 +982,7 @@ public class LocaleNames_bs extends OpenListResourceBundle {
             { "Jurc", "jurchen pismo" },
             { "Kali", "kajah li pismo" },
             { "Kana", "pismo katakana" },
+            { "Kawi", "kavi pismo" },
             { "Khar", "karo\u0161ti pismo" },
             { "Khmr", "kmersko pismo" },
             { "Khoj", "khojki pismo" },
@@ -986,6 +1022,7 @@ public class LocaleNames_bs extends OpenListResourceBundle {
             { "Mtei", "meitei majek pismo" },
             { "Mult", "multani pismo" },
             { "Mymr", "mijanmarsko pismo" },
+            { "Nagm", "nag mundari pismo" },
             { "Nand", "nandinagari pismo" },
             { "Narb", "staro sjevernoarapsko pismo" },
             { "Nbat", "nabatejsko pismo" },
@@ -1095,6 +1132,8 @@ public class LocaleNames_bs extends OpenListResourceBundle {
             { "%%BISKE", "San \u0110or\u0111ijo/Bila dijalekt" },
             { "%%BOONT", "Buntling" },
             { "%%CORNU", "Cornu" },
+            { "%%GALLO", "Gallo" },
+            { "%%JAUER", "Jauer" },
             { "%%KKCOR", "Uobi\u010dajena ortografija" },
             { "%%KSCOR", "Standardna ortografija" },
             { "%%LIPAW", "Lipovac dijalekt rezijanski" },
@@ -1102,7 +1141,10 @@ public class LocaleNames_bs extends OpenListResourceBundle {
             { "%%NJIVA", "Gnjiva/Njiva dijalekt" },
             { "%%NULIK", "Moderni volapuk" },
             { "%%OSOJS", "Oseako/Osojane dijalekt" },
+            { "%%PEANO", "Peano" },
             { "%%POSIX", "Ra\u010dunarski jezik" },
+            { "%%PUTER", "Puter" },
+            { "%%RIGIK", "Rigik" },
             { "%%ROZAJ", "Rezijan" },
             { "%%SAAHO", "Saho" },
             { "%%SOLBA", "Stolvica/Solbica dijalekt" },
@@ -1120,12 +1162,17 @@ public class LocaleNames_bs extends OpenListResourceBundle {
             { "%%EKAVSK", "srpski s ekavskim izgovorom" },
             { "%%FONIPA", "IPA fonetika" },
             { "%%FONUPA", "UPA fonetika" },
+            { "%%GASCON", "Gascon" },
+            { "%%GRITAL", "Grital" },
             { "%%NDYUKA", "Ndjuka dijalekt" },
+            { "%%NICARD", "Nicard" },
             { "%%PAMAKA", "Pamaka dijalekt" },
             { "%%PINYIN", "Pinjinska romanizacija" },
             { "%%SCOUSE", "Skauz" },
+            { "%%SIMPLE", "Simple" },
             { "%%TARASK", "Taraskijevica ortografija" },
             { "%%UCRCOR", "Ujedinjena revidirana ortografija" },
+            { "%%ULSTER", "Ulster" },
             { "%%UNIFON", "Fonetska abeceda Unifon" },
             { "%%ABL1943", "ortografska pravila iz 1943." },
             { "%%AKUAPEM", "akuapem" },
@@ -1137,11 +1184,24 @@ public class LocaleNames_bs extends OpenListResourceBundle {
             { "%%BAUDDHA", "buda" },
             { "%%BOHORIC", "bohori\u010dica" },
             { "%%EMODENG", "Rani moderni engleski" },
+            { "%%FONNAPA", "Fonnapa" },
+            { "%%GRCLASS", "Grclass" },
+            { "%%GRMISTR", "Grmistr" },
             { "%%HEPBURN", "Hepburnova romanizacija" },
+            { "%%ITIHASA", "Itihasa" },
+            { "%%LAUKIKA", "Laukika" },
+            { "%%LEMOSIN", "Lemosin" },
             { "%%METELKO", "Metel\u010dica" },
             { "%%MONOTON", "Monotonik" },
+            { "%%PAHAWH2", "Pahawh2" },
+            { "%%PAHAWH3", "Pahawh3" },
+            { "%%PAHAWH4", "Pahawh4" },
             { "%%POLYTON", "Politonik" },
+            { "%%PROVENC", "Provenc" },
             { "%%REVISED", "Revidirana ortografija" },
+            { "%%SURSILV", "Sursilv" },
+            { "%%SUTSILV", "Sutsilv" },
+            { "%%VAIDIKA", "Vaidika" },
             { "%%1606NICT", "francuski iz kasnog srednjeg vijeka do 1606." },
             { "%%1694ACAD", "rani moderni francuski" },
             { "%%1959ACAD", "Akademski" },
@@ -1150,11 +1210,31 @@ public class LocaleNames_bs extends OpenListResourceBundle {
             { "%%BISCAYAN", "biskajanski" },
             { "%%BORNHOLM", "Bornholm" },
             { "%%COLB1945", "Portugalsko-brazilski ortografski kongres iz 1945." },
+            { "%%FONKIRSH", "Fonkirsh" },
+            { "%%FONXSAMP", "Fonxsamp" },
+            { "%%HOGNORSK", "Hognorsk" },
+            { "%%HSISTEMO", "Hsistemo" },
             { "%%IJEKAVSK", "srpski s ijekavskim izgovorom" },
+            { "%%IVANCHOV", "Ivanchov" },
+            { "%%JYUTPING", "Jyutping" },
+            { "%%KOCIEWIE", "Kociewie" },
+            { "%%LENGADOC", "Lengadoc" },
+            { "%%LUNA1918", "Luna1918" },
+            { "%%NEWFOUND", "Newfound" },
             { "%%OXENDICT", "Pravopis Oksforsdskog rje\u010dnika engleskog jezika" },
+            { "%%PETR1708", "Petr1708" },
             { "%%SCOTLAND", "\u0160kotski standardni engleski" },
+            { "%%SPANGLIS", "Spanglis" },
+            { "%%SURMIRAN", "Surmiran" },
+            { "%%SYNNEJYL", "Synnejyl" },
+            { "%%TONGYONG", "Tongyong" },
+            { "%%TUNUMIIT", "Tunumiit" },
             { "%%VALENCIA", "Valencijski" },
+            { "%%VALLADER", "Vallader" },
+            { "%%VECDRUKA", "Vecdruka" },
+            { "%%VIVARAUP", "Vivaraup" },
             { "%%WADEGILE", "Vejd-\u017dajl romanizacija" },
+            { "%%XSISTEMO", "Xsistemo" },
             { "type.ca.roc", "kalendar Republike Kine" },
             { "type.co.eor", "Evropska pravila sortiranja" },
             { "type.hc.h11", "12-satni format (0\u201311)" },
@@ -1188,6 +1268,7 @@ public class LocaleNames_bs extends OpenListResourceBundle {
             { "type.nu.java", "javanski brojevi" },
             { "type.nu.jpan", "japanski brojevi" },
             { "type.nu.kali", "kajah li brojevi" },
+            { "type.nu.kawi", "kawi cifre" },
             { "type.nu.khmr", "kmerski brojevi" },
             { "type.nu.knda", "brojevi pisma kanada" },
             { "type.nu.lana", "tai tam hora brojevi" },
@@ -1201,6 +1282,7 @@ public class LocaleNames_bs extends OpenListResourceBundle {
             { "type.nu.mroo", "mro cifre" },
             { "type.nu.mtei", "mitei majek cifre" },
             { "type.nu.mymr", "mijanmarski brojevi" },
+            { "type.nu.nagm", "nag mundari cifre" },
             { "type.nu.nkoo", "n\u2019ko cifre" },
             { "type.nu.olck", "ol \u010diki cifre" },
             { "type.nu.orya", "orijski brojevi" },
@@ -1219,6 +1301,7 @@ public class LocaleNames_bs extends OpenListResourceBundle {
             { "type.nu.thai", "tajlandski brojevi" },
             { "type.nu.tibt", "tibetanski brojevi" },
             { "type.nu.tirh", "tirhutanske cifre" },
+            { "type.nu.tnsa", "tangsa cifre" },
             { "type.nu.vaii", "Vai cifre" },
             { "type.nu.wara", "warang citi cifre" },
             { "type.nu.wcho", "van\u010do cifre" },
@@ -1289,7 +1372,7 @@ public class LocaleNames_bs extends OpenListResourceBundle {
             { "type.ca.islamic-tbla", "islamski kalendar, tabelarni, astronomska epoha" },
             { "type.ca.islamic-civil", "islamski civilni kalendar, tabelarni" },
             { "type.ca.islamic-umalqura", "islamski kalendar, Umm al-Qura" },
-            { "type.ca.ethiopic-amete-alem", "Etiopski kalendar \"Amete Alem\"" },
+            { "type.ca.ethiopic-amete-alem", "etiopski kalendar \"Amete Alem\"" },
         };
         return data;
     }
