@@ -93,7 +93,7 @@ public class TimeZoneNames_fil extends TimeZoneNamesBundle {
         final String[] Cuba = new String[] {
                "Standard na Oras sa Cuba",
                "",
-               "Daylight Time sa Cuba",
+               "Daylight na Oras sa Cuba",
                "",
                "Oras sa Cuba",
                "",
@@ -275,7 +275,7 @@ public class TimeZoneNames_fil extends TimeZoneNamesBundle {
                "",
             };
         final String[] Yukon = new String[] {
-               "Yukon Time",
+               "Oras sa Yukon",
                "",
                "",
                "",
@@ -597,7 +597,7 @@ public class TimeZoneNames_fil extends TimeZoneNamesBundle {
         final String[] Atlantic = new String[] {
                "Standard na Oras sa Atlantiko",
                "",
-               "Daylight Time sa Atlantiko",
+               "Daylight na Oras sa Atlantiko",
                "",
                "Oras sa Atlantiko",
                "",
@@ -925,7 +925,7 @@ public class TimeZoneNames_fil extends TimeZoneNamesBundle {
         final String[] Newfoundland = new String[] {
                "Standard na Oras sa Newfoundland",
                "",
-               "Daylight Time sa Newfoundland",
+               "Daylight na Oras sa Newfoundland",
                "",
                "Oras sa Newfoundland",
                "",
@@ -1029,7 +1029,7 @@ public class TimeZoneNames_fil extends TimeZoneNamesBundle {
         final String[] Mexico_Pacific = new String[] {
                "Standard na Oras sa Pasipiko ng Mexico",
                "",
-               "Daylight Time sa Pasipiko ng Mexico",
+               "Daylight na Oras sa Pasipiko ng Mexico",
                "",
                "Oras sa Pasipiko ng Mexico",
                "",
@@ -1043,27 +1043,27 @@ public class TimeZoneNames_fil extends TimeZoneNamesBundle {
                "",
             };
         final String[] America_Central = new String[] {
-               "Sentral na Standard na Oras",
+               "Sentral na Standard na Oras sa North America",
                "",
-               "Sentral na Daylight Time",
+               "Sentral na Daylight na Oras sa North America",
                "",
-               "Sentral na Oras",
+               "Sentral na Oras sa North America",
                "",
             };
         final String[] America_Eastern = new String[] {
-               "Eastern na Standard na Oras",
+               "Standard na Oras sa Silangan ng Hilangang Amerika",
                "",
-               "Eastern Daylight Time",
+               "Daylight na Oras sa Silangan ng Hilagang Amerika",
                "",
-               "Eastern Time",
+               "Oras sa Silangan ng Hilagang Amerika",
                "",
             };
         final String[] America_Pacific = new String[] {
-               "Standard na Oras sa Pasipiko",
+               "Standard na Oras sa Pasipiko sa Hilagang Amerika",
                "",
-               "Daylight Time sa Pasipiko",
+               "Daylight na Oras sa Pasipiko sa Hilagang Amerika",
                "",
-               "Oras sa Pasipiko",
+               "Oras sa Pasipiko sa HIlagang Amerika",
                "",
             };
         final String[] French_Southern = new String[] {
@@ -1101,17 +1101,17 @@ public class TimeZoneNames_fil extends TimeZoneNamesBundle {
         final String[] Pierre_Miquelon = new String[] {
                "Standard na Oras sa Saint Pierre & Miquelon",
                "",
-               "Daylight Time sa Saint Pierre & Miquelon",
+               "Daylight na Oras sa Saint Pierre & Miquelon",
                "",
                "Oras sa Saint Pierre & Miquelon",
                "",
             };
         final String[] America_Mountain = new String[] {
-               "Standard na Oras sa Bundok",
+               "Standard na Oras sa Bundok sa Hilagang Amerika",
                "",
-               "Daylight Time sa Bundok",
+               "Daylight na Oras sa Bundok sa Hilagang Amerika",
                "",
-               "Oras sa Bundok",
+               "Oras sa Bundok sa Hilagang Amerika",
                "",
             };
         final String[] Marshall_Islands = new String[] {
@@ -1125,7 +1125,7 @@ public class TimeZoneNames_fil extends TimeZoneNamesBundle {
         final String[] Mexico_Northwest = new String[] {
                "Standard na Oras sa Hilagang-kanlurang Mexico",
                "",
-               "Daylight Time sa Hilagang-kanlurang Mexico",
+               "Daylight na Oras sa Hilagang-kanlurang Mexico",
                "",
                "Oras sa Hilagang-kanlurang Mexico",
                "",
@@ -1279,7 +1279,6 @@ public class TimeZoneNames_fil extends TimeZoneNamesBundle {
             { "Asia/Hovd", Hovd },
             { "Asia/Omsk", Omsk },
             { "Asia/Oral", Kazakhstan_Western },
-            { "Asia/Amman", Europe_Eastern },
             { "Asia/Aqtau", Kazakhstan_Western },
             { "Asia/Chita", Yakutsk },
             { "Asia/Dhaka", Bangladesh },
@@ -1375,7 +1374,6 @@ public class TimeZoneNames_fil extends TimeZoneNamesBundle {
             { "America/Thule", Atlantic },
             { "Asia/Ashgabat", Turkmenistan },
             { "Asia/Calcutta", India },
-            { "Asia/Damascus", Europe_Eastern },
             { "Asia/Dushanbe", Tajikistan },
             { "Asia/Jayapura", Indonesia_Eastern },
             { "Asia/Katmandu", Nepal },
@@ -1685,6 +1683,7 @@ public class TimeZoneNames_fil extends TimeZoneNamesBundle {
             { "Antarctica/Macquarie", Australia_Eastern },
             { "Pacific/Port_Moresby", Papua_New_Guinea },
             { "America/Cambridge_Bay", America_Mountain },
+            { "America/Ciudad_Juarez", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
             { "America/Indiana/Vevay", America_Eastern },
             { "America/Lower_Princes", Atlantic },
