@@ -66,6 +66,14 @@ import sun.util.resources.TimeZoneNamesBundle;
 public class TimeZoneNames_hi_Latn extends TimeZoneNamesBundle {
     @Override
     protected final Object[][] getContents() {
+        final String[] Reunion = new String[] {
+               "Reunion Time",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] EMPTY_ZONE = new String[] {
                "",
                "",
@@ -161,6 +169,7 @@ public class TimeZoneNames_hi_Latn extends TimeZoneNamesBundle {
             { "America/Nassau", America_Eastern },
             { "America/Panama", America_Eastern },
             { "America/Regina", America_Central },
+            { "Indian/Reunion", Reunion },
             { "America/Creston", America_Mountain },
             { "America/Detroit", America_Eastern },
             { "America/Iqaluit", America_Eastern },
@@ -201,6 +210,7 @@ public class TimeZoneNames_hi_Latn extends TimeZoneNamesBundle {
             { "America/Indiana/Knox", America_Central },
             { "America/Rankin_Inlet", America_Central },
             { "America/Cambridge_Bay", America_Mountain },
+            { "America/Ciudad_Juarez", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
             { "America/Indiana/Vevay", America_Eastern },
             { "America/Swift_Current", America_Central },
@@ -249,7 +259,6 @@ public class TimeZoneNames_hi_Latn extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Taipei", "Taipei" },
             { "timezone.excity.Asia/Tehran", "Tehran" },
             { "timezone.excity.Asia/Urumqi", "Urumqi" },
-            { "timezone.excity.Europe/Kiev", "Kiev" },
             { "timezone.excity.Europe/Oslo", "Oslo" },
             { "timezone.excity.Europe/Riga", "Riga" },
             { "timezone.excity.Europe/Rome", "Rome" },
@@ -317,7 +326,6 @@ public class TimeZoneNames_hi_Latn extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Damascus", "Damascus" },
             { "timezone.excity.Asia/Dushanbe", "Dushanbe" },
             { "timezone.excity.Asia/Jayapura", "Jayapura" },
-            { "timezone.excity.Asia/Katmandu", "Katmandu" },
             { "timezone.excity.Asia/Khandyga", "Khandyga" },
             { "timezone.excity.Asia/Makassar", "Makassar" },
             { "timezone.excity.Asia/Qostanay", "Qostanay" },
@@ -420,7 +428,6 @@ public class TimeZoneNames_hi_Latn extends TimeZoneNamesBundle {
             { "timezone.excity.America/Creston", "Creston" },
             { "timezone.excity.America/Curacao", "Curacao" },
             { "timezone.excity.America/Detroit", "Detroit" },
-            { "timezone.excity.America/Godthab", "Godthab" },
             { "timezone.excity.America/Grenada", "Grenada" },
             { "timezone.excity.America/Halifax", "Halifax" },
             { "timezone.excity.America/Iqaluit", "Iqaluit" },
@@ -473,7 +480,6 @@ public class TimeZoneNames_hi_Latn extends TimeZoneNamesBundle {
             { "timezone.excity.America/Resolute", "Resolute" },
             { "timezone.excity.America/Santarem", "Santarem" },
             { "timezone.excity.America/Santiago", "Santiago" },
-            { "timezone.excity.America/St_Johns", "St Johns" },
             { "timezone.excity.America/Winnipeg", "Winnipeg" },
             { "timezone.excity.Antarctica/Casey", "Casey" },
             { "timezone.excity.Antarctica/Davis", "Davis" },
@@ -486,7 +492,6 @@ public class TimeZoneNames_hi_Latn extends TimeZoneNamesBundle {
             { "timezone.excity.Atlantic/Bermuda", "Bermuda" },
             { "timezone.excity.Atlantic/Madeira", "Madeira" },
             { "timezone.excity.Atlantic/Stanley", "Stanley" },
-            { "timezone.excity.Australia/Currie", "Currie" },
             { "timezone.excity.Australia/Darwin", "Darwin" },
             { "timezone.excity.Australia/Hobart", "Hobart" },
             { "timezone.excity.Australia/Sydney", "Sydney" },
@@ -539,7 +544,6 @@ public class TimeZoneNames_hi_Latn extends TimeZoneNamesBundle {
             { "timezone.excity.Europe/San_Marino", "San Marino" },
             { "timezone.excity.Europe/Simferopol", "Simferopol" },
             { "timezone.excity.Europe/Zaporozhye", "Zaporozhye" },
-            { "timezone.excity.Pacific/Enderbury", "Enderbury" },
             { "timezone.excity.Pacific/Galapagos", "Galapagos" },
             { "timezone.excity.Pacific/Kwajalein", "Kwajalein" },
             { "timezone.excity.Pacific/Marquesas", "Marquesas" },
@@ -597,20 +601,16 @@ public class TimeZoneNames_hi_Latn extends TimeZoneNamesBundle {
             { "timezone.excity.America/Campo_Grande", "Campo Grande" },
             { "timezone.excity.America/Danmarkshavn", "Danmarkshavn" },
             { "timezone.excity.America/Dawson_Creek", "Dawson Creek" },
-            { "timezone.excity.America/Indiana/Knox", "Indiana/Knox" },
             { "timezone.excity.America/Indianapolis", "Indianapolis" },
             { "timezone.excity.America/Punta_Arenas", "Punta Arenas" },
             { "timezone.excity.America/Rankin_Inlet", "Rankin Inlet" },
-            { "timezone.excity.America/Scoresbysund", "Scoresbysund" },
             { "timezone.excity.Antarctica/Macquarie", "Macquarie" },
             { "timezone.excity.Pacific/Bougainville", "Bougainville" },
             { "timezone.excity.Pacific/Port_Moresby", "Port Moresby" },
             { "timezone.excity.America/Cambridge_Bay", "Cambridge Bay" },
             { "timezone.excity.America/Coral_Harbour", "Coral Harbour" },
-            { "timezone.excity.America/Indiana/Vevay", "\u0935\u0947\u0935\u0947, \u0907\u0902\u0921\u093f\u092f\u093e\u0928\u093e" },
-            { "timezone.excity.America/Lower_Princes", "Lower Princes" },
             { "timezone.excity.America/Port_of_Spain", "Port of Spain" },
-            { "timezone.excity.America/Santo_Domingo", "Santo_Domingo" },
+            { "timezone.excity.America/Santo_Domingo", "Santo Domingo" },
             { "timezone.excity.America/St_Barthelemy", "St Barthelemy" },
             { "timezone.excity.America/Swift_Current", "Swift Current" },
             { "timezone.excity.Australia/Broken_Hill", "Broken Hill" },
@@ -618,22 +618,13 @@ public class TimeZoneNames_hi_Latn extends TimeZoneNamesBundle {
             { "timezone.excity.America/Port-au-Prince", "Port-au-Prince" },
             { "timezone.excity.Atlantic/South_Georgia", "South Georgia" },
             { "timezone.excity.America/Argentina/Salta", "Salta" },
-            { "timezone.excity.America/Indiana/Marengo", "Indiana/Marengo" },
-            { "timezone.excity.America/Indiana/Winamac", "Indiana/Winamac" },
             { "timezone.excity.America/Argentina/Tucuman", "Tucuman" },
             { "timezone.excity.America/Argentina/Ushuaia", "Ushuaia" },
-            { "timezone.excity.America/Indiana/Tell_City", "Indiana/Tell City" },
-            { "timezone.excity.America/Indiana/Vincennes", "Indiana/Vincennes" },
             { "timezone.excity.Antarctica/DumontDUrville", "DumontDUrville" },
             { "timezone.excity.America/Argentina/La_Rioja", "La Rioja" },
             { "timezone.excity.America/Argentina/San_Juan", "San Juan" },
             { "timezone.excity.America/Argentina/San_Luis", "San Luis" },
-            { "timezone.excity.America/Indiana/Petersburg", "Indiana/Petersburg" },
-            { "timezone.excity.America/Kentucky/Monticello", "Kentucky/Monticello" },
-            { "timezone.excity.America/North_Dakota/Beulah", "North Dakota/Beulah" },
-            { "timezone.excity.America/North_Dakota/Center", "North Dakota/Center" },
             { "timezone.excity.America/Argentina/Rio_Gallegos", "Rio Gallegos" },
-            { "timezone.excity.America/North_Dakota/New_Salem", "North Dakota/New Salem" },
         };
         return data;
     }
