@@ -1287,7 +1287,6 @@ public class TimeZoneNames_so extends TimeZoneNamesBundle {
             { "Asia/Hovd", Hovd },
             { "Asia/Omsk", Omsk },
             { "Asia/Oral", Kazakhstan_Western },
-            { "Asia/Amman", Europe_Eastern },
             { "Asia/Aqtau", Kazakhstan_Western },
             { "Asia/Chita", Yakutsk },
             { "Asia/Dhaka", Bangladesh },
@@ -1383,7 +1382,6 @@ public class TimeZoneNames_so extends TimeZoneNamesBundle {
             { "America/Thule", Atlantic },
             { "Asia/Ashgabat", Turkmenistan },
             { "Asia/Calcutta", India },
-            { "Asia/Damascus", Europe_Eastern },
             { "Asia/Dushanbe", Tajikistan },
             { "Asia/Jayapura", Indonesia_Eastern },
             { "Asia/Katmandu", Nepal },
@@ -1695,6 +1693,7 @@ public class TimeZoneNames_so extends TimeZoneNamesBundle {
             { "Antarctica/Macquarie", Australia_Eastern },
             { "Pacific/Port_Moresby", Papua_New_Guinea },
             { "America/Cambridge_Bay", America_Mountain },
+            { "America/Ciudad_Juarez", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
             { "America/Indiana/Vevay", America_Eastern },
             { "America/Lower_Princes", Atlantic },
@@ -1716,8 +1715,11 @@ public class TimeZoneNames_so extends TimeZoneNamesBundle {
             { "America/Indiana/Vincennes", America_Eastern },
             { "Antarctica/DumontDUrville", DumontDUrville },
             { "timezone.excity.Asia/Aden", "Cadan" },
+            { "timezone.excity.Asia/Dili", "Dili" },
             { "timezone.excity.Asia/Gaza", "Qasa" },
             { "timezone.excity.Asia/Hovd", "Hofud" },
+            { "timezone.excity.Asia/Omsk", "Omsk" },
+            { "timezone.excity.Asia/Oral", "Oral" },
             { "America/Argentina/La_Rioja", Argentina },
             { "America/Argentina/San_Juan", Argentina },
             { "America/Argentina/San_Luis", Argentina },
@@ -1731,15 +1733,20 @@ public class TimeZoneNames_so extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Macau", "Makow" },
             { "timezone.excity.Asia/Qatar", "Qaddar" },
             { "timezone.excity.Asia/Seoul", "Soul" },
+            { "timezone.excity.Asia/Tokyo", "Tokyo" },
+            { "timezone.excity.Asia/Tomsk", "Tomsk" },
             { "America/Kentucky/Monticello", America_Eastern },
             { "America/North_Dakota/Beulah", America_Central },
             { "America/North_Dakota/Center", America_Central },
+            { "timezone.excity.Africa/Juba", "Juba" },
             { "timezone.excity.Africa/Lome", "Loom" },
             { "timezone.excity.Asia/Almaty", "Almati" },
             { "timezone.excity.Asia/Anadyr", "Anadiyr" },
+            { "timezone.excity.Asia/Aqtobe", "Aqtobe" },
             { "timezone.excity.Asia/Atyrau", "Atiyraw" },
             { "timezone.excity.Asia/Beirut", "Beyruud" },
             { "timezone.excity.Asia/Brunei", "Buruney" },
+            { "timezone.excity.Asia/Hebron", "Hebron" },
             { "timezone.excity.Asia/Kuwait", "Kuweyt" },
             { "timezone.excity.Asia/Manila", "Maniila" },
             { "timezone.excity.Asia/Muscat", "Muskat" },
@@ -1747,6 +1754,7 @@ public class TimeZoneNames_so extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Saigon", "Hoo Ji Mih Siti" },
             { "timezone.excity.Asia/Taipei", "Teybey" },
             { "timezone.excity.Asia/Tehran", "Tehraan" },
+            { "timezone.excity.Asia/Urumqi", "Urumqi" },
             { "timezone.excity.Etc/Unknown", "Magaalo Aan La Garanayn" },
             { "timezone.excity.Europe/Kiev", "Kiyeef" },
             { "timezone.excity.Europe/Riga", "Riija" },
@@ -1754,6 +1762,7 @@ public class TimeZoneNames_so extends TimeZoneNamesBundle {
             { "timezone.excity.Africa/Accra", "Akra" },
             { "timezone.excity.Africa/Cairo", "Qaahira" },
             { "timezone.excity.Africa/Ceuta", "Seuta" },
+            { "timezone.excity.Africa/Dakar", "Dakar" },
             { "timezone.excity.Africa/Lagos", "Laagoos" },
             { "timezone.excity.Africa/Tunis", "Tuunis" },
             { "timezone.excity.America/Lima", "Liima" },
@@ -1762,6 +1771,7 @@ public class TimeZoneNames_so extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Bahrain", "Baxreyn" },
             { "timezone.excity.Asia/Bangkok", "Bangkook" },
             { "timezone.excity.Asia/Barnaul", "Barnaauul" },
+            { "timezone.excity.Asia/Bishkek", "Bishkek" },
             { "timezone.excity.Asia/Colombo", "Kolombo" },
             { "timezone.excity.Asia/Irkutsk", "Irkutsik" },
             { "timezone.excity.Asia/Jakarta", "Jakaarta" },
@@ -1780,14 +1790,18 @@ public class TimeZoneNames_so extends TimeZoneNamesBundle {
             { "timezone.excity.Europe/Vaduz", "Faduus" },
             { "timezone.excity.Indian/Cocos", "Kokos" },
             { "timezone.excity.Pacific/Apia", "Abiya" },
+            { "timezone.excity.Pacific/Fiji", "Fiji" },
             { "timezone.excity.Pacific/Guam", "Guwam" },
             { "timezone.excity.Pacific/Niue", "Niyuu" },
             { "timezone.excity.Pacific/Truk", "Juuk" },
+            { "timezone.excity.Pacific/Wake", "Wake" },
             { "timezone.excity.Africa/Bamako", "Bamaako" },
             { "timezone.excity.Africa/Bangui", "Baagi" },
+            { "timezone.excity.Africa/Banjul", "Banjul" },
             { "timezone.excity.Africa/Bissau", "Bisaaw" },
             { "timezone.excity.Africa/Douala", "Douaala" },
             { "timezone.excity.Africa/Harare", "Haraare" },
+            { "timezone.excity.Africa/Kigali", "Kigali" },
             { "timezone.excity.Africa/Luanda", "Luwaanda" },
             { "timezone.excity.Africa/Lusaka", "Lusaaka" },
             { "timezone.excity.Africa/Maputo", "Mabuuto" },
@@ -1797,15 +1811,19 @@ public class TimeZoneNames_so extends TimeZoneNamesBundle {
             { "timezone.excity.America/Boise", "Boyse" },
             { "timezone.excity.America/Sitka", "Siitka" },
             { "timezone.excity.America/Thule", "Tuul" },
+            { "timezone.excity.Asia/Ashgabat", "Ashgabat" },
             { "timezone.excity.Asia/Calcutta", "Kolkaata" },
             { "timezone.excity.Asia/Damascus", "Dimishiq" },
+            { "timezone.excity.Asia/Dushanbe", "Dushanbe" },
             { "timezone.excity.Asia/Jayapura", "Jayabura" },
             { "timezone.excity.Asia/Katmandu", "Katmandu" },
             { "timezone.excity.Asia/Khandyga", "Khandiyga" },
             { "timezone.excity.Asia/Makassar", "Makasar" },
             { "timezone.excity.Asia/Qostanay", "Kostanay" },
+            { "timezone.excity.Asia/Sakhalin", "Sakhalin" },
             { "timezone.excity.Asia/Shanghai", "Shanghaay" },
             { "timezone.excity.Asia/Tashkent", "Toshkeent" },
+            { "timezone.excity.Asia/Ust-Nera", "Ust-Nera" },
             { "timezone.excity.Europe/Athens", "Atens" },
             { "timezone.excity.Europe/Berlin", "Barliin" },
             { "timezone.excity.Europe/Dublin", "Dhaablin" },
@@ -1815,6 +1833,7 @@ public class TimeZoneNames_so extends TimeZoneNamesBundle {
             { "timezone.excity.Europe/Monaco", "Monako" },
             { "timezone.excity.Europe/Moscow", "Moskow" },
             { "timezone.excity.Europe/Prague", "Baraag" },
+            { "timezone.excity.Europe/Samara", "Samara" },
             { "timezone.excity.Europe/Skopje", "Iskoobje" },
             { "timezone.excity.Europe/Tirane", "Tiraane" },
             { "timezone.excity.Europe/Vienna", "Fiyeena" },
@@ -1822,6 +1841,7 @@ public class TimeZoneNames_so extends TimeZoneNamesBundle {
             { "timezone.excity.Europe/Zurich", "Suurikh" },
             { "timezone.excity.Indian/Chagos", "Jagos" },
             { "timezone.excity.Indian/Comoro", "Komoro" },
+            { "timezone.excity.Pacific/Efate", "Efate" },
             { "timezone.excity.Pacific/Nauru", "Nawroo" },
             { "timezone.excity.Pacific/Palau", "Balaw" },
             { "America/Argentina/Rio_Gallegos", Argentina },
@@ -1851,6 +1871,7 @@ public class TimeZoneNames_so extends TimeZoneNamesBundle {
             { "timezone.excity.America/Panama", "Banaama" },
             { "timezone.excity.America/Recife", "Receyf" },
             { "timezone.excity.America/Regina", "Rejiina" },
+            { "timezone.excity.Asia/Famagusta", "Famagusta" },
             { "timezone.excity.Asia/Hong_Kong", "Hoong Koong" },
             { "timezone.excity.Asia/Jerusalem", "Jeerusaalem" },
             { "timezone.excity.Asia/Kamchatka", "Kamkatka" },
@@ -1870,9 +1891,12 @@ public class TimeZoneNames_so extends TimeZoneNamesBundle {
             { "timezone.excity.Pacific/Easter", "Iistar" },
             { "timezone.excity.Pacific/Kosrae", "Kosrii" },
             { "timezone.excity.Pacific/Majuro", "Majro" },
+            { "timezone.excity.Pacific/Midway", "Midway" },
             { "timezone.excity.Pacific/Noumea", "Noomiya" },
             { "timezone.excity.Pacific/Ponape", "Bonbey" },
             { "timezone.excity.Pacific/Saipan", "Seyban" },
+            { "timezone.excity.Pacific/Tahiti", "Tahiti" },
+            { "timezone.excity.Pacific/Tarawa", "Tarawa" },
             { "timezone.excity.Pacific/Wallis", "Walis" },
             { "timezone.excity.Africa/Blantyre", "Balantire" },
             { "timezone.excity.Africa/Djibouti", "Jibuuti" },
@@ -1880,6 +1904,7 @@ public class TimeZoneNames_so extends TimeZoneNamesBundle {
             { "timezone.excity.Africa/Freetown", "Firiitawn" },
             { "timezone.excity.Africa/Gaborone", "Gabroon" },
             { "timezone.excity.Africa/Khartoum", "Khartuum" },
+            { "timezone.excity.Africa/Kinshasa", "Kinshasa" },
             { "timezone.excity.Africa/Monrovia", "Monrofiya" },
             { "timezone.excity.Africa/Ndjamena", "Injamina" },
             { "timezone.excity.Africa/Sao_Tome", "Saw Toom" },
@@ -1929,6 +1954,7 @@ public class TimeZoneNames_so extends TimeZoneNamesBundle {
             { "timezone.excity.Pacific/Fakaofo", "fakofo" },
             { "timezone.excity.Pacific/Gambier", "Gambiyr" },
             { "timezone.excity.Pacific/Norfolk", "Noorfek" },
+            { "timezone.excity.Africa/Bujumbura", "Bujumbura" },
             { "timezone.excity.Africa/Mogadishu", "Muqdisho" },
             { "timezone.excity.America/Anguilla", "Anguwila" },
             { "timezone.excity.America/Asuncion", "Asunkiyon" },
@@ -1950,11 +1976,13 @@ public class TimeZoneNames_so extends TimeZoneNamesBundle {
             { "timezone.excity.Antarctica/Troll", "Torool" },
             { "timezone.excity.Asia/Krasnoyarsk", "Karasnoyarska" },
             { "timezone.excity.Asia/Novosibirsk", "Nofosibirsik" },
+            { "timezone.excity.Asia/Ulaanbaatar", "Ulaanbaatar" },
             { "timezone.excity.Asia/Vladivostok", "Faladifostok" },
             { "timezone.excity.Atlantic/Bermuda", "Barmuuda" },
             { "timezone.excity.Atlantic/Madeira", "Madira" },
             { "timezone.excity.Atlantic/Stanley", "Istaanley" },
             { "timezone.excity.Australia/Currie", "Kuriy" },
+            { "timezone.excity.Australia/Darwin", "Darwin" },
             { "timezone.excity.Australia/Hobart", "Hubaart" },
             { "timezone.excity.Australia/Sydney", "Sidney" },
             { "timezone.excity.Europe/Amsterdam", "Amsterdaam" },
@@ -1970,6 +1998,7 @@ public class TimeZoneNames_so extends TimeZoneNamesBundle {
             { "timezone.excity.Indian/Kerguelen", "Kergalen" },
             { "timezone.excity.Indian/Mauritius", "Morishiyaas" },
             { "timezone.excity.Pacific/Auckland", "Owklaan" },
+            { "timezone.excity.Pacific/Funafuti", "Funafuti" },
             { "timezone.excity.Pacific/Johnston", "Joonston" },
             { "timezone.excity.Pacific/Pitcairn", "Bitkayrn" },
             { "timezone.excity.Africa/Casablanca", "Kasabalaanka" },
@@ -1992,6 +2021,7 @@ public class TimeZoneNames_so extends TimeZoneNamesBundle {
             { "timezone.excity.America/Sao_Paulo", "Saaw Boolo" },
             { "timezone.excity.America/St_Thomas", "St. Toomas" },
             { "timezone.excity.America/Vancouver", "Fankuufar" },
+            { "timezone.excity.Antarctica/Mawson", "Mawson" },
             { "timezone.excity.Antarctica/Palmer", "Baamar" },
             { "timezone.excity.Antarctica/Vostok", "Fostok" },
             { "timezone.excity.Asia/Kuala_Lumpur", "Kuala Lambuur" },
@@ -2007,7 +2037,9 @@ public class TimeZoneNames_so extends TimeZoneNamesBundle {
             { "timezone.excity.Pacific/Kwajalein", "Kuwajaleyn" },
             { "timezone.excity.Pacific/Marquesas", "Marquwesas" },
             { "timezone.excity.Pacific/Pago_Pago", "Bago Bago" },
+            { "timezone.excity.Pacific/Rarotonga", "Rarotonga" },
             { "timezone.excity.Pacific/Tongatapu", "Tongatabu" },
+            { "timezone.excity.Africa/Addis_Ababa", "Addis Ababa" },
             { "timezone.excity.Africa/Brazzaville", "Barasafil" },
             { "timezone.excity.Africa/Ouagadougou", "Wagadugu" },
             { "timezone.excity.America/Costa_Rica", "Kosta Riika" },
@@ -2031,7 +2063,9 @@ public class TimeZoneNames_so extends TimeZoneNamesBundle {
             { "timezone.excity.Atlantic/Reykjavik", "Reykjafik" },
             { "timezone.excity.Australia/Adelaide", "Adelayde" },
             { "timezone.excity.Australia/Brisbane", "Birisban" },
+            { "timezone.excity.Australia/Lindeman", "Lindeman" },
             { "timezone.excity.Europe/Isle_of_Man", "Ayle of Maan" },
+            { "timezone.excity.Europe/Kaliningrad", "Kaliningrad" },
             { "timezone.excity.Pacific/Kiritimati", "Kiritimaati" },
             { "timezone.excity.Africa/Johannesburg", "Johansbaag" },
             { "timezone.excity.America/El_Salvador", "El Salfadoor" },
