@@ -1295,7 +1295,6 @@ public class TimeZoneNames_sq extends TimeZoneNamesBundle {
             { "Asia/Hovd", Hovd },
             { "Asia/Omsk", Omsk },
             { "Asia/Oral", Kazakhstan_Western },
-            { "Asia/Amman", Europe_Eastern },
             { "Asia/Aqtau", Kazakhstan_Western },
             { "Asia/Chita", Yakutsk },
             { "Asia/Dhaka", Bangladesh },
@@ -1391,7 +1390,6 @@ public class TimeZoneNames_sq extends TimeZoneNamesBundle {
             { "America/Thule", Atlantic },
             { "Asia/Ashgabat", Turkmenistan },
             { "Asia/Calcutta", India },
-            { "Asia/Damascus", Europe_Eastern },
             { "Asia/Dushanbe", Tajikistan },
             { "Asia/Jayapura", Indonesia_Eastern },
             { "Asia/Katmandu", Nepal },
@@ -1704,6 +1702,7 @@ public class TimeZoneNames_sq extends TimeZoneNamesBundle {
             { "Antarctica/Macquarie", Australia_Eastern },
             { "Pacific/Port_Moresby", Papua_New_Guinea },
             { "America/Cambridge_Bay", America_Mountain },
+            { "America/Ciudad_Juarez", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
             { "America/Indiana/Vevay", America_Eastern },
             { "America/Lower_Princes", Atlantic },
@@ -1913,6 +1912,7 @@ public class TimeZoneNames_sq extends TimeZoneNamesBundle {
             { "timezone.excity.Indian/Mayotte", "Majot\u00eb" },
             { "timezone.excity.Indian/Reunion", "Reunion" },
             { "timezone.excity.Pacific/Easter", "Pashk\u00eb" },
+            { "timezone.excity.Pacific/Kanton", "Kanton" },
             { "timezone.excity.Pacific/Kosrae", "Kosre" },
             { "timezone.excity.Pacific/Majuro", "Mahuro" },
             { "timezone.excity.Pacific/Midway", "Miduej" },
