@@ -1255,7 +1255,6 @@ public class TimeZoneNames_tk extends TimeZoneNamesBundle {
             { "Asia/Hovd", Hovd },
             { "Asia/Omsk", Omsk },
             { "Asia/Oral", Kazakhstan_Western },
-            { "Asia/Amman", Europe_Eastern },
             { "Asia/Aqtau", Kazakhstan_Western },
             { "Asia/Chita", Yakutsk },
             { "Asia/Dhaka", Bangladesh },
@@ -1350,7 +1349,6 @@ public class TimeZoneNames_tk extends TimeZoneNamesBundle {
             { "America/Thule", Atlantic },
             { "Asia/Ashgabat", Turkmenistan },
             { "Asia/Calcutta", India },
-            { "Asia/Damascus", Europe_Eastern },
             { "Asia/Dushanbe", Tajikistan },
             { "Asia/Jayapura", Indonesia_Eastern },
             { "Asia/Katmandu", Nepal },
@@ -1658,6 +1656,7 @@ public class TimeZoneNames_tk extends TimeZoneNamesBundle {
             { "Antarctica/Macquarie", Australia_Eastern },
             { "Pacific/Port_Moresby", Papua_New_Guinea },
             { "America/Cambridge_Bay", America_Mountain },
+            { "America/Ciudad_Juarez", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
             { "America/Indiana/Vevay", America_Eastern },
             { "America/Lower_Princes", Atlantic },
@@ -1866,6 +1865,7 @@ public class TimeZoneNames_tk extends TimeZoneNamesBundle {
             { "timezone.excity.Indian/Mayotte", "Ma\u00fdotta" },
             { "timezone.excity.Indian/Reunion", "Re\u00fdun\u00fdon" },
             { "timezone.excity.Pacific/Easter", "Pasha adasy" },
+            { "timezone.excity.Pacific/Kanton", "Kanton" },
             { "timezone.excity.Pacific/Kosrae", "Kosra\u00fde" },
             { "timezone.excity.Pacific/Majuro", "Majuro" },
             { "timezone.excity.Pacific/Midway", "Midue\u00fd" },
