@@ -106,14 +106,6 @@ public class TimeZoneNames_yo extends TimeZoneNamesBundle {
                "Fiji Time",
                "",
             };
-        final String[] Gulf = new String[] {
-               "Gulf Standard Time [translation hint: translate as just \"Gulf Time\"]",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Hovd = new String[] {
                "Hovd Standard Time",
                "",
@@ -1255,11 +1247,9 @@ public class TimeZoneNames_yo extends TimeZoneNamesBundle {
             { "Asia/Hovd", Hovd },
             { "Asia/Omsk", Omsk },
             { "Asia/Oral", Kazakhstan_Western },
-            { "Asia/Amman", Europe_Eastern },
             { "Asia/Aqtau", Kazakhstan_Western },
             { "Asia/Chita", Yakutsk },
             { "Asia/Dhaka", Bangladesh },
-            { "Asia/Dubai", Gulf },
             { "Asia/Kabul", Afghanistan },
             { "Asia/Macau", China },
             { "Asia/Qatar", Arabian },
@@ -1275,7 +1265,6 @@ public class TimeZoneNames_yo extends TimeZoneNamesBundle {
             { "Asia/Hebron", Europe_Eastern },
             { "Asia/Kuwait", Arabian },
             { "Asia/Manila", Philippines },
-            { "Asia/Muscat", Gulf },
             { "Asia/Riyadh", Arabian },
             { "Asia/Saigon", Indochina },
             { "Asia/Taipei", Taipei },
@@ -1350,7 +1339,6 @@ public class TimeZoneNames_yo extends TimeZoneNamesBundle {
             { "America/Thule", Atlantic },
             { "Asia/Ashgabat", Turkmenistan },
             { "Asia/Calcutta", India },
-            { "Asia/Damascus", Europe_Eastern },
             { "Asia/Dushanbe", Tajikistan },
             { "Asia/Jayapura", Indonesia_Eastern },
             { "Asia/Katmandu", Nepal },
@@ -1658,6 +1646,7 @@ public class TimeZoneNames_yo extends TimeZoneNamesBundle {
             { "Antarctica/Macquarie", Australia_Eastern },
             { "Pacific/Port_Moresby", Papua_New_Guinea },
             { "America/Cambridge_Bay", America_Mountain },
+            { "America/Ciudad_Juarez", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
             { "America/Indiana/Vevay", America_Eastern },
             { "America/Lower_Princes", Atlantic },
