@@ -1295,7 +1295,6 @@ public class TimeZoneNames_yue extends TimeZoneNamesBundle {
             { "Asia/Hovd", Hovd },
             { "Asia/Omsk", Omsk },
             { "Asia/Oral", Kazakhstan_Western },
-            { "Asia/Amman", Europe_Eastern },
             { "Asia/Aqtau", Kazakhstan_Western },
             { "Asia/Chita", Yakutsk },
             { "Asia/Dhaka", Bangladesh },
@@ -1391,7 +1390,6 @@ public class TimeZoneNames_yue extends TimeZoneNamesBundle {
             { "America/Thule", Atlantic },
             { "Asia/Ashgabat", Turkmenistan },
             { "Asia/Calcutta", India },
-            { "Asia/Damascus", Europe_Eastern },
             { "Asia/Dushanbe", Tajikistan },
             { "Asia/Jayapura", Indonesia_Eastern },
             { "Asia/Katmandu", Nepal },
@@ -1704,6 +1702,7 @@ public class TimeZoneNames_yue extends TimeZoneNamesBundle {
             { "Antarctica/Macquarie", Australia_Eastern },
             { "Pacific/Port_Moresby", Papua_New_Guinea },
             { "America/Cambridge_Bay", America_Mountain },
+            { "America/Ciudad_Juarez", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
             { "America/Indiana/Vevay", America_Eastern },
             { "America/Lower_Princes", Atlantic },
@@ -1913,6 +1912,7 @@ public class TimeZoneNames_yue extends TimeZoneNamesBundle {
             { "timezone.excity.Indian/Mayotte", "\u99ac\u7d04\u7279\u5cf6" },
             { "timezone.excity.Indian/Reunion", "\u7559\u5c3c\u65fa\u5cf6" },
             { "timezone.excity.Pacific/Easter", "\u5fa9\u6d3b\u5cf6" },
+            { "timezone.excity.Pacific/Kanton", "\u574e\u9813" },
             { "timezone.excity.Pacific/Kosrae", "\u79d1\u65af\u745e" },
             { "timezone.excity.Pacific/Majuro", "\u99ac\u6731\u8afe" },
             { "timezone.excity.Pacific/Midway", "\u4e2d\u9014\u5cf6" },
